package com.andreums.culturarocafort;

import android.app.Notification;
import android.app.NotificationManager;
import android.app.PendingIntent;
import android.content.Context;
import android.content.Intent;
import android.content.SharedPreferences;
import android.os.AsyncTask;
import android.os.Build;
import android.os.Bundle;
import android.support.v4.app.NotificationCompat;
import android.util.Log;
import android.widget.Toast;

import com.andreums.culturarocafort.notification.Notifier;
import com.google.android.gcm.GCMBaseIntentService;

import org.apache.http.NameValuePair;
import org.apache.http.client.HttpClient;
import org.apache.http.client.ResponseHandler;
import org.apache.http.client.entity.UrlEncodedFormEntity;
import org.apache.http.client.methods.HttpPost;
import org.apache.http.impl.client.BasicResponseHandler;
import org.apache.http.impl.client.DefaultHttpClient;
import org.apache.http.message.BasicNameValuePair;
import org.json.JSONObject;

import java.util.ArrayList;
import java.util.Random;

public class GCMIntentService extends GCMBaseIntentService {

    private final static String senderID = "970923970258";



    public GCMIntentService(){
        super(senderID);
	 }

    public GCMIntentService(String senderId) {
        super(senderId);
    }




    @Override
	 protected void onError(Context context, String errorId) {
         Log.d("GCM", "Error: " + errorId);
	 }
 
	 @Override
	 protected void onMessage(Context context, Intent intent) {
         int code     = 0;
         String title = "";
	     String msg   = "";

         Bundle extras = intent.getExtras();
         if (extras.containsKey("message")) {
             msg   = extras.getString("message");
         }
         if (extras.containsKey("title")) {
             title = extras.getString("title");
         }

         if (extras.containsKey("code")) {
             code = Integer.parseInt(intent.getExtras().getString("code"));
         }

         Notifier.getInstance().displayNotification(context,code,msg,title);
	 }

	 @Override
	 protected void onRegistered(Context context, String regId) {
         new RegisterDeviceTask().execute(regId);
	 }

	 @Override
	 protected void onUnregistered(Context context, String regId) {
         new UnregisterDeviceTask().execute(regId);
	 }
	 
	 private class RegisterDeviceTask extends AsyncTask<String,Void,Void> {		
			

	        @Override
	        protected Void doInBackground(String... params) {
	        	SharedPreferences preferences = getSharedPreferences("registration_data",Context.MODE_PRIVATE);
		   		 String username		       = params[0];
		   		 String password		       = params[0];
		   		 String email			       = params[0];
		   		 
		   		 try{
		   			 ArrayList<NameValuePair> nameValuePairs = new ArrayList<NameValuePair>();
		   			 nameValuePairs.add(new BasicNameValuePair("tag","usersave"));
		   			 nameValuePairs.add(new BasicNameValuePair("username",username));
		   			 nameValuePairs.add(new BasicNameValuePair("password",password));
		   			 nameValuePairs.add(new BasicNameValuePair("email",username));
		   			 nameValuePairs.add(new BasicNameValuePair("application", Constants.APP_PACKAGE_GCM));
		   			 nameValuePairs.add(new BasicNameValuePair("registration",params[0]));
		   			   
		   			 HttpClient httpclient = new DefaultHttpClient();
		   			 HttpPost httppost = new HttpPost(Constants.gcmRegisterURL);
		   			 if(nameValuePairs != null) {
		   				 httppost.setEntity(new UrlEncodedFormEntity(nameValuePairs));
		   			 }
		   			 ResponseHandler<String> responseHandler = new BasicResponseHandler();
		   			 String res = httpclient.execute(httppost, responseHandler);

                     JSONObject json =  new JSONObject(res);
                     String sResult  = json.getString("result");
                     GCMIntentService.this.createNotificationResult("register",sResult);

                     Toast.makeText(getApplicationContext(), getResources().getString(R.string.gcm_registered), Toast.LENGTH_LONG).show();
		   		}
		   		catch(Exception e){
		   			Log.w("GCM", "ex: " + e.getMessage().toString());
		   		}
		   		return null;
		   	}     
	  }

    private void createNotificationResult(String action, String result) {

        String message = "";
        String title   = getResources().getString(R.string.gcm_title);

        if (action.equals("register")) {
            if (result.equals("true")) {
                message = getResources().getString(R.string.gcm_registered);
            }
            else {
                message = getResources().getString(R.string.gcm_registered_ko);
            }
        }
        if (action.equals("unregister")) {
            if (result.equals("true")) {
                message = getResources().getString(R.string.gcm_unregistered);
            }
            else {
                message = getResources().getString(R.string.gcm_unregistered_ko);
            }
        }

        NotificationCompat.Builder builder = new NotificationCompat.Builder(this.getApplicationContext());

        Intent intent  = new Intent(this.getApplicationContext(), MainActivity.class);
        PendingIntent contIntent = PendingIntent.getActivity(this.getApplicationContext(), 0, intent, PendingIntent.FLAG_UPDATE_CURRENT);

        if (Build.VERSION.SDK_INT <= Build.VERSION_CODES.JELLY_BEAN) {
                    builder
                    .setSmallIcon(R.drawable.ic_icon)
                    .setContentTitle(title)
                    .setContentIntent(contIntent)
                    .setContentText(message);

        }
        else {
            builder
                    .setSmallIcon(R.drawable.ic_icon)
                    .setContentTitle(title)
                    .setContentText(message)
                    .setContentIntent(contIntent)
                    .setDefaults(Notification.DEFAULT_ALL)
                    .setStyle(new NotificationCompat.BigTextStyle().bigText(message));

        }

        builder.build();

        String notificationService              = Context.NOTIFICATION_SERVICE;
        NotificationManager notificationManager = (NotificationManager) this.getApplicationContext().getSystemService(notificationService);


        Random r        = new Random();
        int id          = r.nextInt();

        notificationManager.notify(id,builder.build());

    }


    private class UnregisterDeviceTask extends AsyncTask<String,Void,Void> {

         @Override
         protected Void doInBackground(String... params) {
             try{
                 ArrayList<NameValuePair> nameValuePairs = new ArrayList<NameValuePair>();
	   			 nameValuePairs.add(new BasicNameValuePair("tag","usersave"));
	   			 nameValuePairs.add(new BasicNameValuePair("application",getApplication().getPackageName()));
	   			 nameValuePairs.add(new BasicNameValuePair("registration",params[0]));

                 HttpClient httpclient = new DefaultHttpClient();
                 HttpPost httppost = new HttpPost(Constants.gcmUnRegisterURL);
                 if(nameValuePairs != null) {
                     httppost.setEntity(new UrlEncodedFormEntity(nameValuePairs));
                 }
                 ResponseHandler<String> responseHandler = new BasicResponseHandler();
                 String res = httpclient.execute(httppost, responseHandler);

                 JSONObject json =  new JSONObject(res);
                 String sResult  = json.getString("result");
                 GCMIntentService.this.createNotificationResult("unregister",sResult);


                 Toast.makeText(getApplicationContext(), getResources().getString(R.string.gcm_unregistered), Toast.LENGTH_LONG).show();
             }
             catch(Exception e){
                 Log.w("GCM", "ex: " + e.getMessage().toString());
             }
             return null;
        }
     }

}