package com.andreums.culturarocafort;

import android.app.AlertDialog;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.DialogInterface;
import android.content.Intent;
import android.content.IntentFilter;
import android.content.pm.ActivityInfo;
import android.content.res.Configuration;
import android.os.Build;
import android.os.Bundle;
import android.provider.Settings;
import android.support.v4.app.ActionBarDrawerToggle;
import android.support.v4.app.ActivityCompat;
import android.support.v4.app.Fragment;
import android.support.v4.app.FragmentManager;
import android.support.v4.app.FragmentTransaction;
import android.support.v4.widget.DrawerLayout;
import android.support.v7.app.ActionBar;
import android.support.v7.app.ActionBarActivity;
import android.util.Log;
import android.view.KeyEvent;
import android.view.Menu;
import android.view.MenuInflater;
import android.view.MenuItem;
import android.view.View;
import android.view.ViewConfiguration;
import android.view.Window;
import android.widget.AdapterView;
import android.widget.ListView;

import com.andreums.culturarocafort.activities.messages.MessagesActivity;
import com.andreums.culturarocafort.activities.settings.SettingsActivity;
import com.andreums.culturarocafort.adapters.main.SideMenuAdapter;
import com.andreums.culturarocafort.dialogs.FirstRunDialog;
import com.andreums.culturarocafort.dialogs.RateAppDialog;
import com.andreums.culturarocafort.fragments.other.AboutFragment;
import com.andreums.culturarocafort.fragments.other.ContactFragment;
import com.andreums.culturarocafort.fragments.events.EventCategoriesFragment;
import com.andreums.culturarocafort.fragments.events.EventsFragment;
import com.andreums.culturarocafort.fragments.facebook.FacebookFragment;
import com.andreums.culturarocafort.fragments.events.FavoriteEventsFragment;
import com.andreums.culturarocafort.fragments.home.HomeScreenFragment;
import com.andreums.culturarocafort.fragments.other.InformationFragment;
import com.andreums.culturarocafort.fragments.events.NextEventsFragment;
import com.andreums.culturarocafort.fragments.photos.PhotosFragment;
import com.andreums.culturarocafort.fragments.posts.PostCategoriesFragment;
import com.andreums.culturarocafort.fragments.posts.PostCategoryFragment;
import com.andreums.culturarocafort.fragments.posts.PostFragment;
import com.andreums.culturarocafort.fragments.events.SpecialEventsFragment;
import com.andreums.culturarocafort.fragments.twitter.TwitterFragment;
import com.andreums.culturarocafort.fragments.videos.VideosFragment;
import com.andreums.culturarocafort.fragments.other.WebViewFragment;
import com.andreums.culturarocafort.models.SideMenuItem;
import com.andreums.culturarocafort.notification.NotificationDialog;
import com.andreums.culturarocafort.services.FirstTimeDownloaderService;
import com.andreums.culturarocafort.util.Connection;
import com.andreums.culturarocafort.util.DataStorage;
import com.andreums.culturarocafort.util.LocaleUtil;
import com.andreums.culturarocafort.util.Preferences;
import com.google.android.gcm.GCMRegistrar;

import java.lang.reflect.Field;
import java.util.ArrayList;
import java.util.Locale;


public class MainActivity extends ActionBarActivity {



    private static boolean isRegistered;

    private DrawerLayout drawerLayout;
    private ListView drawerList;
    private ActionBarDrawerToggle drawerToggle;

    private CharSequence tituloSeccion;
    private CharSequence tituloApp;
    public static boolean mTwoPane;


    private FirstRunDialog dialog;

    private FirstDownloadReceiver receiver;
    public static Fragment displayedFragment;
    private ArrayList<SideMenuItem> options = new ArrayList<SideMenuItem>();


    @Override
    public void onCreate(Bundle savedInstanceState) {
        this.getWindow().requestFeature(Window.FEATURE_INDETERMINATE_PROGRESS);
        super.onCreate(savedInstanceState);
        setProgressBarIndeterminateVisibility(false);
        setContentView(R.layout.activity_main);

        this.changeMenuConfiguration();
        this.setLocale();
        this.setInterface();
        this.firstTime();
        this.rateApp();
        this.checkForMessages();

        if (!DataStorage.isFirstRunRunning() && !this.isGCMRegistered()) {
            this.registerGCM();
        }
    }




    @Override
    public void onResume() {
        super.onResume();
        Log.d("DEBUG", "Llamo a OnResume");

        if (!DataStorage.isFirstRunRunning() && !this.isGCMRegistered()) {
            this.registerGCM();
        }

        this.changeMenuConfiguration();
        this.setLocale();

        this.setDisplayedFragment();
        this.setActionbar();
        this.checkForMessages();

    }


    @Override
    public void onPause() {
        super.onPause();
        Log.d("DEBUG","Llamo a OnPause");
        try {
            GCMRegistrar.onDestroy(getApplicationContext());
            try {
                if (!DataStorage.isFirstRunRunning()) {
                    if (this.receiver!=null && MainActivity.isRegistered!=false) {
                        unregisterReceiver(this.receiver);
                    }
                    MainActivity.isRegistered = false;
                    Log.d("DEBUG","Acabo de destruir el Receiver!");
                }
                else {
                    Log.d("DEBUG","No destruyo el Receiver, porque está cargando datos pror primera vez!");
                }
            }
            catch(Exception ex) {
                ex.printStackTrace();
            }
        }
        catch(Exception ex) {
            ex.printStackTrace();
        }
    }


    private void changeMenuConfiguration() {
        int currentapiVersion = Build.VERSION.SDK_INT;
        if (currentapiVersion >= Build.VERSION_CODES.HONEYCOMB){
            try {
                ViewConfiguration config = ViewConfiguration.get(MainActivity.this);
                Field menuKeyField = ViewConfiguration.class.getDeclaredField("sHasPermanentMenuKey");
                if (menuKeyField != null) {
                    menuKeyField.setAccessible(true);
                    menuKeyField.setBoolean(config, false);
                }
            }
            catch (Exception e) {
                e.printStackTrace();
            }
        }
    }


    private void setDisplayedFragment() {
        Fragment fragment;
        if (MainActivity.displayedFragment==null) {
            fragment = new HomeScreenFragment();
        }
        else {
            fragment = MainActivity.displayedFragment;

        }

        try {
            FragmentManager fragmentManager = getSupportFragmentManager();
            fragmentManager.beginTransaction().replace(R.id.content_frame, fragment).addToBackStack(null).commit();
            MainActivity.displayedFragment = fragment;
        }
        catch (Exception ex) {
            ex.getMessage().toString();
        }
    }




    private void setInterface() {
        drawerLayout = (DrawerLayout) findViewById(R.id.drawer_layout);
        drawerList   = (ListView) findViewById(R.id.left_drawer);

        if (findViewById(R.id.item_detail_container) != null) {
            MainActivity.mTwoPane = true;
        }

        this.setDrawer();
        this.setActionbar();
    }

    private void setActionbar() {
        ActionBar bar = getSupportActionBar();
        bar.setIcon(R.drawable.ic_launcher);
        bar.setTitle(getResources().getString(R.string.app_name));
        /*bar.setHomeButtonEnabled(false);
        bar.setDisplayHomeAsUpEnabled(false);*/
    }

    private void firstTime() {
        Preferences pref = Preferences.getInstance(getApplicationContext());
        if (pref.isFirstRun()) {
            setRequestedOrientation(ActivityInfo.SCREEN_ORIENTATION_NOSENSOR);
            DataStorage.setFirstRunRunning(true);
            if (Connection.getConnectionStatus(this.getApplicationContext())) {
                this.startFirstTimeDownloaderService();
            }
            else {
                this.showNoConnectionDialog();
            }
        }
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        MenuInflater inflater = getMenuInflater();


        inflater.inflate(R.menu.menu_main, menu);

        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {

        if (drawerToggle.onOptionsItemSelected(item)) {
            return true;
        }

        switch (item.getItemId()) {

            case R.id.action_settings:
                Intent intent = new Intent(this,SettingsActivity.class);
                startActivity(intent);
                break;

            case R.id.action_messages:
                Intent intent5 = new Intent(this, MessagesActivity.class);
                startActivity(intent5);
            break;

            case R.id.action_contact:
                Fragment fragment = new ContactFragment();
                this.getSupportFragmentManager().beginTransaction().replace(R.id.content_frame, fragment).addToBackStack(null).commit();
                MainActivity.displayedFragment = fragment;
                break;


            default:
                return super.onOptionsItemSelected(item);

        }

        return true;
    }

        public void showNoConnectionDialog() {
            AlertDialog.Builder builder = new AlertDialog.Builder((MainActivity)this);
            builder.setCancelable(true);
            builder.setTitle(R.string.main_no_connection_title);
            builder.setMessage(R.string.main_no_connection_content);
            builder.setPositiveButton(R.string.main_no_connection_button_settings, new DialogInterface.OnClickListener() {
                public void onClick(DialogInterface dialog, int which) {
                    startActivity(new Intent(Settings.ACTION_WIRELESS_SETTINGS));
                    MainActivity.this.firstTime();
                }
            });
            builder.setNegativeButton(R.string.main_no_connection_button_cancel, new DialogInterface.OnClickListener() {
                public void onClick(DialogInterface dialog, int which) {
                    MainActivity.this.firstTime();
                }
            });
            builder.setOnCancelListener(new DialogInterface.OnCancelListener() {
                public void onCancel(DialogInterface dialog) {
                    MainActivity.this.firstTime();
                }
            });

            builder.show();
        }






        private void startFirstTimeDownloaderService() {
            try {
                this.receiver             = new FirstDownloadReceiver();
                IntentFilter intentFilter = new IntentFilter("com.andreums.culturarocafort.downloaded.global");
                registerReceiver(this.receiver, intentFilter);
                MainActivity.isRegistered = true;
                Intent intent = new Intent(this.getApplicationContext(), FirstTimeDownloaderService.class);
                this.startService(intent);
                //this.progressDialog = ProgressDialog.show((MainActivity) this,getResources().getString(R.string.main_first_load_title),getResources().getString(R.string.main_first_load_content),true,false);
                this.dialog = new FirstRunDialog();
                this.dialog.show(getSupportFragmentManager(),"");

            }
            catch (Exception ex) {
                ex.printStackTrace();
            }



        }

    private void setLocale() {
        Preferences preferences = Preferences.getInstance(getApplicationContext());
        String language         = preferences.getValue("language");
        if (language.length()==0){
            language = "ca";
        }
        Locale locale   = new Locale(language);
        LocaleUtil util = new LocaleUtil(getApplicationContext());
        util.setDefaultLocale(locale);
    }



    private void removeFirstimeDialog() {
        this.registerGCM();
        this.dialog.dismiss();
        DataStorage.setFirstRunRunning(false);




        setRequestedOrientation(ActivityInfo.SCREEN_ORIENTATION_SENSOR);

        Intent intentResponse = new Intent();
        intentResponse.setAction("com.andreums.culturarocafort.startup");
        sendBroadcast(intentResponse);

        this.changeFragment(0,new HomeScreenFragment(),this.options);
        getSupportActionBar().setTitle("Cultura Rocafort");
    }


    /* Methods */


    public void rateApp() {
        Preferences prefs = Preferences.getInstance(this.getApplicationContext());

        boolean dontShowAgain = prefs.getValueBoolean("dontshowagain");
        if (dontShowAgain) {
            return;
        }

        int launchCount = (prefs.getValueInt("launch_count") +1) ;
        prefs.setValueInt("launch_count",launchCount);

        Long dateFirstLaunch = prefs.getValueLong("date_firstlaunch");
        if (dateFirstLaunch == -1) {
            dateFirstLaunch = System.currentTimeMillis();
            prefs.setValueLong("date_firstlaunch", dateFirstLaunch);
        }

        if (launchCount >= Constants.LAUNCHES_UNTIL_PROMPT) {
            if (System.currentTimeMillis() >= dateFirstLaunch +(Constants.DAYS_UNTIL_PROMPT * 24 * 60 * 60 * 1000)) {
                FragmentTransaction ft = getSupportFragmentManager().beginTransaction();
                new RateAppDialog().show(ft, "");
            }
        }
    }


    private void registerGCM(){
        Preferences prefs = Preferences.getInstance(this.getApplicationContext());
        boolean enabled = prefs.getValueBoolean("notifications_enabled");
        boolean isFirstRunning = DataStorage.isFirstRunRunning();
        if (enabled || isFirstRunning) {
            if (!this.isGCMRegistered()) {
                GCMRegistrar.register(getApplicationContext(),"970923970258");
            }
        }
    }

    private boolean isGCMRegistered() {
        return (!GCMRegistrar.getRegistrationId(getApplicationContext()).equals(""));
    }




    /* Home Screen Methods */

    public void showContact(View v) {
        Fragment fragment = new ContactFragment();
        this.getSupportFragmentManager().beginTransaction().replace(R.id.content_frame, fragment).addToBackStack(null).commit();
        MainActivity.displayedFragment = fragment;
    }




    private void checkForMessages() {
        int id = DataStorage.getGcmMessageId();
        if (id==-1 || id==0) {
            return;
        }
        else {
            try {
                FragmentTransaction ft = getSupportFragmentManager().beginTransaction();
                new NotificationDialog().setMessageId(id).show(ft,"");
                DataStorage.setGcmMessageId(-1);
            }
            catch (Exception ex) {
                ex.printStackTrace();
            }
        }
    }


    /* Navigation Drawer */
    private void setDrawer() {

        options.add(new SideMenuItem(getString(R.string.bar_title_home),R.drawable.ic_menu_home));
        options.add(new SideMenuItem(getString(R.string.bar_next_events),R.drawable.ic_menu_next_events));
        options.add(new SideMenuItem(getString(R.string.bar_posts_title),R.drawable.ic_menu_news));
        options.add(new SideMenuItem(getString(R.string.bar_post_categories_title),R.drawable.ic_menu_categories));
        options.add(new SideMenuItem(getString(R.string.bar_special_events),R.drawable.ic_menu_special_events));
        options.add(new SideMenuItem(getString(R.string.bar_favorite_title),R.drawable.ic_menu_favorite));
        options.add(new SideMenuItem(getString(R.string.bar_events_title),R.drawable.ic_menu_events));
        options.add(new SideMenuItem(getString(R.string.bar_categories_title),R.drawable.ic_menu_categories));
        options.add(new SideMenuItem(getString(R.string.bar_title_photos),R.drawable.ic_menu_photos));
        options.add(new SideMenuItem(getString(R.string.bar_title_videos),R.drawable.ic_menu_videos));
        options.add(new SideMenuItem(getString(R.string.bar_title_twitter),R.drawable.ic_menu_twitter));
        options.add(new SideMenuItem(getString(R.string.bar_title_facebook),R.drawable.ic_menu_facebook));
        options.add(new SideMenuItem(getString(R.string.bar_title_services),R.drawable.ic_menu_services));
        options.add(new SideMenuItem(getString(R.string.bar_information_title),R.drawable.ic_menu_information));
        options.add(new SideMenuItem(getString(R.string.bar_title_about),R.drawable.ic_menu_about));


        drawerList.setAdapter(new SideMenuAdapter(getSupportActionBar().getThemedContext(),R.layout.side_menu_item,options));
        drawerList.setOnItemClickListener(new AdapterView.OnItemClickListener() {
            @Override
            public void onItemClick(AdapterView<?> parent, View view,int position, long id) {

                Fragment fragment = null;

                switch (position) {
                    case 0:
                        fragment = new HomeScreenFragment();
                        break;
                    case 1:
                        fragment = new NextEventsFragment();
                        break;
                    case 2:
                        fragment = new PostFragment();
                        break;
                    case 3:
                        fragment = new PostCategoriesFragment();
                        break;
                    case 4:
                        fragment = new SpecialEventsFragment();
                        break;
                    case 5:
                        fragment = new FavoriteEventsFragment();
                        break;
                    case 6:
                        fragment = new EventsFragment();
                        break;
                    case 7:
                        fragment = new EventCategoriesFragment();
                        break;
                    case 8:
                        fragment = new PhotosFragment();
                        break;
                    case 9:
                        fragment = new VideosFragment();
                        break;
                    case 10:
                        fragment = new TwitterFragment();
                        break;
                    case 11:
                        fragment = new FacebookFragment();
                        break;
                    case 12:
                        fragment = new PostCategoryFragment();
                        Bundle bundle = new Bundle();
                        bundle.putIntArray("categories",new int[] {49});
                        fragment.setArguments(bundle);
                        break;
                    case 13:
                        fragment = new InformationFragment();
                        break;
                    case 14:
                        fragment = new AboutFragment();
                        break;
                }
                MainActivity.this.changeFragment(position, fragment, options);
            }
        });

        tituloSeccion = getTitle();
        tituloApp = getTitle();

        drawerToggle = new ActionBarDrawerToggle(this,
                drawerLayout,
                R.drawable.ic_menu,
                R.string.drawer_open,
                R.string.drawer_close) {

            public void onDrawerClosed(View view) {
                getSupportActionBar().setTitle(tituloSeccion);
                ActivityCompat.invalidateOptionsMenu(MainActivity.this);
            }

            public void onDrawerOpened(View drawerView) {
                getSupportActionBar().setTitle(tituloApp);
                ActivityCompat.invalidateOptionsMenu(MainActivity.this);
            }
        };

        drawerLayout.setDrawerListener(drawerToggle);

        getSupportActionBar().setDisplayHomeAsUpEnabled(true);
        getSupportActionBar().setHomeButtonEnabled(true);
    }

    private void changeFragment(int position, Fragment fragment, ArrayList<SideMenuItem> options) {
        getSupportFragmentManager().popBackStack();
        FragmentManager fragmentManager = getSupportFragmentManager();

        View v = (View) findViewById(R.id.content_frame);
        v.setVisibility(View.VISIBLE);

        String className =  ((Object) fragment).getClass().getSimpleName();

        if (className.equals("PhotosFragment")  ) {
            if (MainActivity.mTwoPane) {
                fragmentManager.beginTransaction().replace(R.id.item_detail_container, fragment).addToBackStack(null).commit();
                v = (View) findViewById(R.id.content_frame);
                v.setVisibility(View.GONE);
            }
            else {
                fragmentManager.beginTransaction().replace(R.id.content_frame, fragment).addToBackStack(null).commit();
            }


        }
        else if (className.equals("InformationFragment")  ) {
            if (MainActivity.mTwoPane) {
                fragmentManager.beginTransaction().replace(R.id.item_detail_container, fragment).addToBackStack(null).commit();
                v = (View) findViewById(R.id.content_frame);
                v.setVisibility(View.GONE);
            }
            else {
                fragmentManager.beginTransaction().replace(R.id.content_frame, fragment).addToBackStack(null).commit();
            }

        }
        else if (className.equals("TwitterFragment")) {
            if (MainActivity.mTwoPane) {
                fragmentManager.beginTransaction().replace(R.id.item_detail_container,new WebViewFragment()).commit();
                fragmentManager.beginTransaction().replace(R.id.content_frame, fragment).addToBackStack(null).commit();
            }
            else {
                fragmentManager.beginTransaction().replace(R.id.content_frame, fragment).addToBackStack(null).commit();
            }

        }
        else if (className.equals("VideoFragment")) {
            if (MainActivity.mTwoPane) {
                fragmentManager.beginTransaction().replace(R.id.item_detail_container, new WebViewFragment()).addToBackStack(null).commit();
                fragmentManager.beginTransaction().replace(R.id.content_frame, fragment).addToBackStack(null).commit();
            }
            else {
                fragmentManager.beginTransaction().replace(R.id.content_frame, fragment).addToBackStack(null).commit();
            }
        }
        else {
            fragmentManager.beginTransaction().replace(R.id.content_frame, fragment).addToBackStack(null).commit();
        }

        drawerList.setItemChecked(position, true);

        tituloSeccion = options.get(position).getTitle();
        getSupportActionBar().setTitle(tituloSeccion);

        drawerLayout.closeDrawer(drawerList);
        MainActivity.displayedFragment = fragment;
    }

    @Override
    protected void onPostCreate(Bundle savedInstanceState) {
        super.onPostCreate(savedInstanceState);
        drawerToggle.syncState();
    }

    @Override
    public void onConfigurationChanged(Configuration newConfig) {
        super.onConfigurationChanged(newConfig);
        drawerToggle.onConfigurationChanged(newConfig);
    }

    @Override
    public boolean onPrepareOptionsMenu(Menu menu) {
        return super.onPrepareOptionsMenu(menu);
    }


    @Override
    public boolean onKeyDown(int keyCode, KeyEvent event) {
        if (keyCode == KeyEvent.KEYCODE_BACK) {
            if (getSupportFragmentManager().getBackStackEntryCount() == 0)  {
                this.finish();
                return false;
            }
            else if (getSupportFragmentManager().getBackStackEntryCount() == 1) {
                getSupportFragmentManager().popBackStack();;
                removeCurrentFragment();

                Fragment fragment = new HomeScreenFragment();
                FragmentManager fragmentManager = getSupportFragmentManager();
                fragmentManager.beginTransaction().replace(R.id.content_frame, fragment).addToBackStack(null).commit();
                MainActivity.displayedFragment = fragment;

                return false;
            }
            else {
                getSupportFragmentManager().popBackStack();
                removeCurrentFragment();

                return false;
            }
        }
        return super.onKeyDown(keyCode, event);
    }

    public void removeCurrentFragment()   {
        String fragName = "";
        FragmentTransaction transaction = getSupportFragmentManager().beginTransaction();
        Fragment currentFrag =  getSupportFragmentManager().findFragmentById(R.id.item_detail_container);

        if (currentFrag!=null) {
            fragName =  ((Object) currentFrag).getClass().getSimpleName();
            transaction.remove(currentFrag);
        }
        else {
            if (fragName.length()==0) {
                currentFrag =  getSupportFragmentManager().findFragmentById(R.id.content_frame);
                if (currentFrag!=null) {
                    fragName    =  ((Object) currentFrag).getClass().getSimpleName();
                    if (fragName.equals("HomeScreenFragment")) {
                        return;
                    }
                    this.setActionbar();
                }
            }
        }
        MainActivity.displayedFragment = currentFrag;
        transaction.commit();
    }


    private class FirstDownloadReceiver extends BroadcastReceiver {
        @Override
        public void onReceive(Context context, Intent intent) {
            MainActivity.this.removeFirstimeDialog();
        }
    }



}