package com.andreums.culturarocafort.activities.messages;

import android.content.Intent;
import android.os.Bundle;
import android.support.v7.app.ActionBar;
import android.support.v7.app.ActionBarActivity;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.AdapterView;
import android.widget.BaseAdapter;
import android.widget.ListView;
import android.widget.Toast;

import com.andreums.culturarocafort.R;
import com.andreums.culturarocafort.adapters.messages.GCMMessagesAdapter;
import com.andreums.culturarocafort.database.GCMDatabaseHandler;
import com.andreums.culturarocafort.models.GCMMessage;
import com.andreums.culturarocafort.util.DataStorage;

import java.util.ArrayList;

public class MessagesActivity extends ActionBarActivity {

    private ListView list;
    private GCMMessagesAdapter adapter;


    @Override
    public void onResume() {
        super.onResume();

        ArrayList<GCMMessage> messages = this.getMessagesFromDatabase();
        this.setItemsInListview(messages);
    }

    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.messages_list_activity);
        this.setActionBar();
        this.list = (ListView) findViewById(R.id.messages_list);
        this.list.setEmptyView(findViewById(R.id.messages_list_empty));

        ArrayList<GCMMessage> messages = this.getMessagesFromDatabase();
        this.setItemsInListview(messages);
    }


    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        getMenuInflater().inflate(R.menu.menu_messages, menu);
        return true;

    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        switch (item.getItemId()) {

            case android.R.id.home:
                this.finish();
                return true;


            case R.id.action_messages_clear:
                this.clearAllMessages();
                return true;

            case R.id.action_messages_readed:
                this.markAllMessagesAsReaded();
                return true;

            default:
                break;
        }

        return true;
    }

    private void clearAllMessages() {
        GCMDatabaseHandler handler = GCMDatabaseHandler.getInstance(getApplicationContext());
        handler.clearMessages();
        ArrayList<GCMMessage> messages = this.getMessagesFromDatabase();
        this.setItemsInListview(messages);
        ((BaseAdapter) this.list.getAdapter()).notifyDataSetChanged();

        Toast.makeText(getApplicationContext(),getResources().getString(R.string.messages_cleared),Toast.LENGTH_LONG).show();
    }

    private void markAllMessagesAsReaded() {
        GCMDatabaseHandler handler = GCMDatabaseHandler.getInstance(getApplicationContext());
        handler.markAllMessagesAsReaded();
        ((BaseAdapter) this.list.getAdapter()).notifyDataSetChanged();
        ArrayList<GCMMessage> messages = this.getMessagesFromDatabase();
        this.setItemsInListview(messages);
        Toast.makeText(getApplicationContext(),getResources().getString(R.string.messages_marked_as_readed),Toast.LENGTH_LONG).show();
    }

    @Override
    public void onStart() {
        super.onStart();

    }

    private ArrayList<GCMMessage> getMessagesFromDatabase() {
        GCMDatabaseHandler handler   = GCMDatabaseHandler.getInstance(getApplicationContext());
        ArrayList<GCMMessage> items  = handler.getMessages();
        return items;
    }


    private void setActionBar() {
        ActionBar bar = this.getSupportActionBar();
        getSupportActionBar().setIcon(R.drawable.ic_launcher);
        getSupportActionBar().setHomeButtonEnabled(true);
        getSupportActionBar().setDisplayHomeAsUpEnabled(true);
        bar.setTitle(getResources().getString(R.string.bar_messages));
    }

    private void setItemsInListview(final ArrayList<GCMMessage> messages) {


        this.list.setOnItemClickListener(
                new AdapterView.OnItemClickListener() {
                    @Override
                    public void onItemClick(AdapterView<?> adapterView, View view, int i, long l) {
                        GCMMessage item = (GCMMessage) MessagesActivity.this.list.getItemAtPosition(i);
                        if (item!=null) {
                            int id      = item.getId();
                            DataStorage.setGcmMessageToView(id);
                            Intent intent = new Intent(MessagesActivity.this.getApplicationContext(), MessageViewerActivity.class);

                            MessagesActivity.this.startActivity(intent);
                        }
                    }
                }
        );

        this.list.setOnLongClickListener(
                new View.OnLongClickListener() {
                    @Override
                    public boolean onLongClick(View v) {
                        return false;
                    }
                }
        );

        this.adapter = new GCMMessagesAdapter(getApplicationContext(), R.layout.message_item,messages);
        MessagesActivity.this.list.setAdapter(this.adapter);

    }





}