package com.andreums.culturarocafort.activities.photos;

import android.content.Intent;
import android.os.Bundle;
import android.support.v4.app.FragmentActivity;
import android.support.v4.view.ViewPager;
import android.support.v7.app.ActionBarActivity;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.AdapterView;
import android.widget.GridView;

import com.andreums.culturarocafort.R;
import com.andreums.culturarocafort.adapters.photos.FacebookPhotoAlbumsAdapter;
import com.andreums.culturarocafort.adapters.photos.PhotoGalleryViewerAdapter;
import com.andreums.culturarocafort.database.FacebookPhotosDatabaseHandler;
import com.andreums.culturarocafort.models.FacebookAlbum;
import com.andreums.culturarocafort.models.FacebookPhoto;



import org.apache.commons.lang3.StringEscapeUtils;

import java.util.ArrayList;

public class PhotoGalleryViewerActivity extends ActionBarActivity {


    private FacebookAlbum album;
    private ViewPager viewPager;
    private GridView grid;
    private PhotoGalleryViewerAdapter adapter;

    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);



        setContentView(R.layout.photo_gallery_activity);
        this.grid = (GridView) findViewById(R.id.gridview);

        String id                       = this.getIdFromIntent();
        ArrayList<FacebookPhoto> photos = this.getImages(id);
        this.album                      = this.getAlbum(id);

        this.setItemsInListview(photos);

        this.setActionbar();
    }


    private String getIdFromIntent() {
        String value  = "";
        Intent intent = getIntent();
        value         = intent.getStringExtra("id");
        return value;
    }

    private ArrayList<FacebookPhoto> getImages(String id) {
        ArrayList<FacebookPhoto> photos       = new ArrayList<FacebookPhoto>();
        FacebookPhotosDatabaseHandler handler = FacebookPhotosDatabaseHandler.getInstance(this.getApplicationContext());
        photos                                = handler.getAlbumPhotos(id);

        return photos;
    }

    private FacebookAlbum getAlbum(String id) {
        FacebookAlbum album                   = new FacebookAlbum();
        FacebookPhotosDatabaseHandler handler = FacebookPhotosDatabaseHandler.getInstance(this.getApplicationContext());
        album                                 = handler.getAlbum(id);

        return album;
    }

    private void setActionbar() {
        getSupportActionBar().setIcon(R.drawable.ic_launcher);
        getSupportActionBar().setHomeButtonEnabled(true);
        getSupportActionBar().setDisplayHomeAsUpEnabled(true);
        getSupportActionBar().setTitle(StringEscapeUtils.unescapeHtml4(this.album.getName()));
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        //getSupportMenuInflater().inflate(R.menu.menu_main, menu);
        return true;

    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        switch (item.getItemId()) {

            case android.R.id.home:
                this.finish();
                return true;

            default:
                break;
        }

        return true;
    }


    private void setItemsInListview(final ArrayList<FacebookPhoto> items) {
        this.grid.setOnItemClickListener(
                new AdapterView.OnItemClickListener() {
                    @Override
                    public void onItemClick(AdapterView<?> adapterView, View view, int i, long l) {
                        FacebookPhoto item = (FacebookPhoto) PhotoGalleryViewerActivity.this.grid.getItemAtPosition(i);
                        String id      = item.getAlbum_id();
                        int position   = i;

                        Intent intent = new Intent(PhotoGalleryViewerActivity.this.getApplicationContext(), PhotoViewerActivity.class);
                        intent.putExtra("image_position",position);
                        intent.putExtra("album_id",id);

                        startActivity(intent);
                    }
                }
        );

        FragmentActivity parentActivity = this;
        if(parentActivity != null) {
            parentActivity.runOnUiThread(new Runnable() {

                @Override
                public void run() {
                    PhotoGalleryViewerActivity.this.grid.setAdapter(new FacebookPhotoAlbumsAdapter(PhotoGalleryViewerActivity.this.getApplicationContext(), R.layout.photo_item,items));
                }

            });
        }
    }



}