package com.andreums.culturarocafort.activities.photos;

import android.content.Intent;
import android.os.Bundle;
import android.support.v4.view.ViewPager;
import android.support.v7.app.ActionBarActivity;
import android.view.GestureDetector;
import android.view.Menu;
import android.view.MenuItem;
import android.view.MotionEvent;
import android.view.View;
import android.widget.AdapterView;
import android.widget.Gallery;

import com.andreums.culturarocafort.R;
import com.andreums.culturarocafort.adapters.photos.GalleryImageAdapter;
import com.andreums.culturarocafort.adapters.photos.PhotoGalleryViewerAdapter;
import com.andreums.culturarocafort.database.FacebookPhotosDatabaseHandler;
import com.andreums.culturarocafort.models.FacebookAlbum;
import com.andreums.culturarocafort.models.FacebookPhoto;


import org.apache.commons.lang3.StringEscapeUtils;

import java.util.ArrayList;

public class PhotoViewerActivity extends ActionBarActivity implements GestureDetector.OnGestureListener {


    private FacebookAlbum album;
    private ViewPager viewPager;
    private PhotoGalleryViewerAdapter adapter;
    private Gallery gallery;

    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);


        setContentView(R.layout.photo_gallery_viewer_activity);
        this.viewPager = (ViewPager) findViewById(R.id.pager);


        String id                       = this.getIdFromIntent();
        int position                    = this.getPhotoPositionFromIntent();
        ArrayList<FacebookPhoto> photos = this.getImages(id);
        this.album                      = this.getAlbum(id);

        this.adapter = new PhotoGalleryViewerAdapter(this,photos);
        this.viewPager.setAdapter(this.adapter);
        this.viewPager.setCurrentItem(position);
        this.viewPager.setOffscreenPageLimit(2);

        this.gallery = (Gallery) findViewById(R.id.gallery);
        this.gallery.setAnimationDuration(750);
        this.gallery.setAdapter(new GalleryImageAdapter(this.getApplicationContext(), 0, photos));
        this.gallery.setSelection(position,true);

        this.gallery.setOnItemClickListener(new AdapterView.OnItemClickListener() {
            public void onItemClick(AdapterView<?> parent, View v, int position, long id) {
                PhotoViewerActivity.this.viewPager.setCurrentItem(position, true);
            }
        });


        this.gallery.setOnItemSelectedListener(
                new AdapterView.OnItemSelectedListener() {
                    @Override
                    public void onItemSelected(AdapterView<?> parent, View view, int position, long id) {
                        PhotoViewerActivity.this.viewPager.setCurrentItem(position);
                    }

                    @Override
                    public void onNothingSelected(AdapterView<?> parent) {}
                }
        );


        this.viewPager.setOnPageChangeListener(
                new ViewPager.OnPageChangeListener() {
                    @Override
                    public void onPageScrolled(int i, float v, int i2) {

                    }

                    @Override
                    public void onPageSelected(int i) {
                        PhotoViewerActivity.this.gallery.setSelection(i);
                    }

                    @Override
                    public void onPageScrollStateChanged(int i) {

                    }
                }
        );




        this.setActionbar();
    }

    private int getPhotoPositionFromIntent() {
        int value     = 0;
        Intent intent = getIntent();
        value         = intent.getIntExtra("image_position", 0);
        return value;

    }

    private String getIdFromIntent() {
        String value  = "";
        Intent intent = getIntent();
        value         = intent.getStringExtra("album_id");
        return value;
    }

    private ArrayList<FacebookPhoto> getImages(String id) {
        ArrayList<FacebookPhoto> photos       = new ArrayList<FacebookPhoto>();
        FacebookPhotosDatabaseHandler handler = FacebookPhotosDatabaseHandler.getInstance(this.getApplicationContext());
        photos                                = handler.getAlbumPhotos(id);

        return photos;
    }

    private FacebookAlbum getAlbum(String id) {
        FacebookAlbum album                   = new FacebookAlbum();
        FacebookPhotosDatabaseHandler handler = FacebookPhotosDatabaseHandler.getInstance(this.getApplicationContext());
        album                                 = handler.getAlbum(id);

        return album;
    }

    private void setActionbar() {
        getSupportActionBar().setIcon(R.drawable.ic_launcher);
        getSupportActionBar().setHomeButtonEnabled(true);
        getSupportActionBar().setDisplayHomeAsUpEnabled(true);
        getSupportActionBar().setTitle(StringEscapeUtils.unescapeHtml4(this.album.getName()));
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        //getSupportMenuInflater().inflate(R.menu.menu_main, menu);
        return true;

    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        switch (item.getItemId()) {

            case android.R.id.home:
                this.finish();
                return true;

            default:
                break;
        }

        return true;
    }


    @Override
    public boolean onDown(MotionEvent e) {
        return false;
    }

    @Override
    public void onShowPress(MotionEvent e) {

    }

    @Override
    public boolean onSingleTapUp(MotionEvent e) {
        return false;
    }

    @Override
    public boolean onScroll(MotionEvent e1, MotionEvent e2, float distanceX, float distanceY) {
        return false;
    }

    @Override
    public void onLongPress(MotionEvent e) {
    }

    @Override
    public boolean onFling(MotionEvent e1, MotionEvent e2, float velocityX, float velocityY) {
        return false;
    }
}