package com.andreums.culturarocafort.activities.settings;

import android.app.AlertDialog;
import android.app.ProgressDialog;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.DialogInterface;
import android.content.Intent;
import android.content.IntentFilter;
import android.content.SharedPreferences;
import android.content.pm.ActivityInfo;
import android.os.Bundle;
import android.support.v7.app.ActionBarActivity;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.RadioButton;
import android.widget.RadioGroup;
import android.widget.Toast;
import android.widget.ToggleButton;

import com.andreums.culturarocafort.R;
import com.andreums.culturarocafort.database.DatabaseHandler;
import com.andreums.culturarocafort.services.FirstTimeDownloaderService;
import com.andreums.culturarocafort.util.LocaleUtil;
import com.andreums.culturarocafort.util.Preferences;


import com.google.android.gcm.GCMRegistrar;

import java.util.Locale;

public class SettingsActivity extends ActionBarActivity {

    private ProgressDialog progressDialog;
    private ReloadDataBroadcastReceiver receiver;
    private static boolean hasChangedLocale;
    private static boolean isRegistered;
    private String currentLanguage;
    private boolean wasReloadingAfterLanguageChange;


    @Override
    public void onDestroy() {
        super.onDestroy();
        try {
            unregisterReceiver(this.receiver);
            this.receiver = null;
            SettingsActivity.isRegistered = false;
        }
        catch(Exception e) { }
    }


    @Override
    public void onStop() {
        super.onStop();
        try {
            unregisterReceiver(this.receiver);
            this.receiver = null;
            SettingsActivity.isRegistered = false;
        }
        catch(Exception e) { }
    }

    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.settings_activity);
        this.setActionbar();
        this.setInterface();
    }

    private void setInterface() {
        Preferences pref      = Preferences.getInstance(this.getApplicationContext());
        String language       = pref.getValue("language");

        this.currentLanguage = language;


        RadioButton ca = (RadioButton) findViewById(R.id.settings_radio_ca);
        RadioButton es = (RadioButton) findViewById(R.id.settings_radio_es);

        if (language.equals("ca")) {
            ca.setChecked(true);
        }
        if (language.equals("es")) {
            es.setChecked(true);
        }

        ToggleButton button = (ToggleButton) findViewById(R.id.settings_notification_button);
        if (this.isGCMRegistered()) {
            button.setChecked(true);
        }
        else {
            button.setChecked(false);
        }

    }

    private void setActionbar() {
        getSupportActionBar().setIcon(R.drawable.ic_launcher);
        getSupportActionBar().setTitle(getResources().getString(R.string.settings_title));
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        getMenuInflater().inflate(R.menu.menu_settings, menu);
        return true;

    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        switch (item.getItemId()) {

            case android.R.id.home:
                this.finish();
                return true;


            case R.id.action_save:
                this.saveSettings();
                break;


            default:
                break;
        }

        return true;
    }

    public void deleteContents(View v) {
        Preferences preferences = Preferences.getInstance(this.getApplicationContext());
        preferences.setValue("postsETag","false");
        preferences.setValue("eventsETag","false");
        preferences.setValue("categoriesETag","false");
        preferences.setValue("facebookPostsETag","false");
        preferences.setValue("facebookAlbumsETag","false");
        preferences.setValue("facebookPostsETag","false");
        preferences.setValue("videosETag","false");


        DatabaseHandler db = DatabaseHandler.getInstance(this.getApplicationContext());
        db.dropTables();
        db.createTables();



        Toast.makeText(getApplicationContext(),getResources().getString(R.string.settings_deleted),Toast.LENGTH_LONG).show();

    }

    public void reloadContents(View v) {

        setRequestedOrientation(ActivityInfo.SCREEN_ORIENTATION_NOSENSOR);

        this.progressDialog = ProgressDialog.show(this,getResources().getString(R.string.settings_dialog_title),getResources().getString(R.string.settings_dialog_content),true,false);

        DatabaseHandler db = DatabaseHandler.getInstance(this.getApplicationContext());
        db.dropTables();
        db.createTables();

        IntentFilter intentFilter = new IntentFilter("com.andreums.culturarocafort.downloaded.global");

        if ( (!SettingsActivity.isRegistered) && (this.receiver==null) ) {
            this.receiver   = new ReloadDataBroadcastReceiver();
            registerReceiver(this.receiver, intentFilter);
            SettingsActivity.isRegistered = true;
        }

        Intent intent = new Intent(this.getApplicationContext(), FirstTimeDownloaderService.class);
        this.startService(intent);



    }

    public void saveSettings() {
        String sLocale        = "";
        RadioGroup radioGroup = (RadioGroup) findViewById(R.id.settings_radio_group);
        Preferences pref      = Preferences.getInstance(this.getApplicationContext());
        String currentLanguage= pref.getValue("language");
        int id                = radioGroup.getCheckedRadioButtonId();

        if (id==R.id.settings_radio_ca) {
            Locale ca         = new Locale("ca");
            LocaleUtil locale = new LocaleUtil(this.getApplicationContext());
            locale.setDefaultLocale(ca);

            pref.setValue("language","ca");
            sLocale               = "ca";
        }
        if (id==R.id.settings_radio_es) {
            Locale es         = new Locale("es");
            LocaleUtil locale = new LocaleUtil(this.getApplicationContext());
            locale.setDefaultLocale(es);

            pref.setValue("language","es");
            sLocale               = "es";
        }

        if (!sLocale.equals("") && !sLocale.equals(this.currentLanguage)) {
            this.wasReloadingAfterLanguageChange = true;
            this.reloadContents(null);
        }
        else {
            this.showSavedSettingsDialog();
        }

    }

    private void showSavedSettingsDialog() {

        this.setLocale();

        AlertDialog alertDialog = new AlertDialog.Builder((SettingsActivity)this).create();
        alertDialog.setTitle(getResources().getString(R.string.settings_saved_title));
        alertDialog.setMessage(getResources().getString(R.string.settings_saved_message));
        alertDialog.setButton(getResources().getString(R.string.settings_saved_ok), new DialogInterface.OnClickListener() {
            public void onClick(DialogInterface dialog, int which) {
                finish();
            }
        });
        alertDialog.show();
    }

    public void cancel() {
        this.finish();
    }


    public class ReloadDataBroadcastReceiver extends BroadcastReceiver {

        @Override
        public void onReceive(Context context, Intent intent) {
            try {
                SettingsActivity.this.progressDialog.dismiss();
                setRequestedOrientation(ActivityInfo.SCREEN_ORIENTATION_SENSOR);
                if (SettingsActivity.hasChangedLocale) {
                    SettingsActivity.hasChangedLocale = false;
                    SettingsActivity.this.showSavedSettingsDialog();
                }
                if (SettingsActivity.this.wasReloadingAfterLanguageChange) {
                    SettingsActivity.this.wasReloadingAfterLanguageChange = false;
                    SettingsActivity.this.showSavedSettingsDialog();
                }
            }
            catch (Exception ex) { }
        }

    }


    private void setLocale() {
        Preferences preferences = Preferences.getInstance(getApplicationContext());
        String language         = preferences.getValue("language");
        if (language.length()==0){
            language = "ca";
        }
        Locale locale   = new Locale(language);
        LocaleUtil util = new LocaleUtil(getApplicationContext());
        util.setDefaultLocale(locale);
    }

    public void changeNotificationStatus(View v) {

        Preferences prefs = Preferences.getInstance(this.getApplicationContext());

        if (((ToggleButton) v).isChecked()) {

            if (!this.isGCMRegistered()) {

                String username = "culturaRocafort";
                String password = "culturaRocafort";
                String email    = "culturaRocafort";


                SharedPreferences preferences   = getSharedPreferences("registration_data",Context.MODE_PRIVATE);
                SharedPreferences.Editor editor = preferences.edit();
                editor.putString("username",username);
                editor.putString("password",password);
                editor.putString("email",email);
                editor.commit();
                GCMRegistrar.register(getApplicationContext(),"970923970258");


                prefs.setValueBoolean("notifications_enabled",true);
            }


        }
        else {
            final String regId = GCMRegistrar.getRegistrationId(getApplicationContext());
            if (!regId.equals("")) {
                GCMRegistrar.unregister(getApplicationContext());
            }
            prefs.setValueBoolean("notifications_enabled",false);

        }

    }

    private boolean isGCMRegistered() {
        return (!GCMRegistrar.getRegistrationId(getApplicationContext()).equals(""));
    }


}
