package com.andreums.culturarocafort.activities.video;

import android.content.Intent;
import android.os.AsyncTask;
import android.os.Bundle;
import android.util.Log;
import android.widget.TextView;
import android.widget.Toast;

import com.andreums.culturarocafort.Constants;
import com.andreums.culturarocafort.R;
import com.andreums.culturarocafort.database.VideosDatabaseHandler;
import com.andreums.culturarocafort.models.Video;
import com.andreums.culturarocafort.util.DataStorage;
import com.andreums.culturarocafort.util.DateUtils;
import com.andreums.culturarocafort.util.Downloader;
import com.google.android.youtube.player.YouTubeBaseActivity;
import com.google.android.youtube.player.YouTubeInitializationResult;
import com.google.android.youtube.player.YouTubePlayer;
import com.google.android.youtube.player.YouTubePlayer.ErrorReason;
import com.google.android.youtube.player.YouTubePlayer.PlaybackEventListener;
import com.google.android.youtube.player.YouTubePlayer.PlayerStateChangeListener;
import com.google.android.youtube.player.YouTubePlayer.Provider;
import com.google.android.youtube.player.YouTubePlayerView;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;


public class VideoPlayerActivity extends YouTubeBaseActivity implements YouTubePlayer.OnInitializedListener {

    private TextView videoViews;
    private TextView videoLikes;
    private TextView videoDislikes;
    private YouTubePlayerView youTubePlayerView;
    private YouTubePlayer player;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);

        setContentView(R.layout.activity_video);
        this.youTubePlayerView = (YouTubePlayerView) findViewById(R.id.youtube_view);
        this.youTubePlayerView.initialize(Constants.youtubeAPIKey, this);


        Video video = this.getVideoFromIntent();

        TextView title = (TextView) findViewById(R.id.video_title);
        title.setText(video.getTitle());

        TextView description = (TextView) findViewById(R.id.video_description);
        description.setText(video.getDescription());

        TextView published = (TextView) findViewById(R.id.video_date);
        published.setText(DateUtils.convertToNotificationDate(video.getPublished()));

        this.videoViews = (TextView) findViewById(R.id.video_views);
        this.videoLikes = (TextView) findViewById(R.id.video_likes);
        this.videoDislikes = (TextView) findViewById(R.id.video_dislikes);

        new GetVideoInformationTask().execute(video.getId());

    }

	@Override
	public void onInitializationFailure(Provider provider, YouTubeInitializationResult result) {
		Toast.makeText(this, "Failured to Initialize!", Toast.LENGTH_LONG).show();
	}

	@Override
	public void onInitializationSuccess(Provider provider, YouTubePlayer player, boolean wasRestored) {

        this.player = player;

		player.setPlayerStateChangeListener(playerStateChangeListener);
		player.setPlaybackEventListener(playbackEventListener);

		if (!wasRestored) {
            Video video = DataStorage.getVideo();
			player.cueVideo(video.getId());
		}
	}

	private PlaybackEventListener playbackEventListener = new PlaybackEventListener() {

		@Override
		public void onBuffering(boolean arg0) {

		}

		@Override
		public void onPaused() {

		}

		@Override
		public void onPlaying() {

		}

		@Override
		public void onSeekTo(int arg0) {

		}

		@Override
		public void onStopped() {

		}

	};

	private PlayerStateChangeListener playerStateChangeListener = new PlayerStateChangeListener() {

		@Override
		public void onAdStarted() {

		}

		@Override
		public void onError(ErrorReason arg0) {

		}

		@Override
		public void onLoaded(String arg0) {

		}

		@Override
		public void onLoading() {
		}

		@Override
		public void onVideoEnded() {

		}

		@Override
		public void onVideoStarted() {

		}
	};


    private void updateVideoStats(JSONObject result) {
        try {
            JSONArray item        = result.getJSONArray("items");
            if (item.length()>0) {
                JSONObject statistics = item.getJSONObject(0).getJSONObject("statistics");

                this.videoViews.setText(statistics.getString("viewCount") + " visitas");
                this.videoLikes.setText(statistics.getString("likeCount") + " likes");
                this.videoDislikes.setText(statistics.getString("dislikeCount") + " dislikes");
            }
        }
        catch (JSONException e) {
            e.printStackTrace();
        }
    }

    public Video getVideoFromIntent() {
        Intent intent   = this.getIntent();
        String id       = intent.getStringExtra("videoID");

        VideosDatabaseHandler handler = VideosDatabaseHandler.getInstance(this.getApplicationContext());
        return handler.getVideo(id);
    }


    private class GetVideoInformationTask extends AsyncTask<String, Void, JSONObject> {

        @Override
        protected JSONObject doInBackground(String... params) {
            String result   = "";
            String url      = Constants.youtubeVideoInfoURL;
            url             = url.replace("VIDEO_ID",params[0]);
            Downloader downloader = new Downloader(url);
            downloader.invoke();
            result          = downloader.getResult();

            try {
                JSONObject object = new JSONObject(result);
                return object;
            }
            catch (JSONException e) {
                e.printStackTrace();
            }
            return null;
        }

        @Override
        protected void onPreExecute() {
            super.onPreExecute();

        }

        @Override
        protected void onPostExecute(JSONObject result) {
            VideoPlayerActivity.this.updateVideoStats(result);
        }
    }

}