package com.andreums.culturarocafort.adapters.events;

import android.content.Context;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ArrayAdapter;
import android.widget.ImageView;
import android.widget.TextView;

import com.andreums.culturarocafort.R;
import com.andreums.culturarocafort.models.Event;
import com.andreums.culturarocafort.util.DateUtils;
import com.andreums.culturarocafort.util.LocaleUtil;
import com.andreums.culturarocafort.views.events.EventHeaderView;
import com.andreums.culturarocafort.views.events.EventItemView;
import com.andreums.culturarocafort.views.events.IListViewItem;
import com.squareup.picasso.Picasso;

import org.apache.commons.lang3.StringEscapeUtils;

import java.util.ArrayList;

public class EventsAdapter extends ArrayAdapter<IListViewItem> {

    private ArrayList<IListViewItem> objects = new ArrayList<IListViewItem>();
    private LocaleUtil localeUtil;

    public EventsAdapter(Context itemListFragment, int textviewid, ArrayList<IListViewItem> objects) {
        super(itemListFragment, textviewid, objects);
        this.objects        = objects;
        this.localeUtil     = new LocaleUtil(itemListFragment);
    }

    @Override
    public int getViewTypeCount() {
        return 2;
    }




    @Override
    public int getCount() {
        return ((null != objects) ? objects.size() : 0);
    }

    @Override
    public long getItemId(int position) {
        return position;
    }

    @Override
    public int getItemViewType(int position) {
        return this.getItem(position).getViewType();
    }

    @Override
    public IListViewItem getItem(int position) {
        return ((null != this.objects) ? this.objects.get(position) : null);
    }

    public View getView(int position, View convertView, ViewGroup parent) {
        int type                = this.getItemViewType(position);
        LayoutInflater inflater = (LayoutInflater) getContext().getSystemService(Context.LAYOUT_INFLATER_SERVICE);

        if (type==0) {
            View view;
            EventViewHolder holder;
            EventItemView idata     = (EventItemView) this.getItem(position);
            Event   data            = idata.getEvent();

            if (convertView==null) {
                view                = inflater.inflate(R.layout.event_list_item, null);

                holder = new EventViewHolder();
                holder.title = (TextView) view.findViewById(R.id.event_title);
                holder.date  = (TextView) view.findViewById(R.id.event_date);
                holder.venue = (TextView) view.findViewById(R.id.event_venue);
                holder.image = (ImageView) view.findViewById(R.id.event_image);

                view.setTag(holder);
            }

            else {
                holder = (EventViewHolder) convertView.getTag();
                view   = convertView;
            }

            if (data!=null) {
                if (data.getThumbnail()!=null && data.getThumbnail().length()>0) {
                    Picasso.with(this.getContext()).load(data.getThumbnail()).resize(150,150).placeholder(R.drawable.ic_launcher).error(R.drawable.ic_launcher).into(holder.image);
                }
                holder.title.setText(StringEscapeUtils.unescapeHtml4(data.getTitle()));
                holder.date.setText(DateUtils.convertToEventDate(data.getStart_date()));
                holder.venue.setText(StringEscapeUtils.unescapeHtml4(data.getVenue()));
            }
            return view;

        }

        if (type==1) {
            View view;
            String locale           = this.localeUtil.getLocale();
            EventHeaderView  idata  = (EventHeaderView) this.getItem(position);
            String   date           = idata.getShownDate();
            //date                    = date.toLowerCase();

            if (locale.equals("ca")) {
                date = date.replace("lunes","dilluns").replace("martes","dimarts").replace("miércoles","dimecres").replace("jueves","dijous").replace("viernes","divendres").replace("sábado","dissabte").replace("domingo","diumenge");
            }
            HeaderViewHolder holder;
            if (convertView==null) {
                view          = inflater.inflate(R.layout.header, null);
                holder        = new HeaderViewHolder();
                holder.header = (TextView) view.findViewById(R.id.header_text);

                view.setTag(holder);
            }
            else {
                holder        = (HeaderViewHolder) convertView.getTag();
                view          = convertView;
            }
            holder.header.setText(date);

            return view;
        }
        return convertView;
    }


    private static class EventViewHolder {
        TextView title;
        TextView date;
        TextView venue;
        ImageView image;
    }


    private static class HeaderViewHolder {
        TextView header;
    }



}