package com.andreums.culturarocafort.adapters.events;

import android.content.Context;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ArrayAdapter;
import android.widget.ImageView;
import android.widget.TextView;

import com.andreums.culturarocafort.R;
import com.andreums.culturarocafort.models.Event;
import com.andreums.culturarocafort.util.DateUtils;
import com.squareup.picasso.Picasso;

import org.apache.commons.lang3.StringEscapeUtils;

import java.util.ArrayList;

public class SpecialEventsAdapter extends ArrayAdapter<Event> {


    private ArrayList<Event> objects = new ArrayList<Event>();



    public SpecialEventsAdapter(Context itemListFragment, int textviewid, ArrayList<Event> objects) {
        super(itemListFragment, textviewid, objects);
        this.objects        = objects;
    }


    @Override
    public int getCount() {
        return ((null != objects) ? objects.size() : 0);
    }

    @Override
    public long getItemId(int position) {
        return position;
    }

    @Override
    public Event getItem(int position) {
        return ((null != this.objects) ? this.objects.get(position) : null);
    }

    @Override
    public View getView(int position, View view, ViewGroup parent) {
        ViewHolder holder;
        Event data              = this.getItem(position);

        if (view==null) {
            LayoutInflater inflater = (LayoutInflater) getContext().getSystemService(Context.LAYOUT_INFLATER_SERVICE);
            view                    = inflater.inflate(R.layout.special_event_item, null);

            holder = new ViewHolder();
            holder.title = (TextView) view.findViewById(R.id.event_title);
            holder.date  = (TextView) view.findViewById(R.id.event_date);
            holder.venue = (TextView) view.findViewById(R.id.event_venue);
            holder.image = (ImageView) view.findViewById(R.id.event_image);

            view.setTag(holder);
        }

        else {
            holder = (ViewHolder) view.getTag();
        }

        if (data!=null) {

            if (data.getImage()!=null && data.getImage().length()>0) {
                Picasso.with(this.getContext()).load(data.getImage()).placeholder(R.drawable.ic_launcher).error(R.drawable.ic_launcher).into(holder.image);
            }
            holder.title.setText(StringEscapeUtils.unescapeHtml4(data.getTitle()));
            holder.date.setText(DateUtils.convertToEventDate(data.getStart_date()));
            holder.venue.setText(StringEscapeUtils.unescapeHtml4(data.getVenue()));

        }
        return view;
    }


    private static class ViewHolder {
        TextView title;
        TextView date;
        TextView venue;
        ImageView image;
    }

}