package com.andreums.culturarocafort.adapters.facebook;

import android.content.Context;
import android.content.Intent;
import android.net.Uri;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ArrayAdapter;
import android.widget.ImageView;
import android.widget.TextView;

import com.andreums.culturarocafort.R;
import com.andreums.culturarocafort.models.FacebookPost;
import com.andreums.culturarocafort.util.DateUtils;
import com.andreums.culturarocafort.views.facebook.FacebookLinkView;
import com.andreums.culturarocafort.views.facebook.FacebookPictureView;
import com.andreums.culturarocafort.views.facebook.FacebookStatusView;
import com.andreums.culturarocafort.views.facebook.FacebookVideoView;
import com.andreums.culturarocafort.views.facebook.IListFacebookPostViewItem;
import com.squareup.picasso.Picasso;

import org.apache.commons.lang3.StringEscapeUtils;

import java.util.ArrayList;

public class FacebookPostsAdapter extends ArrayAdapter<IListFacebookPostViewItem> {
    private ArrayList<IListFacebookPostViewItem> objects = new ArrayList<IListFacebookPostViewItem>();


    public FacebookPostsAdapter(Context itemListFragment, int textviewid, ArrayList<IListFacebookPostViewItem> objects) {
        super(itemListFragment, textviewid, objects);
        this.objects = objects;
    }

    @Override
    public int getCount() {
        return ((null != objects) ? objects.size() : 0);
    }

    @Override
    public int getViewTypeCount() {
        return 4;
    }

    @Override
    public long getItemId(int position) {
        return position;
    }

    @Override
    public int getItemViewType(int position) {
        return this.getItem(position).getViewType();
    }

    @Override
    public IListFacebookPostViewItem getItem(int position) {
        return ((null != objects) ? objects.get(position) : null);
    }

    public View getView(int position, View convertView, ViewGroup parent) {
        int type                = this.getItemViewType(position);
        LayoutInflater inflater = (LayoutInflater) getContext().getSystemService(Context.LAYOUT_INFLATER_SERVICE);

        if (type==0) {
            View view;
            FacebookStatusViewHolder holder;
            FacebookStatusView idata = (FacebookStatusView) this.getItem(position);
            FacebookPost post        = idata.getPost();


            if (convertView==null) {
                view                = inflater.inflate(R.layout.facebook_item_status, null);

                holder = new FacebookStatusViewHolder();
                holder.message = (TextView) view.findViewById(R.id.facebook_item_text);
                holder.image   = (ImageView) view.findViewById(R.id.facebook_item_image);
                holder.date    = (TextView) view.findViewById(R.id.facebook_item_published);
                view.setTag(holder);
            }

            else {
                holder = (FacebookStatusViewHolder) convertView.getTag();
                view   = convertView;
            }

            if (post!=null) {
                String thumbanail = post.getThumbnail();
                if (thumbanail.length()>0) {
                    Picasso.with(this.getContext()).load(thumbanail).placeholder(R.drawable.ic_launcher).error(R.drawable.ic_launcher).into(holder.image);
                }
                holder.message.setText(StringEscapeUtils.unescapeHtml4(post.getMessage()));
                holder.date.setText(DateUtils.convertToPostDate(post.getPublished()));
            }
            return view;
        }

        if (type==1) {
            View view;
            FacebookPhotoViewHolder holder;
            FacebookPictureView idata = (FacebookPictureView) this.getItem(position);
            FacebookPost post        = idata.getPost();


            if (convertView==null) {
                view                = inflater.inflate(R.layout.facebook_item_picture, null);

                holder = new FacebookPhotoViewHolder();
                holder.message = (TextView) view.findViewById(R.id.facebook_item_text);
                holder.image   = (ImageView) view.findViewById(R.id.facebook_item_image);
                holder.date    = (TextView) view.findViewById(R.id.facebook_item_published);
                view.setTag(holder);
            }

            else {
                holder = (FacebookPhotoViewHolder) convertView.getTag();
                view   = convertView;
            }

            if (post!=null) {
                String image = post.getImage();
                if (image.length()>0) {
                    Picasso.with(this.getContext()).load(image).placeholder(R.drawable.ic_launcher).error(R.drawable.ic_launcher).into(holder.image);
                }
                holder.message.setText(StringEscapeUtils.unescapeHtml4(post.getMessage()));
                holder.date.setText(DateUtils.convertToPostDate(post.getPublished()));
            }
            return view;
        }

        if (type==2) {
            View view;
            FacebookLinkViewHolder holder;
            FacebookLinkView idata = (FacebookLinkView) this.getItem(position);
            FacebookPost post        = idata.getPost();


            if (convertView==null) {
                view                = inflater.inflate(R.layout.facebook_item_link, null);

                holder = new FacebookLinkViewHolder();
                holder.link    = (TextView) view.findViewById(R.id.facebook_item_link);
                holder.message = (TextView) view.findViewById(R.id.facebook_item_name);
                holder.image   = (ImageView) view.findViewById(R.id.facebook_item_image);
                holder.date    = (TextView) view.findViewById(R.id.facebook_item_published);
                view.setTag(holder);
            }

            else {
                holder = (FacebookLinkViewHolder) convertView.getTag();
                view   = convertView;
            }

            if (post!=null) {
                String image = post.getImage();
                if (image.length()>0) {
                    Picasso.with(this.getContext()).load(image).placeholder(R.drawable.ic_launcher).error(R.drawable.ic_launcher).into(holder.image);
                }
                holder.link.setText(post.getMessage());
                holder.message.setText(StringEscapeUtils.unescapeHtml4(post.getName()));
                holder.date.setText(DateUtils.convertToPostDate(post.getPublished()));
            }
            return view;
        }

        if (type==3) {
            View view;
            FacebookVideoViewHolder holder;
            FacebookVideoView idata = (FacebookVideoView) this.getItem(position);
            final FacebookPost post        = idata.getPost();


            if (convertView==null) {
                view                = inflater.inflate(R.layout.facebook_item_video, null);

                holder = new FacebookVideoViewHolder();
                holder.message = (TextView) view.findViewById(R.id.facebook_item_text);
                holder.image   = (ImageView) view.findViewById(R.id.facebook_item_image);
                holder.date    = (TextView) view.findViewById(R.id.facebook_item_published);
                view.setTag(holder);
            }

            else {
                holder = (FacebookVideoViewHolder) convertView.getTag();
                view   = convertView;
            }

            if (post!=null) {
                String image = post.getImage();
                holder.image.setAlpha(80);
                if (image.length()>0) {
                    Picasso.with(this.getContext()).load(image).placeholder(R.drawable.ic_launcher).error(R.drawable.ic_launcher).into(holder.image);
                }
                holder.image.setAlpha(80);
                holder.message.setText(StringEscapeUtils.unescapeHtml4(post.getMessage()));
                holder.date.setText(DateUtils.convertToPostDate(post.getPublished()));

                holder.image.setOnClickListener(new View.OnClickListener() {
                    @Override
                    public void onClick(View v) {
                        Intent videoClient = new Intent(Intent.ACTION_VIEW);
                        videoClient.setData(Uri.parse(post.getLink()));
                        FacebookPostsAdapter.this.getContext().startActivity(videoClient);
                    }
                });
            }
            return view;
        }




        return convertView;
    }

    private static class FacebookStatusViewHolder {
        TextView message;
        ImageView image;
        TextView date;
    }

    private static class FacebookLinkViewHolder {
        TextView message;
        ImageView image;
        TextView description;
        TextView date;
        TextView link;
    }

    private static class FacebookPhotoViewHolder {
        TextView message;
        ImageView image;
        TextView caption;
        TextView date;
    }

    private static class FacebookVideoViewHolder {
        TextView message;
        ImageView image;
        TextView caption;
        TextView date;
    }




}