package com.andreums.culturarocafort.adapters.messages;

import android.content.Context;
import android.graphics.Color;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ArrayAdapter;
import android.widget.ImageView;
import android.widget.TextView;

import com.andreums.culturarocafort.R;
import com.andreums.culturarocafort.models.GCMMessage;
import com.andreums.culturarocafort.util.DateUtils;

import org.apache.commons.lang3.StringEscapeUtils;

import java.util.ArrayList;

public class GCMMessagesAdapter extends ArrayAdapter<GCMMessage> {
    private ArrayList<GCMMessage> objects = new ArrayList<GCMMessage>();


    public GCMMessagesAdapter(Context itemListFragment, int textviewid, ArrayList<GCMMessage> objects) {
        super(itemListFragment, textviewid, objects);
        this.objects = objects;
    }

    @Override
    public int getCount() {
        return ((null != objects) ? objects.size() : 0);
    }

    @Override
    public long getItemId(int position) {
        return position;
    }

    @Override
    public GCMMessage getItem(int position) {
        return ((null != objects) ? objects.get(position) : null);
    }

    public View getView(int position, View view, ViewGroup parent) {
        ViewHolder holder;
        final GCMMessage message = objects.get(position);

        if (view==null) {
            LayoutInflater vi = (LayoutInflater) getContext().getSystemService(Context.LAYOUT_INFLATER_SERVICE);
            view = vi.inflate(R.layout.message_item,null);

            view.setContentDescription(StringEscapeUtils.unescapeHtml4(message.getTitle()));

            holder          = new ViewHolder();
            holder.title    = (TextView) view.findViewById(R.id.message_title);
            holder.received = (TextView) view.findViewById(R.id.message_date);
            holder.text     = (TextView) view.findViewById(R.id.message_text);
            holder.image    = (ImageView) view.findViewById(R.id.message_image);
            view.setTag(holder);

        }
        else {
            holder = (ViewHolder) view.getTag();
        }


        if (message!=null) {
            holder.title.setText(StringEscapeUtils.unescapeHtml4(message.getTitle()));
            holder.title.setContentDescription(StringEscapeUtils.unescapeHtml4(message.getTitle()));
            holder.received.setText(DateUtils.convertToEventDate(message.getReceived()));
            holder.text.setText(StringEscapeUtils.unescapeHtml4(message.getMessage()));


            if (!message.getReaded()) {
                holder.image.setImageDrawable(this.getContext().getResources().getDrawable(R.drawable.message_indicator_closed));
                holder.title.setTextAppearance(getContext(),R.style.boldText);
                holder.received.setTextColor(Color.parseColor("#000000"));
                holder.text.setTextColor(Color.parseColor("#000000"));
            }
            else {
                holder.title.setTextAppearance(getContext(),R.style.normalText);
            }
        }
        return view;
    }



    private static class ViewHolder {
        private TextView title;
        private TextView received;
        private TextView text;
        private ImageView image;
    }

}