package com.andreums.culturarocafort.adapters.photos;

import android.content.Context;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ArrayAdapter;
import android.widget.ImageView;
import android.widget.TextView;

import com.andreums.culturarocafort.R;
import com.andreums.culturarocafort.database.FacebookPhotosDatabaseHandler;
import com.andreums.culturarocafort.models.FacebookAlbum;
import com.andreums.culturarocafort.models.FacebookPhoto;
import com.squareup.picasso.Picasso;

import org.apache.commons.lang3.StringEscapeUtils;

import java.util.ArrayList;

public class FacebookAlbumAdapter extends ArrayAdapter<FacebookAlbum> {

    private Context context;

    private ArrayList<FacebookAlbum> objects = new ArrayList<FacebookAlbum>();


    public FacebookAlbumAdapter(Context itemListFragment, int textviewid, ArrayList<FacebookAlbum> objects) {
        super(itemListFragment, textviewid, objects);
        this.objects = objects;
        this.context = itemListFragment;
    }


    public int getCount() {
        return this.objects.size();
    }


    public FacebookAlbum getItem(int position) {
        return this.objects.get(position);
    }

    public long getItemId(int position) {
        return position;
    }

    public View getView(int position, View view, ViewGroup parent) {

        ViewHolder holder;
        String url          = "";
        FacebookAlbum album = this.getItem(position);


        FacebookPhotosDatabaseHandler handler = FacebookPhotosDatabaseHandler.getInstance(getContext());
        FacebookPhoto img                     = handler.getPhoto(album.getCover());
        if (img!=null) {
            url = img.getImage();
        }


        if (view==null) {
            LayoutInflater vi = (LayoutInflater) getContext().getSystemService(Context.LAYOUT_INFLATER_SERVICE);
            view              = vi.inflate(R.layout.album_item,null);

            holder            = new ViewHolder();
            holder.title      = (TextView) view.findViewById(R.id.album_title);
            holder.image      = (ImageView) view.findViewById(R.id.album_image);
            holder.count      = (TextView) view.findViewById(R.id.album_photos_count);

            view.setTag(holder);
        }
        else {
            holder = (ViewHolder) view.getTag();
        }
        holder.title.setText(StringEscapeUtils.unescapeHtml4(album.getName()));
        holder.count.setText(album.getCount()+" fotos");
        if ( (url!=null) && (url.length()>0) ) {
            Picasso.with(this.getContext()).load(url).placeholder(R.drawable.ic_launcher).resize(150,150).error(R.drawable.ic_launcher).into(holder.image);
        }
        return view;
    }


    private static class ViewHolder {
        TextView title;
        TextView date;
        TextView count;
        ImageView image;

    }
}