package com.andreums.culturarocafort.adapters.photos;

import android.content.Context;
import android.content.Intent;
import android.graphics.Bitmap;
import android.support.v4.view.PagerAdapter;
import android.support.v4.view.ViewPager;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;
import android.widget.RelativeLayout;
import android.widget.TextView;

import com.andreums.culturarocafort.R;
import com.andreums.culturarocafort.activities.photos.ImageViewerActivity;
import com.andreums.culturarocafort.models.FacebookPhoto;
import com.andreums.culturarocafort.util.DateUtils;
import com.squareup.picasso.Picasso;
import com.squareup.picasso.Transformation;

import java.util.ArrayList;

public class PhotoGalleryViewerAdapter extends PagerAdapter {

    Context context;
    LayoutInflater inflater;
    ArrayList<FacebookPhoto> photos;
 
    public PhotoGalleryViewerAdapter(Context context, ArrayList<FacebookPhoto> photos) {
        this.context = context;
        this.photos  = photos;
    }
 
    @Override
    public int getCount() {
        return this.photos.size();
    }
 
    @Override
    public boolean isViewFromObject(View view, Object object) {
        return view == ((RelativeLayout) object);
    }
 
    @Override
    public Object instantiateItem(ViewGroup container, int position) {

        TextView    title;
        TextView    date;
        TextView    description;
        final ImageView   image;

        inflater = (LayoutInflater) context.getSystemService(Context.LAYOUT_INFLATER_SERVICE);
        View itemView = inflater.inflate(R.layout.photo_gallery_item, container,false);

        final FacebookPhoto photo = this.photos.get(position);
        if (photo!=null) {

            // Locate the TextViews in viewpager_item.xml
            title       = (TextView) itemView.findViewById(R.id.gallery_title);
            date        = (TextView) itemView.findViewById(R.id.gallery_date);
            image       = (ImageView) itemView.findViewById(R.id.gallery_image);


            title.setText(photo.getName());
            date.setText(DateUtils.convertToEventDate(photo.getCreated_time()));

            if (photo.getImage()!=null && photo.getImage().length()>0) {

                Transformation transformation = new Transformation() {

                    @Override public Bitmap transform(Bitmap source) {
                        int targetWidth     = 720;
                        double aspectRatio  = (double) source.getHeight() / (double) source.getWidth();
                        int targetHeight    = (int) (targetWidth * aspectRatio);
                        Bitmap result       = Bitmap.createScaledBitmap(source, targetWidth, targetHeight, false);
                        if (result != source) {
                            source.recycle();
                        }
                        return result;
                    }

                    @Override public String key() {
                        return "transformation" + " desiredWidth";
                    }
                };

                Picasso.with(this.context).load(photo.getImage()).placeholder(R.drawable.ic_launcher).error(R.drawable.ic_launcher).transform(transformation).into(image);
            }

            image.setTag(photo.getImage());
            image.setOnClickListener( new View.OnClickListener() {
                @Override
                public void onClick(View v) {
                    Intent intent = new Intent(PhotoGalleryViewerAdapter.this.context, ImageViewerActivity.class);
                    intent.putExtra("url",(String) v.getTag());
                    intent.setFlags(Intent.FLAG_ACTIVITY_MULTIPLE_TASK);
                    intent.setFlags(Intent.FLAG_ACTIVITY_NEW_TASK);
                    PhotoGalleryViewerAdapter.this.context.startActivity(intent);
                }
            });

            ((ViewPager) container).addView(itemView);
        }
 
        return itemView;
    }
 
    @Override
    public void destroyItem(ViewGroup container, int position, Object object) {
        ((ViewPager) container).removeView((RelativeLayout) object);
    }
}