package com.andreums.culturarocafort.adapters.posts;

import android.content.Context;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ArrayAdapter;
import android.widget.ImageView;
import android.widget.RelativeLayout;
import android.widget.TextView;

import com.andreums.culturarocafort.R;
import com.andreums.culturarocafort.models.Post;
import com.andreums.culturarocafort.util.DateUtils;
import com.squareup.picasso.Picasso;

import org.apache.commons.lang3.StringEscapeUtils;

import java.util.ArrayList;

public class PostsAdapter extends ArrayAdapter<Post> {
    private ArrayList<Post> objects = new ArrayList<Post>();


    public PostsAdapter(Context itemListFragment, int textviewid, ArrayList<Post> objects) {
        super(itemListFragment, textviewid, objects);
        this.objects = objects;
    }

    @Override
    public int getCount() {
        return ((null != objects) ? objects.size() : 0);
    }

    @Override
    public long getItemId(int position) {
        return position;
    }

    @Override
    public Post getItem(int position) {
        return ((null != objects) ? objects.get(position) : null);
    }

    public View getView(int position, View view, ViewGroup parent) {
        ViewHolder holder;
        final Post post = objects.get(position);

        if (view==null) {
            LayoutInflater vi = (LayoutInflater) getContext().getSystemService(Context.LAYOUT_INFLATER_SERVICE);
            view = vi.inflate(R.layout.post_item,null);

            view.setContentDescription(StringEscapeUtils.unescapeHtml4(post.getTitle()));

            holder        = new ViewHolder();
            holder.title  = (TextView) view.findViewById(R.id.blog_title);
            holder.date   = (TextView) view.findViewById(R.id.blog_date);
            holder.image  = (ImageView) view.findViewById(R.id.blog_image);
            holder.layout = (RelativeLayout) view.findViewById(R.id.post_item_wrapper);

            view.setTag(holder);

        }
        else {
            holder = (ViewHolder) view.getTag();
        }


        if (post!=null) {
            holder.title.setText(StringEscapeUtils.unescapeHtml4(post.getTitle()));
            holder.title.setContentDescription(StringEscapeUtils.unescapeHtml4(post.getTitle()));

            holder.date.setText(DateUtils.convertToEventDate(post.getDate()));
            if (post.getThumbnail()!=null) {
                Picasso.with(this.getContext()).load(post.getThumbnail()).placeholder(R.drawable.ic_launcher).resize(150,150).error(R.drawable.ic_launcher).into(holder.image);
            }
            holder.image.setContentDescription(StringEscapeUtils.unescapeHtml4(post.getTitle()));
        }
        return view;
    }



    private static class ViewHolder {
        TextView title;
        TextView date;
        ImageView image;
        public RelativeLayout layout;
    }

}