package com.andreums.culturarocafort.adapters.twitter;

import android.content.Context;
import android.content.Intent;
import android.net.Uri;
import android.text.Layout;
import android.text.Spannable;
import android.text.method.MovementMethod;
import android.text.style.ClickableSpan;
import android.text.style.URLSpan;
import android.view.KeyEvent;
import android.view.LayoutInflater;
import android.view.MotionEvent;
import android.view.View;
import android.view.ViewGroup;
import android.webkit.WebView;
import android.webkit.WebViewClient;
import android.widget.ArrayAdapter;
import android.widget.ImageView;
import android.widget.TextView;

import com.andreums.culturarocafort.MainActivity;
import com.andreums.culturarocafort.R;
import com.andreums.culturarocafort.fragments.other.WebViewFragment;
import com.squareup.picasso.Picasso;

import org.apache.commons.lang3.StringEscapeUtils;

import java.util.ArrayList;

import twitter4j.MediaEntity;
import twitter4j.Status;

public class TwitterAdapter extends ArrayAdapter<Status> {

    private View auxView;
    private ArrayList<Status> objects = new ArrayList<Status>();


    public TwitterAdapter(Context itemListFragment, int textviewid, ArrayList<Status> objects) {
        super(itemListFragment, textviewid, objects);
        this.objects = objects;
    }

    @Override
    public int getCount() {
        return ((null != objects) ? objects.size() : 0);
    }

    @Override
    public long getItemId(int position) {
        return position;
    }

    @Override
    public Status getItem(int position) {
        return ((null != objects) ? objects.get(position) : null);
    }

    public View getView(int position, View view, ViewGroup parent) {
        ViewHolder holder;
        Status post = objects.get(position);


        if (view==null) {
            LayoutInflater vi = (LayoutInflater) getContext().getSystemService(Context.LAYOUT_INFLATER_SERVICE);
            view = vi.inflate(R.layout.tweet_item,null);
            this.auxView = view;

            holder = new ViewHolder();
            holder.title = (TextView) view.findViewById(R.id.tweet_user);
            holder.text  = (TextView) view.findViewById(R.id.tweet_text);
            holder.date  = (TextView) view.findViewById(R.id.tweet_date);
            holder.image = (ImageView) view.findViewById(R.id.tweet_media_image);
            holder.icon  = (ImageView) view.findViewById(R.id.tweet_image);

            view.setTag(holder);

        }
        else {
            holder = (ViewHolder) view.getTag();
        }

        if (post!=null) {
            holder.title.setText(StringEscapeUtils.unescapeHtml4(post.getUser().getScreenName()));
            holder.text.setText(StringEscapeUtils.unescapeHtml4(post.getText()));
            holder.date.setText(StringEscapeUtils.unescapeHtml4(post.getCreatedAt().toString()));

            holder.text.setMovementMethod(new MovementMethod() {
                @Override
                public void initialize(TextView widget, Spannable text) {

                }

                @Override
                public boolean onKeyDown(TextView widget, Spannable text, int keyCode, KeyEvent event) {
                    return false;
                }

                @Override
                public boolean onKeyUp(TextView widget, Spannable text, int keyCode, KeyEvent event) {
                    return false;
                }

                @Override
                public boolean onKeyOther(TextView view, Spannable text, KeyEvent event) {
                    return false;
                }

                @Override
                public void onTakeFocus(TextView widget, Spannable text, int direction) {

                }

                @Override
                public boolean onTrackballEvent(TextView widget, Spannable text, MotionEvent event) {
                    return false;
                }

                @Override
                public boolean onTouchEvent(TextView widget, Spannable buffer, MotionEvent event) {
                    final int action = event.getAction();
                    if (action == MotionEvent.ACTION_UP || action == MotionEvent.ACTION_DOWN) {
                        final int x = (int) event.getX() - widget.getTotalPaddingLeft() + widget.getScrollX();
                        final int y = (int) event.getY() - widget.getTotalPaddingTop() + widget.getScrollY();
                        final Layout layout = widget.getLayout();
                        final int line = layout.getLineForVertical(y);
                        final int off = layout.getOffsetForHorizontal(line, x);
                        final ClickableSpan[] link = buffer.getSpans(off, off, ClickableSpan.class);
                        if (link.length != 0) {
                            URLSpan span = (URLSpan) link[0];
                            String url   = "";
                            url          = span.getURL();

                            Context ctx = widget.getContext().getApplicationContext();
                            if (MainActivity.mTwoPane==true) {

                                WebView webView = WebViewFragment.getWebView();
                                if (webView!=null) {
                                    webView.loadUrl(url);
                                    webView.getSettings().setJavaScriptEnabled(true);
                                    webView.setWebViewClient(new WebViewClient() {
                                        public boolean shouldOverrideUrlLoading(WebView viewx, String urlx) {
                                            viewx.loadUrl(urlx);
                                            return false;
                                        }
                                    });
                                }

                            }
                            else {
                                Intent browserIntent = new Intent(Intent.ACTION_VIEW, Uri.parse(url));
                                browserIntent.setFlags(Intent.FLAG_ACTIVITY_NEW_TASK);
                                ctx.startActivity(browserIntent);
                            }
                        }
                    }
                    return true;
                }

                @Override
                public boolean onGenericMotionEvent(TextView widget, Spannable text, MotionEvent event) {
                    return false;
                }

                @Override
                public boolean canSelectArbitrarily() {
                    return false;
                }
            });

            String profilePic = post.getUser().getBiggerProfileImageURL();
            if (profilePic.length()>0) {
                Picasso.with(this.getContext()).load(profilePic).placeholder(R.drawable.ic_launcher).resize(70,70).error(R.drawable.ic_launcher).into(holder.icon);
            }




            MediaEntity[] medias = post.getMediaEntities();
            if (medias.length>0) {
                for (int i=0;i<medias.length;i++) {
                    if (medias[i].getType().equals("photo")) {
                        String value = medias[i].getMediaURL().toString();
                        if (value.length()>0) {
                            Picasso.with(this.getContext()).load(value).placeholder(R.drawable.ic_launcher).error(R.drawable.ic_launcher).into(holder.image);
                            holder.image.setVisibility(View.VISIBLE);
                        }
                    }
                }
            }
            else {
                holder.image.setVisibility(View.GONE);
            }

        }
        return view;
    }

    private static class ViewHolder {
        TextView title;
        TextView date;
        TextView text;
        ImageView image;
        ImageView icon;
    }

}