package com.andreums.culturarocafort.adapters.videos;

import android.content.Context;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ArrayAdapter;
import android.widget.ImageView;
import android.widget.TextView;

import com.andreums.culturarocafort.R;
import com.andreums.culturarocafort.models.Video;
import com.andreums.culturarocafort.util.DateUtils;
import com.squareup.picasso.Picasso;

import org.apache.commons.lang3.StringEscapeUtils;

import java.util.ArrayList;

public class VideoAdapter extends ArrayAdapter<Video> {
    private ArrayList<Video> objects = new ArrayList<Video>();


    public VideoAdapter(Context itemListFragment, int textviewid, ArrayList<Video> objects) {
        super(itemListFragment, textviewid, objects);
        this.objects = objects;
    }

    @Override
    public int getCount() {
        return ((null != objects) ? objects.size() : 0);
    }

    @Override
    public long getItemId(int position) {
        return position;
    }

    @Override
    public Video getItem(int position) {
        return ((null != objects) ? objects.get(position) : null);
    }

    public View getView(int position, View view, ViewGroup parent) {
        ViewHolder holder;
        Video video = objects.get(position);

        if (view==null) {
            LayoutInflater vi = (LayoutInflater) getContext().getSystemService(Context.LAYOUT_INFLATER_SERVICE);
            view = vi.inflate(R.layout.video_item,null);

            holder = new ViewHolder();
            holder.title = (TextView) view.findViewById(R.id.video_title);
            holder.date  = (TextView) view.findViewById(R.id.video_date);
            holder.image = (ImageView) view.findViewById(R.id.video_image);


            view.setTag(holder);

        }
        else {
            holder = (ViewHolder) view.getTag();
        }

        if (video!=null) {
            holder.title.setText(StringEscapeUtils.unescapeHtml4(video.getTitle()));
            holder.date.setText(DateUtils.convertToNotificationDate(video.getPublished()));
            if (video.getThumbnail()!=null && video.getThumbnail().length()>0) {
                Picasso.with(this.getContext()).load(video.getThumbnail()).placeholder(R.drawable.ic_launcher).error(R.drawable.ic_launcher).into(holder.image);
            }
        }
        return view;
    }



    private static class ViewHolder {
        TextView title;
        TextView date;
        ImageView image;
    }

}