package com.andreums.culturarocafort.adapters.videos;

import android.content.Context;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ArrayAdapter;
import android.widget.ImageView;
import android.widget.TextView;

import com.andreums.culturarocafort.R;
import com.andreums.culturarocafort.models.VideoPlayList;
import com.andreums.culturarocafort.util.DateUtils;
import com.squareup.picasso.Picasso;

import org.apache.commons.lang3.StringEscapeUtils;

import java.util.ArrayList;

public class VideoPlayListAdapter extends ArrayAdapter<VideoPlayList> {
    private ArrayList<VideoPlayList> objects = new ArrayList<VideoPlayList>();


    public VideoPlayListAdapter(Context itemListFragment, int textviewid, ArrayList<VideoPlayList> objects) {
        super(itemListFragment, textviewid, objects);
        this.objects = objects;
    }

    @Override
    public int getCount() {
        return ((null != objects) ? objects.size() : 0);
    }

    @Override
    public long getItemId(int position) {
        return position;
    }

    @Override
    public VideoPlayList getItem(int position) {
        return ((null != objects) ? objects.get(position) : null);
    }

    public View getView(int position, View view, ViewGroup parent) {
        ViewHolder holder;
        VideoPlayList playList = objects.get(position);

        if (view==null) {
            LayoutInflater vi = (LayoutInflater) getContext().getSystemService(Context.LAYOUT_INFLATER_SERVICE);
            view = vi.inflate(R.layout.video_playlist_item,null);

            holder = new ViewHolder();
            holder.title        = (TextView) view.findViewById(R.id.playlist_title);
            holder.description  = (TextView) view.findViewById(R.id.playlist_description);
            holder.count        = (TextView) view.findViewById(R.id.playlist_videos_count);
            holder.date         = (TextView) view.findViewById(R.id.playlist_date);
            holder.image        = (ImageView) view.findViewById(R.id.playlist_image);


            view.setTag(holder);

        }
        else {
            holder = (ViewHolder) view.getTag();
        }

        if (playList!=null) {
            holder.title.setText(StringEscapeUtils.unescapeHtml4(playList.getTitle()));
            holder.date.setText(DateUtils.convertToNotificationDate(playList.getPublished()));
            holder.description.setText(playList.getDescription());
            holder.count.setText(String.valueOf(playList.getVideoCount(this.getContext()))+" vídeos");
            if (playList.getThumbnail()!=null) {
                Picasso.with(this.getContext()).load(playList.getThumbnail()).placeholder(R.drawable.ic_launcher).error(R.drawable.ic_launcher).into(holder.image);
            }
        }
        return view;
    }



    private static class ViewHolder {
        TextView title;
        TextView date;
        TextView description;
        TextView count;
        ImageView image;
    }

}