package com.andreums.culturarocafort.database;

import android.content.Context;
import android.database.Cursor;

import com.andreums.culturarocafort.models.EventCategory;
import com.andreums.culturarocafort.models.PostCategory;

import java.util.ArrayList;

public class CategoryDatabaseHandler {

    private DatabaseHandler db;
    private static CategoryDatabaseHandler instance;

    public static CategoryDatabaseHandler getInstance(Context context) {
        if (instance == null) {
            instance = new CategoryDatabaseHandler(context);
        }
        return instance;
    }


    private CategoryDatabaseHandler(Context context) {
        this.db      = DatabaseHandler.getInstance(context);
    }

    public ArrayList<PostCategory> getPostCategories() {
        ArrayList<PostCategory> categories = new ArrayList<PostCategory>();

        try {
            String query  = "SELECT c.id,c.title,c.slug,c.description,c.parent FROM post_category c ORDER BY title ASC";
            Cursor cursor = this.db.query(query);

            if (cursor != null) {
                if (cursor.moveToFirst()) {
                    do {
                        PostCategory item = new PostCategory(cursor.getInt(0),cursor.getString(1),cursor.getString(2),cursor.getString(3),cursor.getInt(4),0);
                        int numPosts      = this.getPostCount(item.getId());
                        item.setPostCount(numPosts);
                        categories.add(item);
                    } while (cursor.moveToNext());
                }
                cursor.close();
            }
        }
        catch (Exception ex) {
            ex.printStackTrace();
        }

        return categories;

    }

    public PostCategory getPostCategory(int id) {
        PostCategory category = new PostCategory();

        try {
            String query           = "SELECT * FROM post_category WHERE id='"+id+"'";
            Cursor cursor          = this.db.query(query);

            if (cursor != null) {
                if (cursor.moveToFirst()) {
                    category = new PostCategory(cursor.getInt(0),cursor.getString(1),cursor.getString(2),cursor.getString(3),cursor.getInt(4),0);
                }
            }
        }
        catch (Exception ex) {
            ex.printStackTrace();
            ex.getMessage().toString();
        }
        return  category;
    }







    public ArrayList<EventCategory> getEventCategories() {
        ArrayList<EventCategory> categories = new ArrayList<EventCategory>();

        try {

            String query  = "SELECT c.id,c.title,c.slug,c.description,c.parent FROM event_category c ORDER BY title ASC";
            Cursor cursor = this.db.query(query);

            if (cursor != null) {
                if (cursor.moveToFirst()) {
                    do {
                        EventCategory item  = new EventCategory(cursor.getInt(0),cursor.getString(1),cursor.getString(2),cursor.getString(3),cursor.getInt(4),0);
                        int numPosts        = this.getEventCount(item.getId());
                        item.setPost_count(numPosts);
                        categories.add(item);
                    } while (cursor.moveToNext());
                }
                cursor.close();
            }
        }
        catch (Exception ex) {
            ex.getMessage().toString();
        }

        return categories;

    }

    public EventCategory getEventCategory(int id) {
        EventCategory category = new EventCategory();

        try {
            String query           = "SELECT * FROM event_category WHERE id='"+id+"'";
            Cursor cursor          = this.db.query(query);

            if (cursor != null) {
                if (cursor.moveToFirst()) {
                    category = new EventCategory(cursor.getInt(0),cursor.getString(1),cursor.getString(2),cursor.getString(3),cursor.getInt(4),0);
                }
            }
        }
        catch (Exception ex) {
            ex.printStackTrace();
            ex.getMessage().toString();
        }
        return  category;
    }

    public void clearCategories() {
        this.db.exec("DELETE FROM event_category");
        this.db.exec("DELETE FROM post_category");
    }

    public void insertEventCategories(ArrayList<EventCategory> categories) {
        if (categories.size()>0) {
            for (EventCategory category: categories) {
                this.insertEventCategory(category);
            }
        }
    }

    private void insertPostCategory(PostCategory category) {
        try {
            String  query = category.toSQL();
            this.db.exec(query);
        }
        catch (Exception ex) {
            ex.getMessage().toString();
        }
    }



    public void insertPostCategories(ArrayList<PostCategory> categories) {
        if (categories.size()>0) {
            for (PostCategory category: categories) {
                this.insertPostCategory(category);
            }
        }
    }

    private void insertEventCategory(EventCategory category) {
        try {
            String  query = category.toSQL();
            this.db.exec(query);
        }
        catch (Exception ex) {
            ex.getMessage().toString();
        }
    }


    public int getPostCount(int id) {
        int    count  = 0;
        try {
            String query  = "SELECT COUNT(*) FROM post_has_category WHERE id_category='"+id+"' ;";
            Cursor cursor = this.db.query(query);
            if (cursor != null) {
                if (cursor.moveToFirst()) {
                    count = cursor.getInt(0);
                }
                cursor.close();
            }
        }
        catch (Exception ex) { }
        return count;
    }

    public int getEventCount(int id) {
        int    count  = 0;
        try {
            String query  = "SELECT COUNT(*) FROM event_has_category WHERE id_category='"+id+"' ;";
            Cursor cursor = this.db.query(query);
            if (cursor != null) {
                if (cursor.moveToFirst()) {
                    count = cursor.getInt(0);
                }
                cursor.close();
            }
        }
        catch (Exception ex) { }
        return count;
    }

    public boolean haveCategories() {
        boolean result = false;
        try {
            String query  = "SELECT COUNT(*) FROM post_category, event_category";
            Cursor cursor = this.db.query(query);
            if (cursor.moveToFirst()) {
                int count     = cursor.getInt(0);
                if (count>0) {
                    cursor.close();
                    result = true;
                }
            }
            cursor.close();
        }
        catch (Exception ex) { }
        return result;
    }

}