package com.andreums.culturarocafort.database;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteOpenHelper;
import android.util.Log;


public class DatabaseHandler extends SQLiteOpenHelper {


    private static Context context;

    private static final int DATABASE_VERSION = 1;


    private static final String DATABASE_NAME = "culturaRocafortV2";
    private static boolean isRegistered;

    private SQLiteDatabase database;

    private static DatabaseHandler instance = null;
    private FirstDownloadReceiver receiver;


    public static DatabaseHandler getInstance(Context ctx) {

        DatabaseHandler.context = ctx;


        if (instance == null) {
            instance = new DatabaseHandler(ctx.getApplicationContext());
        }
        return instance;
    }

    private DatabaseHandler(Context context) {
        super(context, DATABASE_NAME, null, DATABASE_VERSION);
    }

    // Creating Tables
    @Override
    public void onCreate(SQLiteDatabase db) {
        this.database = db;
        this.createTables();
    }

    public void createTables() {
        String query = "CREATE TABLE post ( id INTEGER NOT NULL PRIMARY KEY, title TEXT, url TEXT, date TEXT, description TEXT, content TEXT, image TEXT, thumbnail TEXT);";
        this.exec(query);

        query = "CREATE TABLE event_category ( id INTEGER NOT NULL PRIMARY KEY,title TEXT, slug TEXT, description TEXT, parent INTEGER NULL DEFAULT 0);";
        this.exec(query);

        query = "CREATE TABLE post_category ( id INTEGER NOT NULL PRIMARY KEY,title TEXT, slug TEXT, description TEXT, parent INTEGER NULL DEFAULT 0);";
        this.exec(query);

        query = "CREATE TABLE event ( id INTEGER NOT NULL PRIMARY KEY, title TEXT, url TEXT, date TEXT, excerpt TEXT, content TEXT, image TEXT, thumbnail TEXT, venue TEXT, address TEXT, price TEXT, start_date DATETIME, end_date DATETIME );";
        this.exec(query);

        query = "CREATE TABLE event_has_category (id_event INTEGER NOT NULL, id_category INTEGER NOT NULL, PRIMARY KEY(id_event,id_category) )";
        this.exec(query);

        query = "CREATE TABLE post_has_category (id_post INTEGER NOT NULL, id_category INTEGER NOT NULL, PRIMARY KEY(id_post,id_category) )";
        this.exec(query);

        query = "CREATE TABLE favorite_event (id_event INTEGER NOT NULL PRIMARY KEY, created_at DATETIME)";
        this.exec(query);

        query = "CREATE TABLE geocoder_cache (address TEXT NOT NULL, lat TEXT, lng TEXT)";
        this.exec(query);

        query = "CREATE TABLE facebook_albums (id TEXT NOT NULL PRIMARY KEY, name TEXT, description TEXT, link TEXT, cover TEXT, created_time DATETIME);";
        this.exec(query);

        query = "CREATE TABLE facebook_photos (id TEXT NOT NULL PRIMARY KEY, id_album TEXT NOT NULL, name TEXT, link TEXT, thumbnail TEXT, image TEXT, created_time DATETIME);";
        this.exec(query);

        query = "CREATE TABLE facebook_posts (id TEXT NOT NULL PRIMARY KEY, caption TEXT, link TEXT, published DATETIME, updated DATETIME, contents TEXT, image TEXT, thumbnail TEXT, type TEXT, message TEXT, name TEXT)";
        this.exec(query);

        query = "CREATE TABLE videos (id TEXT NOT NULL PRIMARY KEY, title TEXT, description TEXT,  url TEXT, published DATETIME, thumbnail TEXT, in_playlist INTEGER NOT NULL DEFAULT 0)";
        this.exec(query);

        query = "CREATE TABLE video_playlist (id TEXT NOT NULL PRIMARY KEY, title TEXT, description TEXT,  url TEXT, published DATETIME, thumbnail TEXT)";
        this.exec(query);

        query = "CREATE TABLE video_in_playlist(id_video VARCHAR(255), id_playlist VARCHAR(255), PRIMARY KEY(id_video,id_playlist))";
        this.exec(query);

        query = "CREATE TABLE gcm_messages(id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT, title TEXT, message TEXT, received DATETIME, readed INTEGER NOT NULL DEFAULT 0)";
        this.exec(query);

        query = "CREATE TABLE instagram_images (id VARCHAR(255) NOT NULL PRIMARY KEY, caption TEXT, url VARCHAR(255), created_at DATETIME, thumbnail VARCHAR(255), image VARCHAR(255),type INTEGER(1) NOT NULL DEFAULT 0,username VARCHAR(255) NOT NULL)";
        this.exec(query);
    }

    // Upgrading database
    @Override
    public void onUpgrade(SQLiteDatabase db, int oldVersion, int newVersion) {

        // Drop older table if existed
        this.database = db;
        this.dropTables();
        this.createTables();
    }

    public void dropTables() {
        this.exec("DROP TABLE IF EXISTS post");
        this.exec("DROP TABLE IF EXISTS event_category");
        this.exec("DROP TABLE IF EXISTS post_category");
        this.exec("DROP TABLE IF EXISTS event");
        this.exec("DROP TABLE IF EXISTS event_has_category");
        this.exec("DROP TABLE IF EXISTS post_has_category");
        this.exec("DROP TABLE IF EXISTS favorite_event");
        this.exec("DROP TABLE IF EXISTS geocoder_cache");
        this.exec("DROP TABLE IF EXISTS facebook_albums");
        this.exec("DROP TABLE IF EXISTS facebook_photos");
        this.exec("DROP TABLE IF EXISTS facebook_posts");
        this.exec("DROP TABLE IF EXISTS videos");
        this.exec("DROP TABLE IF EXISTS video_playlist");
        this.exec("DROP TABLE IF EXISTS video_in_playlist");
        this.exec("DROP TABLE IF EXISTS gcm_messages");
        this.exec("DROP TABLE IF EXISTS instagram_images");
    }

    public void exec(String query) {
        try {
            if (this.database==null) {
                SQLiteDatabase db = this.getWritableDatabase();
                this.database     = db;
            }
            this.database.execSQL(query);
        }
        catch (Exception ex) {
            ex.printStackTrace();
        }
    }

    public Cursor query(String query) {
        Cursor  cursor = null;
        try {
            if (this.database==null) {
                SQLiteDatabase db = this.getWritableDatabase();
                this.database     = db;
            }
             cursor = this.database.rawQuery(query,new String[]{ });
        }
        catch (Exception ex) {
            ex.printStackTrace();
        }
        return cursor;
    }

    public void close() {
        if (this.database!=null) {
            this.database.close();
        }
    }

    private class FirstDownloadReceiver extends BroadcastReceiver {

        @Override
        public void onReceive(Context context, Intent intent) {

            Intent intentResponse = new Intent();
            intentResponse.setAction("com.andreums.culturarocafort.startup");
            context.sendBroadcast(intentResponse);

        }

    }



}