package com.andreums.culturarocafort.database;

import android.content.Context;
import android.database.Cursor;

import com.andreums.culturarocafort.models.Event;
import com.andreums.culturarocafort.models.EventCategory;
import com.andreums.culturarocafort.util.DateUtils;
import com.andreums.culturarocafort.views.events.EventHeaderView;
import com.andreums.culturarocafort.views.events.EventItemView;
import com.andreums.culturarocafort.views.events.IListViewItem;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;


public class EventDatabaseHandler {

    private Context context;
    private DatabaseHandler db;
    private static EventDatabaseHandler instance;

    public static EventDatabaseHandler getInstance(Context context) {
        if (instance == null) {
            instance = new EventDatabaseHandler(context);
        }
        return instance;
    }


    private EventDatabaseHandler(Context context) {
        this.db      = DatabaseHandler.getInstance(context);
        this.context = context;
    }

    public ArrayList<Event> getEvents() {
        ArrayList<Event> events = new ArrayList<Event>();

        try {

            String query  = "SELECT * FROM event ORDER BY DATE(start_date) DESC,TIME(start_date)  DESC";
            Cursor cursor = this.db.query(query);

            if (cursor != null) {
                if (cursor.moveToFirst()) {
                    do {
                        Event item = new Event(cursor.getInt(0),cursor.getString(1),cursor.getString(2),cursor.getString(3),cursor.getString(4),cursor.getString(5),cursor.getString(6),cursor.getString(7),cursor.getString(8),cursor.getString(9),cursor.getString(10),cursor.getString(11),cursor.getString(12));
                        events.add(item);
                    } while (cursor.moveToNext());
                }
                cursor.close();
            }
        }
        catch (Exception ex) { }

        return events;

    }


    public ArrayList<Event> getEventsListView() {
        ArrayList<Event> events = new ArrayList<Event>();

        try {
            String query            = "SELECT * FROM event ORDER BY DATE(start_date) DESC, TIME(start_date) DESC";
            Cursor cur              = this.db.query(query);
            if (cur != null) {
                if (cur.moveToFirst()) {
                    do {
                        Event event = new Event(cur.getInt(0),cur.getString(1),cur.getString(2),cur.getString(3),cur.getString(4),cur.getString(5),cur.getString(6),cur.getString(7),cur.getString(8),cur.getString(9),cur.getString(10),cur.getString(11),cur.getString(12));
                        events.add(event);
                    } while (cur.moveToNext());
                }
                cur.close();
            }
        }
        catch (Exception ex) { }

        return events;
    }

    public ArrayList<IListViewItem> getEventsByCategoryId(int id) {
        ArrayList<IListViewItem> items     = new ArrayList<IListViewItem>();
        ArrayList<EventHeaderView> headers = new ArrayList<EventHeaderView>();

        try {

            String query  = "SELECT DATE(start_date), COUNT(*) FROM event INNER JOIN event_has_category ON (id_event=id) WHERE (id_category='"+id+"') GROUP BY DATE(start_date)  ORDER BY DATE(start_date) DESC";
            Cursor cursor = this.db.query(query);
            if (cursor != null) {
                if (cursor.moveToFirst()) {
                    do {
                        EventHeaderView header = new EventHeaderView(cursor.getString(0));
                        headers.add(header);
                    } while (cursor.moveToNext());
                }
                cursor.close();
            }

            if (headers.size()>0) {
                for (EventHeaderView header: headers) {
                    items.add(header);
                    String date = header.getDate();
                    query       = "SELECT id,title,url,date,excerpt,content,image,thumbnail,venue,address,price,start_date,end_date FROM event INNER JOIN event_has_category ON (id_event=id) WHERE (id_category='"+id+"' AND DATE(start_date)='"+date+"') ORDER BY DATE(start_date) DESC,TIME(start_date)  DESC";
                    Cursor cur  = this.db.query(query);
                    if (cur != null) {
                        if (cur.moveToFirst()) {
                            do {
                                Event event        = new Event(cur.getInt(0),cur.getString(1),cur.getString(2),cur.getString(3),cur.getString(4),cur.getString(5),cur.getString(6),cur.getString(7),cur.getString(8),cur.getString(9),cur.getString(10),cur.getString(11),cur.getString(12));
                                EventItemView item = new EventItemView(event);

                                items.add(item);
                            } while (cur.moveToNext());
                        }
                        cur.close();
                    }
                }
            }
        }
        catch (Exception ex) { }

        return items;
    }

    public ArrayList<Event> getSpecialEvents(int id) {
        ArrayList<Event> events = new ArrayList<Event>();


        try {

            String query  = "SELECT id,title,url,date,excerpt,content,image,thumbnail,venue,address,price,start_date,end_date FROM event INNER JOIN event_has_category ON (id_event=id) WHERE (id_category='"+id+"') ORDER BY DATE(start_date) DESC,TIME(start_date)  DESC";
            Cursor cursor = this.db.query(query);

            if (cursor != null) {
                if (cursor.moveToFirst()) {
                    do {
                        Event item = new Event(cursor.getInt(0),cursor.getString(1),cursor.getString(2),cursor.getString(3),cursor.getString(4),cursor.getString(5),cursor.getString(6),cursor.getString(7),cursor.getString(8),cursor.getString(9),cursor.getString(10),cursor.getString(11),cursor.getString(12));
                        events.add(item);
                    } while (cursor.moveToNext());
                }
                cursor.close();
            }
        }
        catch (Exception ex) { }

        return events;
    }

    public ArrayList<IListViewItem> getEventsByTitle(String title) {
        ArrayList<IListViewItem> items     = new ArrayList<IListViewItem>();
        ArrayList<EventHeaderView> headers = new ArrayList<EventHeaderView>();

        try {

            String query  = "SELECT DATE(start_date), COUNT(*) FROM event WHERE title LIKE '%"+title+"%' GROUP BY DATE(start_date)  ORDER BY DATE(start_date) DESC";
            Cursor cursor = this.db.query(query);
            if (cursor != null) {
                if (cursor.moveToFirst()) {
                    do {
                        EventHeaderView header = new EventHeaderView(cursor.getString(0));
                        headers.add(header);
                    } while (cursor.moveToNext());
                }
                cursor.close();
            }

            if (headers.size()>0) {
                for (EventHeaderView header: headers) {
                    items.add(header);
                    String date = header.getDate();
                    query       = "SELECT id,title,url,date,excerpt,content,image,thumbnail,venue,address,price,start_date,end_date FROM event WHERE (title LIKE '%"+title+"%' AND DATE(start_date)='"+date+"') ORDER BY DATE(start_date) DESC,TIME(start_date)  DESC";
                    Cursor cur  = this.db.query(query);
                    if (cur != null) {
                        if (cur.moveToFirst()) {
                            do {
                                Event event        = new Event(cur.getInt(0),cur.getString(1),cur.getString(2),cur.getString(3),cur.getString(4),cur.getString(5),cur.getString(6),cur.getString(7),cur.getString(8),cur.getString(9),cur.getString(10),cur.getString(11),cur.getString(12));
                                EventItemView item = new EventItemView(event);

                                items.add(item);
                            } while (cur.moveToNext());
                        }
                        cur.close();
                    }
                }
            }
        }
        catch (Exception ex) { }

        return items;
    }

    public ArrayList<IListViewItem> getEventsForListView() {
        ArrayList<IListViewItem> items     = new ArrayList<IListViewItem>();
        ArrayList<EventHeaderView> headers = new ArrayList<EventHeaderView>();

        try {

            String query  = "SELECT DATE(start_date), COUNT(*) FROM event GROUP BY DATE(start_date)  ORDER BY DATE(start_date) DESC";
            Cursor cursor = this.db.query(query);
            if (cursor != null) {
                if (cursor.moveToFirst()) {
                    do {
                        EventHeaderView header = new EventHeaderView(cursor.getString(0));
                        headers.add(header);
                    } while (cursor.moveToNext());
                }
                cursor.close();
            }

            if (headers.size()>0) {
                for (EventHeaderView header: headers) {
                    items.add(header);
                    String date = header.getDate();
                    query       = "SELECT id,title,url,date,excerpt,content,image,thumbnail,venue,address,price,start_date,end_date FROM event WHERE (DATE(start_date)='"+date+"') ORDER BY DATE(start_date) DESC,TIME(start_date)  DESC";
                    Cursor cur  = this.db.query(query);
                    if (cur != null) {
                        if (cur.moveToFirst()) {
                            do {
                                Event event        = new Event(cur.getInt(0),cur.getString(1),cur.getString(2),cur.getString(3),cur.getString(4),cur.getString(5),cur.getString(6),cur.getString(7),cur.getString(8),cur.getString(9),cur.getString(10),cur.getString(11),cur.getString(12));
                                EventItemView item = new EventItemView(event);

                                items.add(item);
                            } while (cur.moveToNext());
                        }
                        cur.close();
                    }
                }
            }
        }
        catch (Exception ex) { }

        return items;
    }

    public ArrayList<Event> getFavoriteEvents() {
        ArrayList<Event> events = new ArrayList<Event>();

        try {

            String query  = "SELECT id,title,url,date,excerpt,content,image,thumbnail,venue,address,price,start_date,end_date FROM favorite_event INNER JOIN event ON (id_event=id) ORDER BY DATE(start_date) ASC,TIME(start_date)  ASC";
            Cursor cursor = this.db.query(query);

            if (cursor != null) {
                if (cursor.moveToFirst()) {
                    do {
                        Event item = new Event(cursor.getInt(0),cursor.getString(1),cursor.getString(2),cursor.getString(3),cursor.getString(4),cursor.getString(5),cursor.getString(6),cursor.getString(7),cursor.getString(8),cursor.getString(9),cursor.getString(10),cursor.getString(11),cursor.getString(12));
                        events.add(item);
                    } while (cursor.moveToNext());
                }
                cursor.close();
            }
        }
        catch (Exception ex) { }

        return events;
    }

    public Event getNextEvent() {
        Event event = null;

        try {

            String dateNow = DateUtils.getDateNow();
            String timeNow = DateUtils.getMinutesNowPlusFifteen();
            String query   = "SELECT id,title,url,date,excerpt,content,image,thumbnail,venue,address,price,start_date,end_date FROM event WHERE (DATE(end_date)>'"+dateNow+"') OR (DATE(end_date)='"+dateNow+"' AND TIME(end_date)>='"+timeNow+"' ) ORDER BY DATE(start_date) ASC,TIME(start_date) ASC LIMIT 1";
            Cursor cursor  = this.db.query(query);

            if (cursor != null) {
                if (cursor.moveToFirst()) {
                    event = new Event(cursor.getInt(0),cursor.getString(1),cursor.getString(2),cursor.getString(3),cursor.getString(4),cursor.getString(5),cursor.getString(6),cursor.getString(7),cursor.getString(8),cursor.getString(9),cursor.getString(10),cursor.getString(11),cursor.getString(12));
                }
                cursor.close();
            }
        }
        catch (Exception ex) {
            ex.printStackTrace();
        }

        return event;
    }


    public ArrayList<Event> getNextEvents() {
        ArrayList<Event> events = new ArrayList<Event>();

        try {

            String dateNow = DateUtils.getDateNow();
            String timeNow = DateUtils.getMinutesNowPlusFifteen();
            String query   = "SELECT id,title,url,date,excerpt,content,image,thumbnail,venue,address,price,start_date,end_date FROM event WHERE (DATE(end_date)>'"+dateNow+"') OR (DATE(end_date)='"+dateNow+"' AND TIME(end_date)>='"+timeNow+"' ) ORDER BY DATE(start_date) ASC,TIME(start_date) ASC LIMIT 10";
            Cursor cursor  = this.db.query(query);


            if (cursor != null) {
                if (cursor.moveToFirst()) {
                    do {
                        Event item = new Event(cursor.getInt(0),cursor.getString(1),cursor.getString(2),cursor.getString(3),cursor.getString(4),cursor.getString(5),cursor.getString(6),cursor.getString(7),cursor.getString(8),cursor.getString(9),cursor.getString(10),cursor.getString(11),cursor.getString(12));
                        events.add(item);
                    } while (cursor.moveToNext());
                }
                cursor.close();
            }
        }
        catch (Exception ex) {
            ex.printStackTrace();
        }

        return events;
    }

    public void insertFavoriteEvent(int id) {

        try {
            String query = "INSERT INTO favorite_event VALUES ('"+id+"','"+this.getDateNow()+"' );";
            this.db.exec(query);
        }
        catch (Exception ex) { }

    }

    public void deleteFavoriteEvent(int id) {
        try {
            String query = "DELETE FROM favorite_event WHERE id_event='"+id+"'";
            this.db.exec(query);
        }
        catch (Exception ex) { }
    }

    public boolean isFavorited(int id) {
        boolean isFavorited = false;
        try {
            String query  = "SELECT * FROM favorite_event WHERE id_event='"+id+"'";
            Cursor cursor = this.db.query(query);
            if (cursor.moveToFirst()) {
                cursor.close();
                isFavorited = true;
            }
            cursor.close();

        }
        catch (Exception ex) { }
        return isFavorited;
    }

    public Event getEvent(int id) {
        Event event     = new Event();
        try {
            String query    = "SELECT * FROM event WHERE id='"+id+"'";
            Cursor cursor   = this.db.query(query);

            if (cursor != null) {
                if (cursor.moveToFirst()) {
                    event = new Event(cursor.getInt(0),cursor.getString(1),cursor.getString(2),cursor.getString(3),cursor.getString(4),cursor.getString(5),cursor.getString(6),cursor.getString(7),cursor.getString(8),cursor.getString(9),cursor.getString(10),cursor.getString(11),cursor.getString(12));
                }
                cursor.close();
            }
        }
        catch (Exception ex) { }

        return  event;
    }

    public void clearEvents() {
        try {
            this.db.exec("DELETE FROM event");
            this.db.exec("DELETE FROM event_has_category");
        }
        catch (Exception ex) { }
    }

    public void insertEvents(ArrayList<Event> events) {
        if (events.size()>0) {
            for (Event event:events) {
                this.insertEvent(event);
            }
        }
    }

    private void insertEvent(Event event) {
        try {
            String  query = event.toSQL();
            this.db.exec(query);

            ArrayList<EventCategory> categories = event.getCategories();
            if (categories!=null) {
                for (EventCategory category : categories) {
                    int cat = category.getId();
                    int id = event.getId();
                    String queryCat = "INSERT INTO event_has_category VALUES ('" + id + "','" + cat + "'); ";
                    this.db.exec(queryCat);
                }
            }
        }
        catch (Exception ex) {
            ex.printStackTrace();
        }
    }

    private String getDateNow() {
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm::ss");
        Date now             = new Date();
        String date = sdf.format(now);
        return date;

    }

    public boolean haveEvents() {
        boolean result = false;
        try {
            String query  = "SELECT COUNT(*) FROM event";
            Cursor cursor = this.db.query(query);
            if (cursor!=null) {
                if (cursor.moveToFirst()) {
                    int count     = cursor.getInt(0);
                    if (count>0) {
                        result = true;
                    }
                }
                cursor.close();
            }
        }
        catch (Exception ex) { }
        return result;
    }


}