package com.andreums.culturarocafort.database;

import android.content.Context;
import android.database.Cursor;

import com.andreums.culturarocafort.models.FacebookAlbum;
import com.andreums.culturarocafort.models.FacebookPhoto;

import java.util.ArrayList;

public class FacebookPhotosDatabaseHandler {

    private DatabaseHandler db;
    private static FacebookPhotosDatabaseHandler instance;

    public static FacebookPhotosDatabaseHandler getInstance(Context context) {
        if (instance == null) {
            instance = new FacebookPhotosDatabaseHandler(context);
        }
        return instance;
    }


    public FacebookPhotosDatabaseHandler(Context context) {
        this.db      = DatabaseHandler.getInstance(context);
    }

    public void clearAlbums() {
        try {
            this.db.exec("DELETE FROM facebook_albums");
        }
        catch (Exception ex) { }
    }

    public void clearPhotos() {
        try {
            this.db.exec("DELETE FROM facebook_photos");
        }
        catch (Exception ex) { }
    }

    public ArrayList<FacebookAlbum> getAlbums() {
        ArrayList<FacebookAlbum> albums = new ArrayList<FacebookAlbum>();
        try {
            String query  = "SELECT a.id,a.name,a.description,a.link,a.cover,a.created_time,COUNT(b.id_album) FROM facebook_albums a JOIN facebook_photos b ON(b.id_album=a.id) GROUP BY(b.id_album) ORDER BY DATE(a.created_time) DESC, TIME(a.created_time) DESC";
            Cursor cursor = this.db.query(query);

            if (cursor != null) {
                if (cursor.moveToFirst()) {
                    do {
                        FacebookAlbum album = new FacebookAlbum(cursor.getString(0),cursor.getString(1),cursor.getString(2),cursor.getString(3),cursor.getString(4),cursor.getString(5));
                        album.setCount(cursor.getInt(6));
                        albums.add(album);
                    } while (cursor.moveToNext());
                }
            }
            cursor.close();
        }
        catch (Exception ex) { }
        return albums;
    }

    public FacebookAlbum getAlbum(String id) {
        FacebookAlbum album = new FacebookAlbum();
        try {
            String query   = "SELECT * FROM facebook_albums WHERE id='"+id+"' ORDER BY DATE(created_time) DESC, TIME(created_time) DESC";
            Cursor cursor  = this.db.query(query);

            if (cursor != null) {
                if (cursor.moveToFirst()) {
                    album = new FacebookAlbum(cursor.getString(0),cursor.getString(1),cursor.getString(2),cursor.getString(3),cursor.getString(4),cursor.getString(5));
                }
            }
            cursor.close();
        }
        catch (Exception ex) { }
        return album;
    }

    public FacebookPhoto getPhoto(String id) {
        FacebookPhoto photo = new FacebookPhoto();
        try {
            String query   = "SELECT * FROM facebook_photos WHERE id='"+id+"' ORDER BY DATE(created_time) DESC, TIME(created_time) DESC";
            Cursor cursor  = this.db.query(query);

            if (cursor != null) {
                if (cursor.moveToFirst()) {
                    photo = new FacebookPhoto(cursor.getString(0),cursor.getString(1),cursor.getString(2),cursor.getString(3),cursor.getString(4),cursor.getString(5),cursor.getString(6));
                }
            }
            cursor.close();
        }
        catch (Exception ex) { }
        return photo;
    }


    public void insertAlbums(ArrayList<FacebookAlbum> albums) {
        if (albums.size()>0) {
            for(FacebookAlbum album:albums) {
                this.insertAlbum(album);
            }
        }
    }

    public void insertAlbum(FacebookAlbum album) {
        try {
            String query = album.toSQL();
            this.db.exec(query);
        }
        catch (Exception ex) {
            ex.printStackTrace();
        }
    }


    public void insertPhotos(ArrayList<FacebookPhoto> photos) {
        if (photos.size()>0) {
            for(FacebookPhoto photo: photos) {
                this.insertPhoto(photo);
            }
        }
    }

    public void insertPhoto(FacebookPhoto photo) {
        try {
            String query = photo.toSQL();
            this.db.exec(query);
        }
        catch (Exception ex) {
            ex.printStackTrace();
        }
    }

    public boolean haveAlbums() {
        boolean result = false;
        try {
            String query  = "SELECT COUNT(*) FROM facebook_albums";
            Cursor cursor = this.db.query(query);
            if (cursor.moveToFirst()) {
                int count     = cursor.getInt(0);
                if (count>0) {
                    cursor.close();
                    result = true;
                }
            }
            cursor.close();
        }
        catch (Exception ex) { }
        return result;
    }



    public ArrayList<FacebookPhoto> getAlbumPhotos(String id) {
        ArrayList<FacebookPhoto> photos = new ArrayList<FacebookPhoto>();
        try {
            String query   = "SELECT * FROM facebook_photos WHERE id_album='"+id+"' ORDER BY DATE(created_time) DESC, TIME(created_time) DESC";
            Cursor cursor  = this.db.query(query);

            if (cursor != null) {
                if (cursor.moveToFirst()) {
                    do {
                        FacebookPhoto aux = new FacebookPhoto(cursor.getString(0),cursor.getString(1),cursor.getString(2),cursor.getString(3),cursor.getColumnName(4),cursor.getString(5),cursor.getString(6));
                        photos.add(aux);
                    } while (cursor.moveToNext());
                }
            }
            cursor.close();
        }
        catch (Exception ex) { }
        return photos;
    }
}
