package com.andreums.culturarocafort.database;

import android.content.Context;
import android.database.Cursor;

import com.andreums.culturarocafort.models.FacebookPost;
import com.andreums.culturarocafort.views.facebook.FacebookLinkView;
import com.andreums.culturarocafort.views.facebook.FacebookPictureView;
import com.andreums.culturarocafort.views.facebook.FacebookStatusView;
import com.andreums.culturarocafort.views.facebook.FacebookVideoView;
import com.andreums.culturarocafort.views.facebook.IListFacebookPostViewItem;

import java.util.ArrayList;

public class FacebookPostsDatabaseHandler {

    private DatabaseHandler db;
    private static FacebookPostsDatabaseHandler instance;

    public static FacebookPostsDatabaseHandler getInstance(Context context) {
        if (instance == null) {
            instance = new FacebookPostsDatabaseHandler(context);
        }
        return instance;
    }


    private FacebookPostsDatabaseHandler(Context context) {
        this.db      = DatabaseHandler.getInstance(context);
    }

    public ArrayList<FacebookPost> getPostsSimple() {
        ArrayList<FacebookPost> posts = new ArrayList<FacebookPost>();
        try {
            String query  = "SELECT * FROM facebook_posts ORDER BY DATE(published) DESC, TIME(published) DESC";
            Cursor cursor = this.db.query(query);

            if (cursor != null) {
                if (cursor.moveToFirst()) {
                    do {
                        FacebookPost item = new FacebookPost(cursor.getString(0),cursor.getString(1),cursor.getString(2),cursor.getString(3),cursor.getString(4),cursor.getString(5),cursor.getString(6),cursor.getString(7),cursor.getString(8),cursor.getString(9),cursor.getString(10));
                        posts.add(item);

                    } while (cursor.moveToNext());
                }
            }
            cursor.close();
        }
        catch (Exception ex) { }
        return posts;

    }

    public ArrayList<IListFacebookPostViewItem> getPosts() {
        ArrayList<IListFacebookPostViewItem> posts = new ArrayList<IListFacebookPostViewItem>();
        try {
            String query  = "SELECT * FROM facebook_posts ORDER BY DATE(published) DESC, TIME(published) DESC";
            Cursor cursor = this.db.query(query);

            if (cursor != null) {
                if (cursor.moveToFirst()) {
                    do {
                        FacebookPost item = new FacebookPost(cursor.getString(0),cursor.getString(1),cursor.getString(2),cursor.getString(3),cursor.getString(4),cursor.getString(5),cursor.getString(6),cursor.getString(7),cursor.getString(8),cursor.getString(9),cursor.getString(10));
                        String type       = item.getType();

                        if (type.equals("status")) {
                            posts.add(new FacebookStatusView(item));
                        }
                        if (type.equals("link")) {
                            posts.add(new FacebookLinkView(item));
                        }
                        if (type.equals("video")) {
                            posts.add(new FacebookVideoView(item));
                        }
                        if (type.equals("photo")) {
                            posts.add(new FacebookPictureView(item));
                        }

                    } while (cursor.moveToNext());
                }
            }
            cursor.close();
        }
        catch (Exception ex) { }
        return posts;

    }

    public FacebookPost getPost(String id) {
        FacebookPost    post   = new FacebookPost();
        try {
            String query   = "SELECT * FROM facebook_posts WHERE id='"+id+"' ORDER BY DATE(published) DESC, TIME(published) DESC";
            Cursor cursor  = this.db.query(query);

            if (cursor != null) {
                if (cursor.moveToFirst()) {
                    post = new FacebookPost(cursor.getString(0),cursor.getString(1),cursor.getString(2),cursor.getString(3),cursor.getString(4),cursor.getString(5),cursor.getString(6),cursor.getString(7),cursor.getString(8),cursor.getString(9),cursor.getString(10));
                }
            }
            cursor.close();
        }
        catch (Exception ex) { }
        return  post;
    }

    public void clearPosts() {
        try {
            this.db.exec("DELETE FROM facebook_posts");
        }
        catch (Exception ex) { }
    }

    public void insertPosts(ArrayList<FacebookPost> posts) {
        if (posts.size()>0) {
            for(FacebookPost post:posts) {
                this.insertPost(post);
            }
        }
    }

    private void insertPost(FacebookPost post) {
        try {
            String  query = post.toSQL();
            this.db.exec(query);
        }
        catch (Exception ex) { }
    }

    public boolean havePosts() {
        boolean result = false;
        try {
            String query  = "SELECT COUNT(*) FROM facebook_posts";
            Cursor cursor = this.db.query(query);
            if (cursor.moveToFirst()) {
                int count     = cursor.getInt(0);
                if (count>0) {
                    cursor.close();
                    result = true;
                }
            }
            cursor.close();
        }
        catch (Exception ex) { }
        return result;
    }



}
