package com.andreums.culturarocafort.database;

import android.content.Context;
import android.database.Cursor;

import com.andreums.culturarocafort.models.GCMMessage;

import java.util.ArrayList;

public class GCMDatabaseHandler {

    private DatabaseHandler db;
    private static GCMDatabaseHandler instance;

    public static GCMDatabaseHandler getInstance(Context context) {
        if (instance == null) {
            instance = new GCMDatabaseHandler(context);
        }
        return instance;
    }


    private GCMDatabaseHandler(Context context) {
        this.db      = DatabaseHandler.getInstance(context);
    }

    public ArrayList<GCMMessage> getMessages() {
        ArrayList<GCMMessage> messages = new ArrayList<GCMMessage>();
        try {
            String query  = "SELECT * FROM gcm_messages ORDER BY DATE(received) DESC, TIME(received) DESC";
            Cursor cursor = this.db.query(query);

            if (cursor != null) {
                if (cursor.moveToFirst()) {
                    do {
                        int readed         = cursor.getInt(4);
                        boolean readedBool = (readed==0?false:true);
                        GCMMessage item = new GCMMessage(cursor.getInt(0),cursor.getString(1),cursor.getString(2),cursor.getString(3),readedBool);
                        messages.add(item);
                    } while (cursor.moveToNext());
                }
            }
            cursor.close();
        }
        catch (Exception ex) { }
        return messages;

    }

    public GCMMessage getMessage(int id) {
        GCMMessage message = new GCMMessage();
        try {
            String query   = "SELECT * FROM gcm_messages WHERE id='"+id+"' ORDER BY DATE(received) DESC, TIME(received) DESC";
            Cursor cursor  = this.db.query(query);

            if (cursor != null) {
                if (cursor.moveToFirst()) {
                    int readed         = cursor.getInt(4);
                    boolean readedBool = (readed==0?false:true);
                    message = new GCMMessage(cursor.getInt(0),cursor.getString(1),cursor.getString(2),cursor.getString(3),readedBool);
                }
            }
            cursor.close();
        }
        catch (Exception ex) { }
        return  message;
    }

    public void clearMessages() {
        try {
            this.db.exec("DELETE FROM gcm_messages");
        }
        catch (Exception ex) { }
    }


    public void insertMessage(GCMMessage message) {
        try {
            String  query = message.toSQL();
            this.db.exec(query);
        }
        catch (Exception ex) { }
    }

    public boolean hasMessages() {
        boolean result = false;
        try {
            String query  = "SELECT COUNT(*) FROM gcm_messages";
            Cursor cursor = this.db.query(query);
            if (cursor.moveToFirst()) {
                int count     = cursor.getInt(0);
                if (count>0) {
                    cursor.close();
                    result = true;
                }
            }
            cursor.close();
        }
        catch (Exception ex) { }
        return result;
    }


    public int getLastInsertedMessageId() {
        int result   = -1;
        String query = "SELECT id from gcm_messages order by id DESC limit 1";
        try {
            Cursor c = this.db.query(query);
            if (c != null && c.moveToFirst()) {
                result = c.getInt(0);
            }
        }
        catch (Exception ex) {
            ex.printStackTrace();
        }
        return result;
    }

    public void deleteMessage(int id) {
        try {
            String query = "DELETE FROM gcm_messages WHERE id='"+id+"'";
            this.db.exec(query);
        }
        catch (Exception ex) {
            ex.printStackTrace();
        }
    }

    public void markMessageAsReaded(int id) {
        try {
            String query = "UPDATE gcm_messages SET readed='1' WHERE id='"+id+"'";
            this.db.exec(query);
        }
        catch (Exception ex) {
            ex.printStackTrace();
        }
    }


    public void markAllMessagesAsReaded() {
        try {
            String query = "UPDATE gcm_messages SET readed='1' ";
            this.db.exec(query);
        }
        catch (Exception ex) {
            ex.printStackTrace();
        }
    }
}
