package com.andreums.culturarocafort.database;

import android.content.Context;
import android.database.Cursor;

import com.andreums.culturarocafort.models.Post;
import com.andreums.culturarocafort.models.PostCategory;

import java.util.ArrayList;

public class PostDatabaseHandler {

    private DatabaseHandler db;
    private static PostDatabaseHandler instance;

    public static PostDatabaseHandler getInstance(Context context) {
        if (instance == null) {
            instance = new PostDatabaseHandler(context);
        }
        return instance;
    }


    private PostDatabaseHandler(Context context) {
        this.db      = DatabaseHandler.getInstance(context);
    }

    public ArrayList<Post> getPosts() {
        ArrayList<Post> posts = new ArrayList<Post>();
        try {
            String query  = "SELECT * FROM post ORDER BY DATE(date) DESC, TIME(date) DESC";
            Cursor cursor = this.db.query(query);

            if (cursor != null) {
                if (cursor.moveToFirst()) {
                    do {
                        Post item = new Post(cursor.getInt(0),cursor.getString(1),cursor.getString(2),cursor.getString(3),cursor.getString(4),cursor.getString(5),cursor.getString(6),cursor.getString(7));
                        posts.add(item);
                    } while (cursor.moveToNext());
                }
            }
            cursor.close();
        }
        catch (Exception ex) { }
        return posts;

    }

    public Post getPost(int id) {
        Post    post   = new Post();
        try {
            String query   = "SELECT * FROM post WHERE id='"+id+"' ORDER BY DATE(date) DESC, TIME(date) DESC";
            Cursor cursor  = this.db.query(query);

            if (cursor != null) {
                if (cursor.moveToFirst()) {
                    post = new Post(cursor.getInt(0),cursor.getString(1),cursor.getString(2),cursor.getString(3),cursor.getString(4),cursor.getString(5),cursor.getString(6), cursor.getString(7));
                }
            }
            cursor.close();
        }
        catch (Exception ex) { }
        return  post;
    }

    public void clearPosts() {
        try {
            this.db.exec("DELETE FROM post");
            this.db.exec("DELETE FROM post_has_category");
        }
        catch (Exception ex) { }
    }

    public void insertPosts(ArrayList<Post> posts) {
        if (posts.size()>0) {
            for(Post post:posts) {
                this.insertPost(post);
            }
        }
    }

    private void insertPost(Post post) {
        try {
            String  query = post.toSQL();
            this.db.exec(query);

            ArrayList<PostCategory> categories = post.getCategories();
            for (PostCategory category:categories) {
                int cat         = category.getId();
                String queryCat = "INSERT INTO post_has_category VALUES ('"+post.getId()+"','"+cat+"'); ";
                this.db.exec(queryCat);
            }
        }
        catch (Exception ex) { }
    }

    public boolean havePosts() {
        boolean result = false;
        try {
            String query  = "SELECT COUNT(*) FROM post";
            Cursor cursor = this.db.query(query);
            if (cursor.moveToFirst()) {
                int count     = cursor.getInt(0);
                if (count>0) {
                    cursor.close();
                    result = true;
                }
            }
            cursor.close();
        }
        catch (Exception ex) { }
        return result;
    }

    public ArrayList<Post> getLatestNews(int id) {
        ArrayList<Post> items     = new ArrayList<Post>();

        try {
            String query  = "SELECT * FROM post INNER JOIN post_has_category ON (id_post=id) WHERE (id_category='"+id+"') ORDER BY DATE(date) DESC, TIME(date) DESC LIMIT 6";
            Cursor cursor = this.db.query(query);
            if (cursor != null) {
                if (cursor.moveToFirst()) {
                    do {
                        Post post = new Post(cursor.getInt(0),cursor.getString(1),cursor.getString(2),cursor.getString(3),cursor.getString(4),cursor.getString(5),cursor.getString(6),cursor.getString(7));
                        items.add(post);
                    } while (cursor.moveToNext());
                }
                cursor.close();
            }
        }

        catch (Exception ex) { }

        return items;
    }

    public ArrayList<Post> getPostsByCategoriesId(int[] ids) {
        ArrayList<Post> items     = new ArrayList<Post>();

        String inClause           = "(";
        if (ids.length>0) {
            for (int i=0;i<ids.length;i++) {
                inClause += "'"+ids[i]+"'";
            }
        }
        inClause += ")";

        try {
            String query  = "SELECT * FROM post INNER JOIN post_has_category ON (id_post=id) WHERE id_category IN "+inClause+" ORDER BY DATE(date) DESC, TIME(date) DESC";
            Cursor cursor = this.db.query(query);
            if (cursor != null) {
                if (cursor.moveToFirst()) {
                    do {
                        Post post = new Post(cursor.getInt(0),cursor.getString(1),cursor.getString(2),cursor.getString(3),cursor.getString(4),cursor.getString(5),cursor.getString(6),cursor.getString(7));
                        items.add(post);
                    } while (cursor.moveToNext());
                }
                cursor.close();
            }
        }

        catch (Exception ex) { }

        return items;
    }


    public ArrayList<Post> getPostsByCategoryId(int id) {
        ArrayList<Post> items     = new ArrayList<Post>();

        try {
            String query  = "SELECT * FROM post INNER JOIN post_has_category ON (id_post=id) WHERE (id_category='"+id+"') ORDER BY DATE(date) DESC, TIME(date) DESC";
            Cursor cursor = this.db.query(query);
            if (cursor != null) {
                if (cursor.moveToFirst()) {
                    do {
                        Post post = new Post(cursor.getInt(0),cursor.getString(1),cursor.getString(2),cursor.getString(3),cursor.getString(4),cursor.getString(5),cursor.getString(6),cursor.getString(7));
                        items.add(post);
                    } while (cursor.moveToNext());
                }
                cursor.close();
            }
        }

        catch (Exception ex) { }

        return items;
    }

    public ArrayList<Post> getPostsByTitle(String title) {
        ArrayList<Post> posts = new ArrayList<Post>();
        try {
            String query  = "SELECT * FROM post WHERE title LIKE '%"+title+"%' ORDER BY DATE(date) DESC, TIME(date) DESC";
            Cursor cursor = this.db.query(query);

            if (cursor != null) {
                if (cursor.moveToFirst()) {
                    do {
                        Post item = new Post(cursor.getInt(0),cursor.getString(1),cursor.getString(2),cursor.getString(3),cursor.getString(4),cursor.getString(5),cursor.getString(6),cursor.getString(7));
                        posts.add(item);
                    } while (cursor.moveToNext());
                }
            }
            cursor.close();
        }
        catch (Exception ex) { }
        return posts;

    }



}