package com.andreums.culturarocafort.database;

import android.content.Context;
import android.database.Cursor;

import com.andreums.culturarocafort.models.Video;
import com.andreums.culturarocafort.models.VideoPlayList;

import java.util.ArrayList;

public class VideosDatabaseHandler {

    private DatabaseHandler db;
    private static VideosDatabaseHandler instance;

    public static VideosDatabaseHandler getInstance(Context context) {
        if (instance == null) {
            instance = new VideosDatabaseHandler(context);
        }
        return instance;
    }


    private VideosDatabaseHandler(Context context) {
        this.db      = DatabaseHandler.getInstance(context);
    }

    public ArrayList<Video> getVideos() {
        ArrayList<Video> videos = new ArrayList<Video>();
        try {
            String query  = "SELECT * FROM videos WHERE in_playlist='0' ORDER BY DATE(published) DESC, TIME(published) DESC";
            Cursor cursor = this.db.query(query);

            if (cursor != null) {
                if (cursor.moveToFirst()) {
                    do {
                        Video item = new Video(cursor.getString(0),cursor.getString(1),cursor.getString(2),cursor.getString(3),cursor.getString(4),cursor.getString(5),0);
                        videos.add(item);
                    } while (cursor.moveToNext());
                }
            }
            cursor.close();
        }
        catch (Exception ex) { }
        return videos;
    }

    public ArrayList<Video> getPlayListVideos(String playlistId) {


        ArrayList<Video> videos = new ArrayList<Video>();
        try {
            String query  = "SELECT * FROM videos WHERE in_playlist='1' AND id IN (SELECT id_video FROM video_in_playlist WHERE id_playlist='"+playlistId+"') ORDER BY DATE(published) DESC, TIME(published) DESC";
            Cursor cursor = this.db.query(query);

            if (cursor != null) {
                if (cursor.moveToFirst()) {
                    do {
                        Video item = new Video(cursor.getString(0),cursor.getString(1),cursor.getString(2),cursor.getString(3),cursor.getString(4),cursor.getString(5),0);
                        videos.add(item);
                    } while (cursor.moveToNext());
                }
            }
            cursor.close();
        }
        catch (Exception ex) { }
        return videos;
    }


    public ArrayList<VideoPlayList> getPlayLists() {
        ArrayList<VideoPlayList> playLists = new ArrayList<VideoPlayList>();
        try {
            String query  = "SELECT * FROM video_playlist ORDER BY DATE(published) DESC, TIME(published) DESC";
            Cursor cursor = this.db.query(query);

            if (cursor != null) {
                if (cursor.moveToFirst()) {
                    do {
                        VideoPlayList item = new VideoPlayList(cursor.getString(0),cursor.getString(1),cursor.getString(2),cursor.getString(3),cursor.getString(4),cursor.getString(5));
                        playLists.add(item);
                    } while (cursor.moveToNext());
                }
            }
            cursor.close();
        }
        catch (Exception ex) { }
        return playLists;
    }

    public Video getVideo(String id) {
        Video video = new Video();
        try {
            String query   = "SELECT * FROM videos WHERE id='"+id+"' ORDER BY DATE(published) DESC, TIME(published) DESC";
            Cursor cursor  = this.db.query(query);

            if (cursor != null) {
                if (cursor.moveToFirst()) {
                    video = new Video(cursor.getString(0),cursor.getString(1),cursor.getString(2),cursor.getString(3),cursor.getString(4),cursor.getString(5),0);
                }
            }
            cursor.close();
        }
        catch (Exception ex) { }
        return  video;
    }

    public void clearVideos() {
        try {
            this.db.exec("DELETE FROM videos WHERE in_playlist<>'1' ");
        }
        catch (Exception ex) { }
    }

    public void clearPlayLists() {
        try {
            this.db.exec("DELETE FROM video_playlist");
        }
        catch (Exception ex) { }
    }

    public void clearPlayListVideos() {
        try {
            this.db.exec("DELETE FROM video_in_playlist");
            this.db.exec("DELETE FROM videos WHERE in_playlist='1' ");
        }
        catch (Exception ex) {}
    }

    public void insertVideos(ArrayList<Video> videos) {
        if (videos.size()>0) {
            for(Video video:videos) {
                this.insertVideo(video);
            }
        }
    }

    private void insertVideo(Video video) {
        try {
            if (!this.existsInsertedVideo(video)) {
                String query = video.toSQL();
                this.db.exec(query);
            }
        }
        catch (Exception ex) {
            ex.printStackTrace();
        }
    }

    private boolean existsInsertedVideo(Video video) {
        boolean result = false;
        try {
            String query  = "SELECT COUNT(*) FROM videos WHERE id='"+video.getId()+"'";
            Cursor cursor = this.db.query(query);
            if (cursor.moveToFirst()) {
                int count     = cursor.getInt(0);
                if (count>0) {
                    result = true;
                }
            }
            cursor.close();
        }
        catch (Exception ex) { }
        return result;
    }


    public void insertVideosInPlayList(VideoPlayList playList,ArrayList<Video> videos) {
        if (videos.size()>0) {
            for(Video video:videos) {
                this.insertVideoIntoPlayList(playList.getId(), video.getId());
            }
        }
    }

    private void insertVideoIntoPlayList(String id_playlist,String id_video) {
        try {
            if (!this.existsInsertedInPlayList(id_playlist,id_video)) {
                String query = "INSERT INTO video_in_playlist(id_playlist,id_video) VALUES ('" + id_playlist + "','" + id_video + "')";
                this.db.exec(query);


            }
        }
        catch (Exception ex) {
            ex.printStackTrace();
        }
    }

    private boolean existsInsertedInPlayList(String id_playlist, String id_video) {
        boolean result = false;
        try {
            String query  = "SELECT COUNT(*) FROM video_in_playlist WHERE (id_playlist='"+id_playlist+"' AND id_video='"+id_video+"' )";
            Cursor cursor = this.db.query(query);
            if (cursor.moveToFirst()) {
                int count     = cursor.getInt(0);
                if (count>0) {
                    result = true;
                }
            }
            cursor.close();
        }
        catch (Exception ex) { }
        return result;
    }

    public boolean haveVideos() {
        boolean result = false;
        try {
            String query  = "SELECT COUNT(*) FROM videos";
            Cursor cursor = this.db.query(query);
            if (cursor.moveToFirst()) {
                int count     = cursor.getInt(0);
                if (count>0) {
                    result = true;
                }
            }
            cursor.close();
        }
        catch (Exception ex) { }
        return result;
    }

    public boolean havePlaylists() {
        boolean result = false;
        try {
            String query  = "SELECT COUNT(*) FROM video_in_playlist";
            Cursor cursor = this.db.query(query);
            if (cursor.moveToFirst()) {
                int count     = cursor.getInt(0);
                if (count>0) {
                    result = true;
                }
            }
            cursor.close();
        }
        catch (Exception ex) { }
        return result;
    }





    public void insertPlaylists(ArrayList<VideoPlayList> playlists) {
        if (playlists.size()>0) {
            for(VideoPlayList playlist:playlists) {
                this.insertPlayList(playlist);
            }
        }
    }

    private void insertPlayList(VideoPlayList playlist) {
        try {
            String  query = playlist.toSQL();
            this.db.exec(query);
        }
        catch (Exception ex) { }
    }


    public VideoPlayList getPlayList(String id) {
        VideoPlayList playList = new VideoPlayList();
        String query  = "SELECT * FROM video_playlist WHERE id='"+id+"' ";
        Cursor cursor = this.db.query(query);
        if (cursor != null) {
            if (cursor.moveToFirst()) {
                playList = new VideoPlayList(cursor.getString(0),cursor.getString(1),cursor.getString(2),cursor.getString(3),cursor.getString(4),cursor.getString(5));
            }
            cursor.close();
        }
        return playList;
    }
}
