package com.andreums.culturarocafort.fragments.events;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.os.Bundle;
import android.support.v4.app.Fragment;
import android.support.v4.app.FragmentActivity;
import android.support.v7.app.ActionBar;
import android.support.v7.app.ActionBarActivity;
import android.view.LayoutInflater;
import android.view.Menu;
import android.view.MenuInflater;
import android.view.MenuItem;
import android.view.View;
import android.view.ViewGroup;
import android.widget.AdapterView;
import android.widget.ListView;
import android.widget.Toast;

import com.andreums.culturarocafort.Constants;
import com.andreums.culturarocafort.MainActivity;
import com.andreums.culturarocafort.R;
import com.andreums.culturarocafort.adapters.events.EventCategoryAdapter;
import com.andreums.culturarocafort.database.CategoryDatabaseHandler;
import com.andreums.culturarocafort.models.EventCategory;
import com.andreums.culturarocafort.services.CategoryDownloaderService;
import com.andreums.culturarocafort.util.DataStorage;



import java.util.ArrayList;

public class EventCategoriesFragment extends Fragment {

    private static Bundle savedInstance;
    private ListView list;
    private EventCategoryBroadcastReceiver receiver;
    private static boolean isRegistered;

    @Override
    public void onCreate (Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setHasOptionsMenu(true);
    }
    @Override
    public void onStop() {
        super.onStop();
        onSaveInstanceState(new Bundle());
    }



    @Override
    public void onPause() {
        super.onPause();
        try {
            if (EventCategoriesFragment.isRegistered) {
                if (this.receiver!=null) {
                    getActivity().unregisterReceiver(this.receiver);
                    EventCategoriesFragment.isRegistered = false;
                    this.receiver = null;
                }
            }
        }
        catch(Exception e) {
            e.printStackTrace();
        }
    }



    @Override
    public void onResume() {
        super.onResume();
        this.setActionBar();
        ArrayList<EventCategory> categories = this.getCategoriesFromDatabase();
        if (categories.size()>0) {
            this.setItemsInListview(categories);
        }
    }



    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container,Bundle savedInstanceState) {
        this.startService();

        View view = inflater.inflate(R.layout.event_category_fragment, container, false);
        this.list = (ListView) view.findViewById(R.id.event_category_list);
        this.list.setEmptyView(view.findViewById(R.id.event_category_empty));

        ArrayList<EventCategory> categories = this.getCategoriesFromDatabase();
        if (categories.size()>0) {
            this.setItemsInListview(categories);
        }
        this.startProgressBarAnimation();
        this.startService();

        return view;
    }

    private void setItemsInListview(final ArrayList<EventCategory> items) {
        this.list.setOnItemClickListener(
                new AdapterView.OnItemClickListener() {
                    @Override
                    public void onItemClick(AdapterView<?> adapterView, View view, int i, long l) {
                        EventCategory item = (EventCategory) EventCategoriesFragment.this.list.getItemAtPosition(i);

                        Bundle arguments = new Bundle();
                        arguments.putInt("category", item.getId());
                        EventCategoryViewerFragment fragment = new EventCategoryViewerFragment();
                        fragment.setArguments(arguments);

                        if (MainActivity.mTwoPane) {
                            EventCategoriesFragment.this.getActivity().getSupportFragmentManager().beginTransaction().replace(R.id.item_detail_container, fragment).addToBackStack(null).commit();
                        }
                        else {
                            EventCategoriesFragment.this.getActivity().getSupportFragmentManager().beginTransaction().replace(R.id.content_frame, fragment).addToBackStack(null).commit();
                        }
                        MainActivity.displayedFragment = fragment;
                    }
                }
        );

        FragmentActivity parentActivity = getActivity();
        if(parentActivity != null) parentActivity.runOnUiThread(new Runnable() {

            @Override
            public void run() {
                EventCategoriesFragment.this.list.setAdapter(new EventCategoryAdapter(getActivity(), R.layout.event_category_item,items));

                int index = -1;
                int top   = 0;

                if (EventCategoriesFragment.savedInstance != null) {
                    // Restore last state for checked position.
                    index = EventCategoriesFragment.savedInstance.getInt("index", -1);
                    top   = EventCategoriesFragment.savedInstance.getInt("top", 0);
                }
                if(index!=-1){
                    final int finalIndex = index;
                    final int finalTop = top;
                    EventCategoriesFragment.this.list.setSelectionFromTop(finalIndex, finalTop);
                }
            }
        });
    }

    @Override
    public void onCreateOptionsMenu(Menu menu, MenuInflater inflater) {
        inflater.inflate(R.menu.menu_fragments, menu);
    }


    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        super.onOptionsItemSelected(item);
        switch (item.getItemId()) {

            case R.id.action_refresh:
                Toast.makeText(this.getActivity().getApplicationContext(), getResources().getString(R.string.action_refresh), Toast.LENGTH_SHORT).show();

                this.startProgressBarAnimation();
                this.startService();
                break;

            default:
                return super.onOptionsItemSelected(item);
        }

        return true;
    }


    private void startService() {
        try {
            IntentFilter intentFilter = new IntentFilter("com.andreums.culturarocafort.downloaded.categories");
            intentFilter.addCategory(Intent.CATEGORY_DEFAULT);

            if ( (!EventCategoriesFragment.isRegistered) && (this.receiver==null) ) {
                this.receiver             = new EventCategoryBroadcastReceiver();
                getActivity().registerReceiver(this.receiver, intentFilter);
                EventCategoriesFragment.isRegistered = true;
            }

            Intent intent = new Intent(this.getActivity(), CategoryDownloaderService.class);
            intent.putExtra("url", Constants.getCategoriesURL(getActivity().getApplicationContext()));
            getActivity().startService(intent);


        }
        catch (Exception ex) {}
    }


    private ArrayList<EventCategory> getCategoriesFromDatabase() {
        CategoryDatabaseHandler handler   = CategoryDatabaseHandler.getInstance(EventCategoriesFragment.this.getActivity().getApplicationContext());
        ArrayList<EventCategory> items    = handler.getEventCategories();
        return items;
    }


    private void setActionBar() {
        ActionBar bar = ( (ActionBarActivity) getActivity()).getSupportActionBar();
        bar.setIcon(R.drawable.ic_launcher);
        bar.setHomeButtonEnabled(true);
        bar.setDisplayHomeAsUpEnabled(true);
        bar.setTitle(getResources().getString(R.string.bar_categories_title));
    }

    @Override
    public void setUserVisibleHint(boolean isVisibleToUser) {
        super.setUserVisibleHint(isVisibleToUser);
        if (isVisibleToUser) {
            this.setActionBar();
        }
    }

    private class EventCategoryBroadcastReceiver extends BroadcastReceiver {

        @Override
        public void onReceive(Context context, Intent intent) {
            ArrayList<EventCategory> categories  = DataStorage.getEventCategories();
            EventCategoriesFragment.this.setItemsInListview(categories);
            EventCategoriesFragment.this.stopProgressBarAnimation();
        }

    }


    void startProgressBarAnimation() {
        DataStorage.pushProcess();
        this.getActivity().setProgressBarIndeterminateVisibility(true);

    }

    void stopProgressBarAnimation() {
        DataStorage.popProcess();
        this.getActivity().setProgressBarIndeterminateVisibility(false);
    }


    @Override
    public void onSaveInstanceState(Bundle outState) {

        int index = this.list.getFirstVisiblePosition();
        View v    = this.list.getChildAt(0);
        int top   = (v == null) ? 0 : v.getTop();

        outState.putInt("index", index);
        outState.putInt("top", top);

        EventCategoriesFragment.savedInstance = outState;
        super.onSaveInstanceState(outState);
    }

}