package com.andreums.culturarocafort.fragments.events;


import android.os.Bundle;
import android.support.v4.app.Fragment;
import android.support.v4.app.FragmentActivity;
import android.support.v7.app.ActionBar;
import android.support.v7.app.ActionBarActivity;
import android.view.LayoutInflater;
import android.view.Menu;
import android.view.MenuInflater;
import android.view.MenuItem;
import android.view.View;
import android.view.ViewGroup;
import android.widget.AdapterView;
import android.widget.ListView;
import android.widget.TextView;

import com.andreums.culturarocafort.MainActivity;
import com.andreums.culturarocafort.R;
import com.andreums.culturarocafort.adapters.events.EventsAdapter;
import com.andreums.culturarocafort.database.CategoryDatabaseHandler;
import com.andreums.culturarocafort.database.EventDatabaseHandler;
import com.andreums.culturarocafort.models.Event;
import com.andreums.culturarocafort.models.EventCategory;
import com.andreums.culturarocafort.views.events.EventItemView;
import com.andreums.culturarocafort.views.events.IListViewItem;



import java.util.ArrayList;

public class EventCategoryViewerFragment extends Fragment {

    private static Bundle savedInstance;
    private ListView list;


    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container,Bundle savedInstanceState) {
        this.setHasOptionsMenu(true);
        View view = inflater.inflate(R.layout.event_category_activity,container, false);

        EventCategory category = this.getCategoryFromIntent();
        ArrayList<IListViewItem> events = this.getCategoryEvents(category.getId());

        this.list = (ListView) view.findViewById(R.id.event_category_list);
        this.list.setEmptyView(view.findViewById(R.id.event_category_empty));
        this.list.addHeaderView(inflater.inflate(R.layout.event_category_header,null));

        this.setActionbar(category);

        view = this.setCategoryData(view,category,events);

        return view;
    }



    private void setActionbar(EventCategory category) {
        ActionBar bar = ( (ActionBarActivity) getActivity()).getSupportActionBar();
        bar.setIcon(R.drawable.ic_launcher);
        bar.setHomeButtonEnabled(true);
        bar.setDisplayHomeAsUpEnabled(true);
        bar.setTitle(category.getTitle());
    }

    private ArrayList<IListViewItem> getCategoryEvents(int id) {
        EventDatabaseHandler handler       = EventDatabaseHandler.getInstance(this.getActivity().getApplicationContext());
        ArrayList<IListViewItem> events    = handler.getEventsByCategoryId(id);
        return events;
    }


    private EventCategory getCategoryFromIntent() {
        Bundle extras = getArguments();
        int id        = extras.getInt("category", 0);

        CategoryDatabaseHandler handler = CategoryDatabaseHandler.getInstance(this.getActivity().getApplicationContext());
        EventCategory category          = handler.getEventCategory(id);
        return category;
    }



    private View setCategoryData(View view,EventCategory category, final ArrayList<IListViewItem> events) {

        TextView title = (TextView) view.findViewById(R.id.event_category_title);
        title.setText(category.getTitle());


        /*TextView description = (TextView) findViewById(R.id.event_category_description);
        String desc = category.getDescription();
        if ( (desc!=null) && (desc.length()>0) ) {
            description.setText(category.getDescription());
            description.setVisibility(View.VISIBLE);
        }*/




        list.setOnItemClickListener(
                new AdapterView.OnItemClickListener() {
                    @Override
                    public void onItemClick(AdapterView<?> adapterView, View view, int i, long l) {
                        IListViewItem item = (IListViewItem) EventCategoryViewerFragment.this.list.getItemAtPosition(i);
                        if ( (item!=null) && (item.getViewType()==0)) {
                            Event event = ((EventItemView) item).getEvent();
                            int id      = event.getId();

                            Bundle arguments = new Bundle();
                            arguments.putInt("event",id);
                            EventViewerFragment fragment = new EventViewerFragment();
                            fragment.setArguments(arguments);


                            if (MainActivity.mTwoPane) {
                                EventCategoryViewerFragment.this.getActivity().getSupportFragmentManager().beginTransaction().replace(R.id.item_detail_container, fragment).addToBackStack(null).commit();
                            }
                            else {
                                EventCategoryViewerFragment.this.getActivity().getSupportFragmentManager().beginTransaction().replace(R.id.content_frame, fragment).addToBackStack(null).commit();
                            }
                            MainActivity.displayedFragment = fragment;
                        }
                    }
                }
        );

        FragmentActivity parentActivity = getActivity();
        if(parentActivity != null) parentActivity.runOnUiThread(new Runnable() {

            @Override
            public void run() {
                EventCategoryViewerFragment.this.list.setAdapter(new EventsAdapter(EventCategoryViewerFragment.this.getActivity().getApplicationContext(),R.layout.event_list_item,events));

                int index = -1;
                int top   = 0;

                if (EventCategoryViewerFragment.savedInstance != null) {
                    // Restore last state for checked position.
                    index = EventCategoryViewerFragment.savedInstance.getInt("index", -1);
                    top   = EventCategoryViewerFragment.savedInstance.getInt("top", 0);
                }
                if(index!=-1){
                    final int finalIndex = index;
                    final int finalTop = top;
                    EventCategoryViewerFragment.this.list.setSelectionFromTop(finalIndex, finalTop);
                }
            }
        });
        return view;
    }


    @Override
    public void onCreateOptionsMenu(Menu menu, MenuInflater inflater) {
        //inflater.inflate(R.menu.menu_main, menu);
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        super.onOptionsItemSelected(item);
        switch (item.getItemId()) {

            case android.R.id.home:
                this.getActivity().finish();
                return true;

            default:
                break;
        }

        return true;
    }


    @Override
    public void onSaveInstanceState(Bundle outState) {

        int index = this.list.getFirstVisiblePosition();
        View v    = this.list.getChildAt(0);
        int top   = (v == null) ? 0 : v.getTop();

        outState.putInt("index", index);
        outState.putInt("top", top);

        EventCategoryViewerFragment.savedInstance = outState;
        super.onSaveInstanceState(outState);
    }


}
