package com.andreums.culturarocafort.fragments.events;

import android.content.Intent;
import android.net.Uri;
import android.os.AsyncTask;
import android.os.Bundle;
import android.provider.CalendarContract;
import android.support.v4.app.Fragment;
import android.support.v7.app.ActionBar;
import android.support.v7.app.ActionBarActivity;
import android.text.Html;
import android.util.DisplayMetrics;
import android.view.LayoutInflater;
import android.view.Menu;
import android.view.MenuInflater;
import android.view.MenuItem;
import android.view.View;
import android.view.ViewGroup;
import android.webkit.WebSettings;
import android.webkit.WebView;
import android.widget.ImageView;
import android.widget.TextView;
import android.widget.Toast;

import com.andreums.culturarocafort.R;
import com.andreums.culturarocafort.activities.photos.ImageViewerActivity;
import com.andreums.culturarocafort.database.EventDatabaseHandler;
import com.andreums.culturarocafort.database.GeocoderDatabaseHandler;
import com.andreums.culturarocafort.models.Event;
import com.andreums.culturarocafort.models.LatLng;
import com.andreums.culturarocafort.util.Connection;
import com.andreums.culturarocafort.util.DateUtils;
import com.andreums.culturarocafort.util.Downloader;
import com.andreums.culturarocafort.util.HTML;
import com.andreums.culturarocafort.util.StaticMaps;


import com.squareup.picasso.Picasso;

import org.apache.commons.lang3.StringEscapeUtils;
import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import java.io.UnsupportedEncodingException;
import java.lang.reflect.InvocationTargetException;
import java.net.URLEncoder;
import java.util.Date;

public class EventViewerFragment extends Fragment {

    private String dataToShare;
    private Event event;
    private double lat;
    private double lng;
    private WebView content;

    @Override
    public void onResume() {
        super.onResume();
        this.setActionbar();
    }

    @Override
    public void onPause() {
        super.onPause();
        this.stopWebView();
    }

    private void stopWebView() {
        try {
            Class.forName("android.webkit.WebView").getMethod("onPause", (Class[]) null).invoke(this.content, (Object[]) null);

        }
        catch(ClassNotFoundException cnfe) {

        }
        catch(NoSuchMethodException nsme) {

        }
        catch(InvocationTargetException ite) {

        }
        catch (IllegalAccessException iae) {

        }
    }

    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        this.event = this.getEventFromIntent();
    }

    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container,Bundle savedInstanceState) {
        this.setHasOptionsMenu(true);
        View view  = inflater.inflate(R.layout.event_viewer_activity,container, false);

        if (this.event!=null) {
            view = this.setInterface(view);
            view = this.setMap(view);
            this.setActionbar();
        }

        return view;
    }


    private View setInterface(View view) {

        TextView title = (TextView) view.findViewById(R.id.event_title);
        title.setText(StringEscapeUtils.unescapeHtml4(this.event.getTitle()));

        TextView date  = (TextView) view.findViewById(R.id.event_date);
        TextView start = (TextView) view.findViewById(R.id.event_label_start);
        TextView end   = (TextView) view.findViewById(R.id.event_label_end);

        start.setText(DateUtils.convertToEventDate(this.event.getStart_date()));
        end.setText(DateUtils.convertToEventDate(this.event.getEnd_date()));
        date.setText(DateUtils.convertToPostDate(this.event.getDate()));

        TextView place = (TextView) view.findViewById(R.id.event_label_place);
        TextView venue = (TextView) view.findViewById(R.id.event_label_venue);
        place.setText(StringEscapeUtils.unescapeHtml4(this.event.getAddress()));
        venue.setText(StringEscapeUtils.unescapeHtml4(this.event.getVenue()));

        TextView calendar = (TextView) view.findViewById(R.id.event_add_calendar);
        calendar.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                EventViewerFragment.this.addEventToCalendar();
            }
        });


        TextView map = (TextView) view.findViewById(R.id.event_view_map);
        map.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                EventViewerFragment.this.viewEventInMap();
            }
        });




        view = this.setEventContents(view);
        view = this.setEventImage(view);


        return view;
    }

    private View setEventContents(View view) {
        String data = this.event.getContent();

        this.content = (WebView) view.findViewById(R.id.event_content);

        if (data!=null && data.length()==0) {
            data = getResources().getString(R.string.event_no_content);
        }

        data = HTML.getCleanHTML(data, this.getScreenWidth());
        this.dataToShare = Html.fromHtml(data).toString();

        try {
            WebSettings settings = this.content.getSettings();
            String appCachePath = this.getActivity().getApplicationContext().getCacheDir().getAbsolutePath();
            settings.setAppCachePath(appCachePath);
            settings.setAppCacheEnabled(true);
            settings.setAppCacheMaxSize(30 * 1024 * 10);
            settings.setJavaScriptEnabled(true);
            settings.setPluginState(WebSettings.PluginState.ON);
        }
        catch (Exception e) {
            e.printStackTrace();
        }

        data = HTML.getContentsAsHTML(data, this.getScreenWidth());
        this.content.loadDataWithBaseURL("http://cultura.rocafort.es", data, "text/html", "UTF-8", "");
        return view;
    }

    private View setEventImage(View view) {
        ImageView image = (ImageView) view.findViewById(R.id.event_image);
        image.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                EventViewerFragment.this.viewImage();
            }
        });

        if (this.event.getImage()!=null && this.event.getImage().length()>0) {
            String      img = event.getImage();
            if (img.equals("assets://images/placeholder.png")) {
                image.setScaleType(ImageView.ScaleType.CENTER_INSIDE);
                image.setImageDrawable(getResources().getDrawable(R.drawable.placeholder_big));
            }
            else  {
                Picasso.with(this.getActivity().getApplicationContext()).load(img).placeholder(R.drawable.ic_launcher).error(R.drawable.ic_launcher).into(image);
            }
        }
        return view;
    }


    private void setActionbar() {
        ActionBar bar = ( (ActionBarActivity) getActivity()).getSupportActionBar();
        bar.setIcon(R.drawable.ic_launcher);
        bar.setHomeButtonEnabled(true);
        bar.setDisplayHomeAsUpEnabled(true);
        bar.setTitle(StringEscapeUtils.unescapeHtml4(this.event.getTitle()));
    }

    private void updateMap(LatLng result) {
        StaticMaps maps = new StaticMaps();
        String url      = maps.getURLForImageAtPosition(result,this.getScreenWidth(),300);
        ImageView image = (ImageView) this.getView().findViewById(R.id.event_map);
        Picasso.with(this.getActivity().getApplicationContext()).load(url).placeholder(R.drawable.ic_launcher).error(R.drawable.ic_launcher).into(image);
    }



    private View setMap(View view) {
        String address                  = this.event.getAddress();
        GeocoderDatabaseHandler handler = new GeocoderDatabaseHandler(this.getActivity().getApplicationContext());
        if (!handler.hasPosition(address)) {
            new GeocoderTask().execute(address);
        }
        else {
            LatLng latLng  = this.getLatLongFromAddress(address);
            StaticMaps maps = new StaticMaps();
            String url      = maps.getURLForImageAtPosition(latLng,this.getScreenWidth(),300);
            ImageView image = (ImageView) view.findViewById(R.id.event_map);

            Picasso.with(this.getActivity().getApplicationContext()).load(url).placeholder(R.drawable.ic_launcher).error(R.drawable.ic_launcher).into(image);
            image.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {
                    EventViewerFragment.this.viewEventInMap();
                }
            });

        }

        return view;
    }

    @Override
    public void onCreateOptionsMenu(Menu menu, MenuInflater inflater) {
        inflater.inflate(R.menu.event_viewer_menu, menu);
        MenuItem favoriteItem = menu.findItem(R.id.action_favorite);

        if (this.isFavorited()) {
            favoriteItem.setIcon(getResources().getDrawable(R.drawable.ic_favorite_on));
        }
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {

        switch (item.getItemId()) {
            case R.id.action_share:
                this.shareItem();
                break;

            case android.R.id.home:
                return true;

            case R.id.action_map:
                this.viewEventInMap();
            break;

            case R.id.action_calendar:
                this.addEventToCalendar();
            break;

            case R.id.action_here:
                this.sendHere();
            break;


            case R.id.action_favorite:
                if (!this.isFavorited()) {
                    this.addToFavorites();
                    Toast.makeText(this.getActivity(), this.getActivity().getResources().getString(R.string.event_action_favorited),Toast.LENGTH_LONG).show();
                    item.setIcon(getResources().getDrawable(R.drawable.ic_favorite_on));
                }
                else {
                    this.deleteFromFavorites();
                    Toast.makeText(this.getActivity(), this.getActivity().getResources().getString(R.string.event_action_unfavorited),Toast.LENGTH_LONG).show();
                    item.setIcon(getResources().getDrawable(R.drawable.ic_favorite_off));
                }
            break;




            default:
                break;
        }

        return true;
    }

    void sendHere() {

        String title         = StringEscapeUtils.unescapeHtml4(this.event.getTitle())+" "+this.event.getUrl();

        String header        = getResources().getString(R.string.event_here_header);
        String via           = getResources().getString(R.string.event_here_via);

        String text          = header+" "+title+". "+via;
        Intent sharingIntent = new Intent(Intent.ACTION_SEND);
        sharingIntent.setType("text/plain");
        sharingIntent.putExtra(Intent.EXTRA_TEXT, text);
        startActivity(Intent.createChooser(sharingIntent, getResources().getString(R.string.event_here_with)));
    }

    private void deleteFromFavorites() {
        EventDatabaseHandler handler = EventDatabaseHandler.getInstance(this.getActivity());
        handler.deleteFavoriteEvent(this.event.getId());
    }

    private void addToFavorites() {
        EventDatabaseHandler handler = EventDatabaseHandler.getInstance(this.getActivity());
        handler.insertFavoriteEvent(this.event.getId());
    }

    private boolean isFavorited() {
        EventDatabaseHandler handler = EventDatabaseHandler.getInstance(this.getActivity());
        return handler.isFavorited(this.event.getId());
    }


    private int getScreenWidth() {
        DisplayMetrics dm = new DisplayMetrics();
        EventViewerFragment.this.getActivity().getWindowManager().getDefaultDisplay().getMetrics(dm);
        return (int) Math.round((dm.widthPixels)-(dm.widthPixels/2.50));
    }



    private Event getEventFromIntent() {
        Event event;
        Bundle extras = getArguments();
        int id                       = extras.getInt("event", 0);
        EventDatabaseHandler handler = EventDatabaseHandler.getInstance(this.getActivity().getApplicationContext());
        event                        = handler.getEvent(id);
        this.event                   = event;
        return event;
    }



    private void shareItem() {
        String title         = StringEscapeUtils.unescapeHtml4(this.event.getTitle());
        String description   = Html.fromHtml((StringEscapeUtils.unescapeHtml4(this.event.getContent()))).toString();
        String venue         = StringEscapeUtils.unescapeHtml4(this.event.getVenue()+" "+this.event.getAddress());
        String start         = DateUtils.convertToEventDate(this.event.getStart_date());
        String end           = DateUtils.convertToEventDate(this.event.getEnd_date());

        String header        = getResources().getString(R.string.event_share_header);
        String footer        = getResources().getString(R.string.event_share_read_more)+this.event.getUrl()+getResources().getString(R.string.event_share_more);

        String text          = header+title+getResources().getString(R.string.event_share_start)+start+getResources().getString(R.string.event_share_end)+end+getResources().getString(R.string.event_share_place)+venue+"\n\n"+description+"\n\n"+footer;
        Intent sharingIntent = new Intent(Intent.ACTION_SEND);
        sharingIntent.setType("text/plain");
        sharingIntent.putExtra(Intent.EXTRA_TEXT,text);
        startActivity(Intent.createChooser(sharingIntent, getResources().getString(R.string.event_share_with)));
    }

    void viewImage() {
        Intent intent = new Intent(this.getActivity(),ImageViewerActivity.class);
        intent.putExtra("url",this.event.getImage());
        startActivity(intent);
    }

    void viewEventInMap() {
        try {
            String uri = "geo:"+this.lat+","+this.lng+"?q="+StringEscapeUtils.unescapeHtml4(this.event.getAddress());
            startActivity(new Intent(Intent.ACTION_VIEW, Uri.parse(uri)));
        }
        catch (Exception ex) {
            Toast.makeText(this.getActivity().getApplicationContext(),"Google Maps APP is not Installed",Toast.LENGTH_LONG).show();
        }

    }

    void addEventToCalendar() {
        Date start = this.event.getStartAsDate();
        Date end   = this.event.getEndAsDate();

        Intent intent = new Intent(Intent.ACTION_EDIT);
        intent.setType("vnd.android.cursor.item/event");
        intent.putExtra("beginTime",start.getTime());
        intent.putExtra("allDay",false);
        intent.putExtra("description",StringEscapeUtils.unescapeHtml4(this.dataToShare));
        intent.putExtra(CalendarContract.Events.EVENT_LOCATION,StringEscapeUtils.unescapeHtml4(this.event.getAddress()));
        intent.putExtra("endTime",end.getTime());
        intent.putExtra("title",StringEscapeUtils.unescapeHtml4(this.event.getTitle()));
        startActivity(intent);
    }


    private LatLng getLatLongFromAddress(String address)  {
        LatLng result = StaticMaps.getLatLongFromAddress(this.getActivity().getApplicationContext(), address);
        this.lat      = result.latitude();
        this.lng      = result.longitude();

        return result;
    }

    public void openInBrowser() {
        String url    = this.event.getUrl();
        Intent intent = new Intent(Intent.ACTION_VIEW);
        intent.setData(Uri.parse(url));
        startActivity(intent);
    }


    private class GeocoderTask extends AsyncTask<String, Void, LatLng> {
        @Override
        protected LatLng doInBackground(String... addresses) {
            double lat;
            double lng;
            LatLng result   = new LatLng(0,0);
            String address  = addresses[0];
            String copyAd   = address;

            if (Connection.getConnectionStatus(EventViewerFragment.this.getActivity().getApplicationContext())) {
                try {
                    address = URLEncoder.encode(address, "UTF-8");
                }
                catch (UnsupportedEncodingException e) {
                    e.printStackTrace();
                }

                String url            = "http://maps.google.com/maps/api/geocode/json?address="+address+"&sensor=true";
                Downloader downloader = new Downloader(url);
                downloader.invoke();
                String mResult        = downloader.getResult();

                JSONObject jsonObject;
                try {
                    jsonObject = new JSONObject(mResult);
                    lng        = ((JSONArray)jsonObject.get("results")).getJSONObject(0).getJSONObject("geometry").getJSONObject("location").getDouble("lng");
                    lat        = ((JSONArray)jsonObject.get("results")).getJSONObject(0).getJSONObject("geometry").getJSONObject("location").getDouble("lat");
                    result     = new LatLng(lat,lng);
                }
                catch (JSONException e) {
                    e.printStackTrace();
                }

                GeocoderDatabaseHandler handler = new GeocoderDatabaseHandler(EventViewerFragment.this.getActivity().getApplicationContext());
                handler.insertAddress(copyAd,result);
            }

            return result;
        }

        @Override
        protected void onPostExecute(LatLng result) {
            EventViewerFragment.this.updateMap(result);
        }
    }




}
