package com.andreums.culturarocafort.fragments.events;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.os.Bundle;
import android.support.v4.app.Fragment;
import android.support.v4.app.FragmentActivity;
import android.support.v7.app.ActionBar;
import android.support.v7.app.ActionBarActivity;
import android.view.LayoutInflater;
import android.view.Menu;
import android.view.MenuInflater;
import android.view.MenuItem;
import android.view.View;
import android.view.ViewGroup;
import android.widget.AdapterView;
import android.widget.ListView;
import android.widget.Toast;

import com.andreums.culturarocafort.Constants;
import com.andreums.culturarocafort.MainActivity;
import com.andreums.culturarocafort.R;
import com.andreums.culturarocafort.adapters.events.EventsAdapter;
import com.andreums.culturarocafort.database.EventDatabaseHandler;
import com.andreums.culturarocafort.models.Event;
import com.andreums.culturarocafort.services.EventsDownloadService;
import com.andreums.culturarocafort.util.DataStorage;
import com.andreums.culturarocafort.util.DateUtils;
import com.andreums.culturarocafort.views.events.EventHeaderView;
import com.andreums.culturarocafort.views.events.EventItemView;
import com.andreums.culturarocafort.views.events.IListViewItem;



import java.util.ArrayList;
import java.util.List;

public class EventsFragment extends Fragment {

    private static Bundle savedInstance;
    private ListView list;
    private EventsDownloadBroadcastReceiver receiver;
    private static boolean isRegistered;



    @Override
    public void onCreate (Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setRetainInstance(true);
        setHasOptionsMenu(true);

    }

    @Override
    public void onStop() {
        super.onStop();
        onSaveInstanceState(new Bundle());
    }


    @Override
    public void onPause() {
        super.onPause();
        try {
            if (EventsFragment.isRegistered) {
                getActivity().unregisterReceiver(this.receiver);
                EventsFragment.isRegistered = false;
                this.receiver               = null;
            }
        }
        catch(Exception e) {
            e.printStackTrace();
        }
    }


    @Override
    public void onResume() {
        super.onResume();
        this.setActionBar();
        ArrayList<IListViewItem> events = this.getEventsFromDatabase();
        if (events.size()>0) {
            this.setItemsOnListView(events);
        }
        this.startService();
    }

    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container,Bundle savedInstanceState) {
        View view = inflater.inflate(R.layout.events_fragment, container, false);


        this.list = (ListView) view.findViewById(R.id.events_list);
        this.list.setEmptyView(view.findViewById(R.id.events_empty));

        ArrayList<IListViewItem> events = this.getEventsFromDatabase();
        if (events.size()>0) {
            this.setItemsOnListView(events);
        }
        this.startProgressBarAnimation();
        this.startService();

        return view;
    }


    @Override
    public void onCreateOptionsMenu(Menu menu, MenuInflater inflater) {
        inflater.inflate(R.menu.menu_events_fragment, menu);
    }


    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        super.onOptionsItemSelected(item);
        switch (item.getItemId()) {

            case R.id.action_refresh:
                Toast.makeText(this.getActivity().getApplicationContext(), getResources().getString(R.string.action_refresh), Toast.LENGTH_SHORT).show();

                this.startProgressBarAnimation();
                this.startService();
                break;

            case R.id.action_favorite_events:
                FavoriteEventsFragment fragment = new FavoriteEventsFragment();
                EventsFragment.this.getActivity().getSupportFragmentManager().beginTransaction().replace(R.id.content_frame, fragment).addToBackStack(null).commit();
                MainActivity.displayedFragment = fragment;
                break;
            default:
                return super.onOptionsItemSelected(item);
        }

        return true;
    }

        private void startService() {
            try {
                IntentFilter intentFilter = new IntentFilter("com.andreums.culturarocafort.downloaded.events");

                if (!EventsFragment.isRegistered && this.receiver==null) {
                    this.receiver             = new EventsDownloadBroadcastReceiver();
                    getActivity().registerReceiver(this.receiver, intentFilter);
                    EventsFragment.isRegistered = true;
                }
                Intent intent = new Intent(this.getActivity(), EventsDownloadService.class);
                intent.putExtra("url", Constants.getEventsURL(getActivity().getApplicationContext()));
                getActivity().startService(intent);
            }
            catch (Exception ex) { }
        }

        private void setItemsOnListView(final ArrayList<IListViewItem> items) {

            this.list.setOnItemClickListener(
                    new AdapterView.OnItemClickListener() {
                        @Override
                        public void onItemClick(AdapterView<?> adapterView, View view, int i, long l) {
                            IListViewItem item = (IListViewItem) EventsFragment.this.list.getItemAtPosition(i);
                            if ( (item!=null) && (item.getViewType()==0) ) {
                                Event event = ((EventItemView) item).getEvent();
                                if (event!=null) {
                                    int id      = event.getId();

                                    Bundle arguments = new Bundle();
                                    arguments.putInt("event",id);
                                    EventViewerFragment fragment = new EventViewerFragment();
                                    fragment.setArguments(arguments);


                                    if (MainActivity.mTwoPane) {
                                        EventsFragment.this.getActivity().getSupportFragmentManager().beginTransaction().replace(R.id.item_detail_container, fragment).addToBackStack(null).commit();
                                    }
                                    else {
                                        EventsFragment.this.getActivity().getSupportFragmentManager().beginTransaction().replace(R.id.content_frame, fragment).addToBackStack(null).commit();
                                    }
                                    MainActivity.displayedFragment = fragment;
                                }
                            }
                        }
                    }
            );

            FragmentActivity parentActivity = getActivity();
            if(parentActivity != null) parentActivity.runOnUiThread(new Runnable() {

                @Override
                public void run() {
                    EventsFragment.this.list.setAdapter(new EventsAdapter(getActivity(), R.layout.post_item, items));

                    int index = -1;
                    int top   = 0;

                    if (EventsFragment.savedInstance != null) {
                        index = EventsFragment.savedInstance.getInt("index", -1);
                        top   = EventsFragment.savedInstance.getInt("top", 0);
                    }
                    if(index!=-1){
                        final int finalIndex = index;
                        final int finalTop = top;
                        EventsFragment.this.list.setSelectionFromTop(finalIndex, finalTop);
                    }
                }
            });
        }

        private ArrayList<IListViewItem> getEventsFromDatabase() {
            ArrayList<Event> events;
            EventDatabaseHandler handler    = EventDatabaseHandler.getInstance(getActivity().getBaseContext());
            events                          = handler.getEventsListView();
            return this.transformEventsForListview(events);
        }

        private ArrayList<IListViewItem> transformEventsForListview(List<Event> items) {
            ArrayList<IListViewItem> events       = new ArrayList<IListViewItem>();
            if (items.size()>0) {
                Event aux                             = items.get(0);
                String date                           = DateUtils.convertDateFormat(aux.getStart_date());

                events.add(new EventHeaderView(date));
                for (Event event:items) {
                    aux            = event;

                    String auxDate = DateUtils.convertDateFormat(aux.getStart_date());
                    if (!date.equals(auxDate)) {
                        events.add(new EventHeaderView(auxDate));
                        date = auxDate;
                    }
                    events.add(new EventItemView(aux));
                }
            }
            return events;
        }


    private void setActionBar() {
        ActionBar bar = ( (ActionBarActivity) getActivity()).getSupportActionBar();
        bar.setIcon(R.drawable.ic_launcher);
        bar.setHomeButtonEnabled(true);
        bar.setDisplayHomeAsUpEnabled(true);
        bar.setTitle(getResources().getString(R.string.bar_events_title));
    }

    @Override
    public void setUserVisibleHint(boolean isVisibleToUser) {
        super.setUserVisibleHint(isVisibleToUser);
        if (isVisibleToUser) {
            this.setActionBar();
        }
    }

    void startProgressBarAnimation() {
        DataStorage.pushProcess();
        this.getActivity().setProgressBarIndeterminateVisibility(true);

    }

    void stopProgressBarAnimation() {
        DataStorage.popProcess();
        this.getActivity().setProgressBarIndeterminateVisibility(false);
    }

    private class EventsDownloadBroadcastReceiver extends BroadcastReceiver {

        @Override
        public void onReceive(Context context, Intent intent) {
            ArrayList<Event> items          = DataStorage.getEvents();
            ArrayList<IListViewItem> events = EventsFragment.this.transformEventsForListview(items);
            EventsFragment.this.stopProgressBarAnimation();
            EventsFragment.this.setItemsOnListView(events);
        }
    }



    @Override
    public void onSaveInstanceState(Bundle outState) {

        int index = this.list.getFirstVisiblePosition();
        View v    = this.list.getChildAt(0);
        int top   = (v == null) ? 0 : v.getTop();

        outState.putInt("index", index);
        outState.putInt("top", top);

        EventsFragment.savedInstance = outState;
        super.onSaveInstanceState(outState);
    }


}