package com.andreums.culturarocafort.fragments.events;

import android.os.Bundle;
import android.support.v4.app.Fragment;
import android.support.v7.app.ActionBar;
import android.support.v7.app.ActionBarActivity;
import android.view.LayoutInflater;
import android.view.Menu;
import android.view.MenuInflater;
import android.view.MenuItem;
import android.view.View;
import android.view.ViewGroup;
import android.widget.AdapterView;
import android.widget.ListView;

import com.andreums.culturarocafort.MainActivity;
import com.andreums.culturarocafort.R;
import com.andreums.culturarocafort.adapters.events.EventByCategoryAdapter;
import com.andreums.culturarocafort.database.EventDatabaseHandler;
import com.andreums.culturarocafort.models.Event;



import java.util.ArrayList;

public class FavoriteEventsFragment extends Fragment {

    private ListView list;

    @Override
    public void onResume() {
        super.onResume();
        this.setActionBar();
        ArrayList<Event> events = this.getEventsFromDatabase();
        this.setItemsInListview(events);
    }

    @Override
    public void onCreate (Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setHasOptionsMenu(true);
    }

    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container,Bundle savedInstanceState) {
        View view = inflater.inflate(R.layout.favorite_events_activity, container, false);
        this.setActionBar();

        this.list = (ListView) view.findViewById(R.id.favorite_events_list);
        this.list.setEmptyView(view.findViewById(R.id.favorite_events_empty));

        ArrayList<Event> events = this.getEventsFromDatabase();
        this.setItemsInListview(events);
        return view;
    }

    @Override
    public void onCreateOptionsMenu(Menu menu, MenuInflater inflater) {
        inflater.inflate(R.menu.menu_fragments, menu);
    }



    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        switch (item.getItemId()) {


            default:
                return super.onOptionsItemSelected(item);
        }
    }

    private ArrayList<Event> getEventsFromDatabase() {
        EventDatabaseHandler handler   = EventDatabaseHandler.getInstance(this.getActivity().getApplicationContext());
        ArrayList<Event> items         = handler.getFavoriteEvents();
        return items;
    }


    private void setActionBar() {
        ActionBar bar = ( (ActionBarActivity) getActivity()).getSupportActionBar();
        bar.setHomeButtonEnabled(true);
        bar.setDisplayHomeAsUpEnabled(true);
        bar.setTitle(getResources().getString(R.string.bar_title_about));
    }

    @Override
    public void setUserVisibleHint(boolean isVisibleToUser) {
        super.setUserVisibleHint(isVisibleToUser);
        if (isVisibleToUser) {
            this.setActionBar();
        }
    }

    private void setItemsInListview(final ArrayList<Event> events) {


        this.list.setOnItemClickListener(
                new AdapterView.OnItemClickListener() {
                    @Override
                    public void onItemClick(AdapterView<?> adapterView, View view, int i, long l) {
                        Event item = (Event) FavoriteEventsFragment.this.list.getItemAtPosition(i);
                        if (item!=null) {

                            int id      = item.getId();

                            Bundle arguments = new Bundle();
                            arguments.putInt("event",id);
                            EventViewerFragment fragment = new EventViewerFragment();
                            fragment.setArguments(arguments);

                            if (MainActivity.mTwoPane) {
                                FavoriteEventsFragment.this.getActivity().getSupportFragmentManager().beginTransaction().replace(R.id.item_detail_container, fragment).addToBackStack(null).commit();
                            }
                            else {
                                FavoriteEventsFragment.this.getActivity().getSupportFragmentManager().beginTransaction().replace(R.id.content_frame, fragment).addToBackStack(null).commit();
                            }
                            MainActivity.displayedFragment = fragment;
                        }
                    }
                }
        );

        FavoriteEventsFragment.this.list.setAdapter(new EventByCategoryAdapter(this.getActivity().getApplicationContext(), R.layout.event_item,events));

    }





}