package com.andreums.culturarocafort.fragments.events;

import android.os.Bundle;
import android.support.v4.app.Fragment;
import android.support.v4.app.FragmentActivity;
import android.support.v7.app.ActionBar;
import android.support.v7.app.ActionBarActivity;
import android.view.LayoutInflater;
import android.view.Menu;
import android.view.MenuInflater;
import android.view.MenuItem;
import android.view.View;
import android.view.ViewGroup;
import android.widget.AdapterView;
import android.widget.ListView;
import android.widget.Toast;

import com.andreums.culturarocafort.MainActivity;
import com.andreums.culturarocafort.R;
import com.andreums.culturarocafort.adapters.events.NextEventsAdapter;
import com.andreums.culturarocafort.database.EventDatabaseHandler;
import com.andreums.culturarocafort.models.Event;



import java.util.ArrayList;

public class NextEventsFragment extends Fragment {


    private static Bundle savedInstance;
    private ListView list;

    @Override
    public void onStop() {
        super.onStop();
        onSaveInstanceState(new Bundle());
    }

    @Override
    public void onResume() {
        super.onResume();
        this.setActionBar();
        ArrayList<Event> events = this.getEventsFromDatabase();
        if (events.size()>0) {
            this.setItemsInListview(events);
        }
    }


    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container,Bundle savedInstanceState) {
        super.onCreateView(inflater,container,savedInstanceState);
        NextEventsFragment.this.setRetainInstance(true);
        NextEventsFragment.this.setHasOptionsMenu(true);

        View view               = inflater.inflate(R.layout.next_events_fragment, container, false);
        this.list               = (ListView) view.findViewById(R.id.next_events_list);
        this.list.setEmptyView(view.findViewById(R.id.next_events_empty));

        ArrayList<Event> events = this.getEventsFromDatabase();
        if (events.size()>0) {
            this.setItemsInListview(events);
        }
        return view;
    }


    @Override
    public void onCreateOptionsMenu(Menu menu, MenuInflater inflater) {
        inflater.inflate(R.menu.menu_fragments, menu);
    }


    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        super.onOptionsItemSelected(item);
        switch (item.getItemId()) {

            case R.id.action_refresh:
                Toast.makeText(this.getActivity().getApplicationContext(), getResources().getString(R.string.action_refresh), Toast.LENGTH_SHORT).show();

                ArrayList<Event> events = this.getEventsFromDatabase();
                if (events.size()>0) {
                    this.setItemsInListview(events);
                }
                break;

            default:
                return super.onOptionsItemSelected(item);
        }

        return true;
    }




    private void setItemsInListview(final ArrayList<Event> events) {

        this.list.setOnItemClickListener(
                new AdapterView.OnItemClickListener() {
                    @Override
                    public void onItemClick(AdapterView<?> adapterView, View view, int i, long l) {
                        Event item = (Event) NextEventsFragment.this.list.getItemAtPosition(i);
                        if (item!=null) {

                            int id      = item.getId();

                            Bundle arguments = new Bundle();
                            arguments.putInt("event",id);
                            EventViewerFragment fragment = new EventViewerFragment();
                            fragment.setArguments(arguments);

                            if (MainActivity.mTwoPane) {
                                NextEventsFragment.this.getActivity().getSupportFragmentManager().beginTransaction().replace(R.id.item_detail_container, fragment).addToBackStack(null).commit();
                            }
                            else {
                                NextEventsFragment.this.getActivity().getSupportFragmentManager().beginTransaction().replace(R.id.content_frame, fragment).addToBackStack(null).commit();
                            }
                            MainActivity.displayedFragment = fragment;
                        }
                    }
                }
        );

        FragmentActivity parentActivity = getActivity();
        if(parentActivity != null) {
            parentActivity.runOnUiThread(new Runnable() {

                @Override
                public void run() {
                    NextEventsFragment.this.list.setAdapter(new NextEventsAdapter(getActivity(), R.layout.event_item,events));
                    if (NextEventsFragment.savedInstance!=null) {
                        int index = NextEventsFragment.savedInstance.getInt("index", -1);
                        int top   = NextEventsFragment.savedInstance.getInt("top", 0);
                        if(index!=-1){
                            NextEventsFragment.this.list.setSelectionFromTop(index, top);
                        }
                    }
                }
            });
        }
    }

    private ArrayList<Event> getEventsFromDatabase() {
        EventDatabaseHandler handler   = EventDatabaseHandler.getInstance(NextEventsFragment.this.getActivity().getApplicationContext());
        ArrayList<Event> items         = handler.getNextEvents();
        return items;
    }

    private void setActionBar() {
        ActionBar bar = ( (ActionBarActivity) getActivity()).getSupportActionBar();
        bar.setTitle(getResources().getString(R.string.bar_next_events));
    }

    @Override
    public void setUserVisibleHint(boolean isVisibleToUser) {
        super.setUserVisibleHint(isVisibleToUser);
        if (isVisibleToUser) {
            this.setActionBar();
        }
    }


    @Override
    public void onSaveInstanceState(Bundle outState) {
        int index = this.list.getFirstVisiblePosition();
        View v    = this.list.getChildAt(0);
        int top   = (v == null) ? 0 : v.getTop();

        outState.putInt("index", index);
        outState.putInt("top", top);

        NextEventsFragment.savedInstance = outState;
        super.onSaveInstanceState(outState);
    }

    @Override
    public void onActivityCreated(Bundle savedInstanceState) {
        super.onActivityCreated(savedInstanceState);
        NextEventsFragment.this.setRetainInstance(true);
    }

}