package com.andreums.culturarocafort.fragments.facebook;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.os.Bundle;
import android.support.v4.app.Fragment;
import android.support.v4.app.FragmentActivity;
import android.support.v7.app.ActionBar;
import android.support.v7.app.ActionBarActivity;
import android.view.LayoutInflater;
import android.view.Menu;
import android.view.MenuInflater;
import android.view.MenuItem;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ListView;
import android.widget.Toast;

import com.andreums.culturarocafort.Constants;
import com.andreums.culturarocafort.R;
import com.andreums.culturarocafort.adapters.facebook.FacebookPostsAdapter;
import com.andreums.culturarocafort.database.FacebookPostsDatabaseHandler;
import com.andreums.culturarocafort.services.FacebookPostsDownloaderService;
import com.andreums.culturarocafort.util.DataStorage;
import com.andreums.culturarocafort.views.facebook.IListFacebookPostViewItem;



import java.util.ArrayList;

public class FacebookFragment extends Fragment {

    private static Bundle savedInstance;
    private ListView list;
    private PostBroadcastReceiver receiver;
    private static boolean isRegistered;


    @Override
        public void onCreate (Bundle savedInstanceState) {
            super.onCreate(savedInstanceState);
            setHasOptionsMenu(true);
        }

        @Override
        public void onStop() {
            super.onStop();
            onSaveInstanceState(new Bundle());
        }


        @Override
        public void onPause() {
            super.onPause();
            try {
                if (FacebookFragment.isRegistered) {
                    getActivity().unregisterReceiver(this.receiver);
                    FacebookFragment.isRegistered = false;
                    this.receiver                 = null;
                }
            }
            catch(Exception e) {
                e.printStackTrace();
            }
        }

        @Override
        public void onResume() {
            super.onResume();

            ArrayList<IListFacebookPostViewItem> posts = this.getPostsFromDatabase();
            if (posts.size()>0)  {
                this.setItemsInListview(posts);
            }
        }



        @Override
        public View onCreateView(LayoutInflater inflater, ViewGroup container,Bundle savedInstanceState) {
            this.setHasOptionsMenu(true);

            View view = inflater.inflate(R.layout.facebok_fragment, container, false);
            this.list = (ListView) view.findViewById(R.id.facebook_list);
            this.list.setEmptyView(view.findViewById(R.id.facebook_empty));

            ArrayList<IListFacebookPostViewItem> posts = this.getPostsFromDatabase();
            if (posts.size()>0) {
                this.setItemsInListview(posts);
            }
            this.startProgressBarAnimation();
            this.startService();
            return view;
        }


        private void setItemsInListview(final ArrayList<IListFacebookPostViewItem> items) {
            FragmentActivity parentActivity = getActivity();
            if(parentActivity != null) {
                parentActivity.runOnUiThread(new Runnable() {



                    @Override
                    public void run() {
                        FacebookFragment.this.list.setAdapter(new FacebookPostsAdapter(getActivity(), R.layout.post_item,items));

                        if (FacebookFragment.savedInstance!=null) {
                            int index = FacebookFragment.savedInstance.getInt("index", -1);
                            int top   = FacebookFragment.savedInstance.getInt("top", 0);
                            if(index!=-1){
                                FacebookFragment.this.list.setSelectionFromTop(index, top);
                            }
                        }
                    }

                });
            }
        }


    @Override
    public void onCreateOptionsMenu(Menu menu, MenuInflater inflater) {
        //inflater.inflate(R.menu.menu_fragments, menu);
    }


    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        super.onOptionsItemSelected(item);
        switch (item.getItemId()) {

            case R.id.action_refresh:
                Toast.makeText(this.getActivity().getApplicationContext(), getResources().getString(R.string.action_refresh), Toast.LENGTH_SHORT).show();
                this.startProgressBarAnimation();
                this.startService();
                break;

            default:
                return super.onOptionsItemSelected(item);
        }

        return true;
    }


    private void startService() {
        try {
            IntentFilter intentFilter = new IntentFilter("com.andreums.culturarocafort.downloaded.facebook");

            if (!FacebookFragment.isRegistered && this.receiver==null ) {
                this.receiver             = new PostBroadcastReceiver();
                getActivity().registerReceiver(this.receiver, intentFilter);
                FacebookFragment.isRegistered = true;
            }
            Intent intent = new Intent(this.getActivity(), FacebookPostsDownloaderService.class);
            intent.putExtra("url", Constants.facebookFeed);
            getActivity().startService(intent);
        }
        catch (Exception ex) {
            ex.printStackTrace();
        }
    }

    private class PostBroadcastReceiver extends BroadcastReceiver {

        @Override
        public void onReceive(Context context, Intent intent) {
            FacebookFragment.this.setItemsInListview(FacebookFragment.this.getPostsFromDatabase());
            FacebookFragment.this.stopProgressBarAnimation();
        }

    }

    private void setActionBar() {
        ActionBar bar = ( (ActionBarActivity) getActivity()).getSupportActionBar();
        // TODO: Change
        bar.setTitle("Facebook");
    }


    @Override
    public void setUserVisibleHint(boolean isVisibleToUser) {
        super.setUserVisibleHint(isVisibleToUser);
        if (isVisibleToUser) {
            this.setActionBar();
        }
    }

    void startProgressBarAnimation() {
        DataStorage.pushProcess();
        try {
            this.getActivity().setProgressBarIndeterminateVisibility(true);
        }
        catch (Exception ex) {}

    }

    void stopProgressBarAnimation() {
        DataStorage.popProcess();
        this.getActivity().setProgressBarIndeterminateVisibility(false);
    }

    private ArrayList<IListFacebookPostViewItem> getPostsFromDatabase() {
        ArrayList<IListFacebookPostViewItem> posts;
        FacebookPostsDatabaseHandler handler = FacebookPostsDatabaseHandler.getInstance(getActivity().getBaseContext());
        posts                       = handler.getPosts();
        return posts;
    }

    @Override
    public void onSaveInstanceState(Bundle outState) {

        int index = this.list.getFirstVisiblePosition();
        View v    = this.list.getChildAt(0);
        int top   = (v == null) ? 0 : v.getTop();

        outState.putInt("index", index);
        outState.putInt("top", top);

        FacebookFragment.savedInstance = outState;
        super.onSaveInstanceState(outState);
    }

}