package com.andreums.culturarocafort.fragments.home;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.os.Bundle;
import android.support.v4.app.Fragment;
import android.support.v4.app.FragmentManager;
import android.support.v7.app.ActionBar;
import android.support.v7.app.ActionBarActivity;
import android.text.Html;
import android.view.LayoutInflater;
import android.view.Menu;
import android.view.MenuInflater;
import android.view.MenuItem;
import android.view.View;
import android.view.ViewGroup;
import android.widget.FrameLayout;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.RelativeLayout;
import android.widget.TextView;

import com.andreums.culturarocafort.Constants;
import com.andreums.culturarocafort.MainActivity;
import com.andreums.culturarocafort.R;
import com.andreums.culturarocafort.database.EventDatabaseHandler;
import com.andreums.culturarocafort.database.PostDatabaseHandler;
import com.andreums.culturarocafort.fragments.events.EventViewerFragment;
import com.andreums.culturarocafort.fragments.events.EventsFragment;
import com.andreums.culturarocafort.fragments.facebook.FacebookFragment;
import com.andreums.culturarocafort.fragments.other.ContactFragment;
import com.andreums.culturarocafort.fragments.other.InformationFragment;
import com.andreums.culturarocafort.fragments.other.WebViewFragment;
import com.andreums.culturarocafort.fragments.photos.PhotosFragment;
import com.andreums.culturarocafort.fragments.posts.PostCategoryFragment;
import com.andreums.culturarocafort.fragments.posts.PostFragment;
import com.andreums.culturarocafort.fragments.posts.PostViewerFragment;
import com.andreums.culturarocafort.fragments.twitter.TwitterFragment;
import com.andreums.culturarocafort.fragments.videos.VideosFragment;
import com.andreums.culturarocafort.models.Event;
import com.andreums.culturarocafort.models.Post;
import com.andreums.culturarocafort.services.EventsDownloadService;
import com.andreums.culturarocafort.services.PostDownloaderService;
import com.andreums.culturarocafort.util.DataStorage;
import com.andreums.culturarocafort.util.DateUtils;


import com.squareup.picasso.Picasso;

import org.apache.commons.lang3.StringEscapeUtils;

import java.util.ArrayList;

public class HomeScreenFragment extends Fragment {

    private static boolean isRegistered;
    private StartupBroadcastReceiver receiver;
    private UpdaterBroadcastReceiver updateReceiver;


    @Override
    public void onResume() {
        super.onResume();
        this.setActionBar();
        if (DataStorage.isFirstRunRunning()) {
            this.setFrame(this.getView());
            this.drawContents(false);
        }
        else {
            this.startEventUpdater();
            this.startPostUpdater();
            this.drawContents(true);
        }
    }


    @Override
    public void onPause() {
        super.onPause();
        try {
            if (this.receiver!=null && HomeScreenFragment.isRegistered) {
                getActivity().unregisterReceiver(this.receiver);
                HomeScreenFragment.isRegistered = false;
                this.receiver                   = null;
            }
        }
        catch(Exception e) {
            e.printStackTrace();
        }
    }

    @Override
    public void onCreate (Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setHasOptionsMenu(true);
        if (DataStorage.isFirstRunRunning()) {
            this.startService();
        }
    }


    private void startService() {
        try {
            IntentFilter intentFilter = new IntentFilter("com.andreums.culturarocafort.startup");

            if (!HomeScreenFragment.isRegistered && this.receiver==null) {
                this.receiver             = new StartupBroadcastReceiver();
                getActivity().registerReceiver(this.receiver, intentFilter);
                HomeScreenFragment.isRegistered = true;
            }
        }
        catch (Exception ex) {
            ex.printStackTrace();
        }
    }

    private View drawContents(boolean removeFrameLayout) {
        View view = this.getLayoutInflater(new Bundle()).inflate(R.layout.home_screen_fragment,null,false);

        if (removeFrameLayout) {
            FrameLayout frame = (FrameLayout) this.getView().findViewById(R.id.home_screen_empty);
            frame.setVisibility(View.GONE);

            android.support.v7.widget.GridLayout grid = (android.support.v7.widget.GridLayout) this.getView().findViewById(R.id.home_screen_grid);
            grid.setVisibility(View.VISIBLE);

        }

        if (! DataStorage.isFirstRunRunning()) {

            view    = this.setNextEvents(view);
            view    = this.setLatestsPosts(view);
            view    = this.homeScreenButtons(view);
        }
        return view;
    }

    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container,Bundle savedInstanceState) {
        super.onCreateView(inflater,container,savedInstanceState);
        View view = inflater.inflate(R.layout.home_screen_fragment, container, false);

        this.getActivity().setProgressBarIndeterminateVisibility(false);

        try {

            if (DataStorage.isFirstRunRunning()) {
                this.setFrame(view);
            }
            view = this.drawContents(false);
        }
        catch (Exception ex) {
            ex.printStackTrace();
        }
        return  view;
    }

    private void setFrame(View view) {
        FrameLayout frame = (FrameLayout) view.findViewById(R.id.home_screen_empty);
        frame.setVisibility(View.VISIBLE);

        android.support.v7.widget.GridLayout grid = (android.support.v7.widget.GridLayout) view.findViewById(R.id.home_screen_grid);
        grid.setVisibility(View.GONE);
    }


    @Override
    public void onCreateOptionsMenu(Menu menu, MenuInflater inflater) {
        //inflater.inflate(R.menu.menu_main, menu);
    }


    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        super.onOptionsItemSelected(item);
        switch (item.getItemId()) {
            case R.id.action_refresh:
            break;

            default:
                return super.onOptionsItemSelected(item);
        }
        return true;
    }

    private void setActionBar() {
        ActionBar bar = ( (ActionBarActivity) getActivity()).getSupportActionBar();
        bar.setTitle(getResources().getString(R.string.bar_home_title));
    }

    @Override
    public void setUserVisibleHint(boolean isVisibleToUser) {
        super.setUserVisibleHint(isVisibleToUser);
        if (isVisibleToUser) {
            this.setActionBar();
        }
    }

    private View homeScreenButtons(View view) {
        LinearLayout facebook = (LinearLayout) view.findViewById(R.id.home_screen_launch_facebook);
        facebook.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                HomeScreenFragment.this.setFacebookTab(v);
            }
        });

        LinearLayout twitter  = (LinearLayout) view.findViewById(R.id.home_screen_launch_twitter);
        twitter.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                HomeScreenFragment.this.setTwitterTab(v);
            }
        });

        LinearLayout photos   = (LinearLayout) view.findViewById(R.id.home_screen_launch_photos);
        photos.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                HomeScreenFragment.this.setPhotosTab(v);
            }
        });

        LinearLayout videos   = (LinearLayout) view.findViewById(R.id.home_screen_launch_videos);
        videos.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                HomeScreenFragment.this.setVideosTab(v);
            }
        });


        LinearLayout news   = (LinearLayout) view.findViewById(R.id.linear_last_news);
        news.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                HomeScreenFragment.this.showNews(v);
            }
        });


        LinearLayout events   = (LinearLayout) view.findViewById(R.id.linear_next_events);
        events.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                HomeScreenFragment.this.showEvents(v);
            }
        });

        LinearLayout information   = (LinearLayout) view.findViewById(R.id.home_screen_launch_information);
        information.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                HomeScreenFragment.this.showInformation(v);
            }
        });

        LinearLayout services   = (LinearLayout) view.findViewById(R.id.home_screen_launch_services);
        services.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                HomeScreenFragment.this.showServices(v);
            }
        });


        LinearLayout contact   = (LinearLayout) view.findViewById(R.id.home_screen_launch_contact);
        contact.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                HomeScreenFragment.this.showContact(v);
            }
        });

        return view;
    }


    private View setNextEvents(View view) {
        ArrayList<Event> events = this.getNextEvents();
        if (events.size()==0) {
            return view;
        }

        Event aux;

        LinearLayout wrapper = (LinearLayout) view.findViewById(R.id.home_screen_events_first);

        if (events.size()>=1) {
            aux              = events.get(0);

            ImageView image = (ImageView) view.findViewById(R.id.home_screen_events_first_picture);
            String imageURL = aux.getThumbnail();
            if (imageURL.length()>0) {
                try {
                    Picasso.with(this.getActivity().getApplicationContext()).load(imageURL).placeholder(R.drawable.ic_launcher).resize(300,300).error(R.drawable.ic_launcher).into(image);
                }
                catch (Exception ex) {
                    ex.printStackTrace();
                }
            }

            TextView eventTitle = (TextView) view.findViewById(R.id.home_screen_events_first_title);
            eventTitle.setText(StringEscapeUtils.unescapeHtml4(aux.getTitle()));

            TextView eventDate = (TextView) view.findViewById(R.id.home_screen_events_first_date);
            eventDate.setText(StringEscapeUtils.unescapeHtml4(DateUtils.convertToEventDate(aux.getStart_date())));

            TextView eventPlace = (TextView) view.findViewById(R.id.home_screen_events_first_place);
            eventPlace.setText(StringEscapeUtils.unescapeHtml4(aux.getVenue()));

            final Event finalAux = aux;
            wrapper.setOnClickListener(
                    new View.OnClickListener() {
                        @Override
                        public void onClick(View v) {
                            int id = finalAux.getId();
                            Bundle arguments = new Bundle();
                            arguments.putInt("event",id);
                            EventViewerFragment fragment = new EventViewerFragment();
                            fragment.setArguments(arguments);
                            HomeScreenFragment.this.getActivity().getSupportFragmentManager().beginTransaction().replace(R.id.content_frame, fragment).addToBackStack(null).commit();

                        }
                    }
            );

        }
        else {
            wrapper.setVisibility(View.GONE);
        }


        wrapper = (LinearLayout) view.findViewById(R.id.home_screen_events_second);

        if (events.size()>=2) {
            aux = events.get(1);
            ImageView image = (ImageView) view.findViewById(R.id.home_screen_events_second_picture);
            String imageURL = aux.getThumbnail();
            if (imageURL.length()>0) {
                try {
                    Picasso.with(this.getActivity().getApplicationContext()).load(imageURL).placeholder(R.drawable.ic_launcher).resize(300,300).error(R.drawable.ic_launcher).into(image);
                }
                catch (Exception ex) {
                    ex.printStackTrace();
                }
            }

            TextView eventTitle = (TextView) view.findViewById(R.id.home_screen_events_second_title);
            eventTitle.setText(StringEscapeUtils.unescapeHtml4(aux.getTitle()));

            TextView eventDate = (TextView) view.findViewById(R.id.home_screen_events_second_date);
            eventDate.setText(StringEscapeUtils.unescapeHtml4(DateUtils.convertToEventDate(aux.getStart_date())));

            TextView eventPlace = (TextView) view.findViewById(R.id.home_screen_events_second_place);
            eventPlace.setText(StringEscapeUtils.unescapeHtml4(aux.getVenue()));

            final Event finalAux = aux;
            wrapper.setOnClickListener(
                    new View.OnClickListener() {
                        @Override
                        public void onClick(View v) {
                            int id = finalAux.getId();

                            Bundle arguments = new Bundle();
                            arguments.putInt("event",id);
                            EventViewerFragment fragment = new EventViewerFragment();
                            fragment.setArguments(arguments);
                            HomeScreenFragment.this.getActivity().getSupportFragmentManager().beginTransaction().replace(R.id.content_frame, fragment).addToBackStack(null).commit();


                        }
                    }
            );
        }
        else {
            wrapper.setVisibility(View.GONE);
        }


        wrapper = (LinearLayout) view.findViewById(R.id.home_screen_events_third);
        if (events.size()>=3) {
            aux = events.get(2);

            ImageView image = (ImageView) view.findViewById(R.id.home_screen_events_third_picture);
            String imageURL = aux.getThumbnail();
            if (imageURL.length()>0) {
                try {
                    Picasso.with(this.getActivity().getApplicationContext()).load(imageURL).placeholder(R.drawable.ic_launcher).resize(300,300).error(R.drawable.ic_launcher).into(image);
                }
                catch (Exception ex) {
                    ex.printStackTrace();
                }
            }

            TextView eventTitle = (TextView) view.findViewById(R.id.home_screen_events_third_title);
            eventTitle.setText(StringEscapeUtils.unescapeHtml4(aux.getTitle()));

            TextView eventDate = (TextView) view.findViewById(R.id.home_screen_events_third_date);
            eventDate.setText(StringEscapeUtils.unescapeHtml4(DateUtils.convertToEventDate(aux.getStart_date())));

            TextView eventPlace = (TextView) view.findViewById(R.id.home_screen_events_third_place);
            eventPlace.setText(StringEscapeUtils.unescapeHtml4(aux.getVenue()));

            final Event finalAux = aux;
            wrapper.setOnClickListener(
                    new View.OnClickListener() {
                        @Override
                        public void onClick(View v) {
                            int id = finalAux.getId();
                            Bundle arguments = new Bundle();
                            arguments.putInt("event",id);
                            EventViewerFragment fragment = new EventViewerFragment();
                            fragment.setArguments(arguments);
                            HomeScreenFragment.this.getActivity().getSupportFragmentManager().beginTransaction().replace(R.id.content_frame, fragment).addToBackStack(null).commit();


                        }
                    }
            );
        }
        else {
            wrapper.setVisibility(View.GONE);
        }

        wrapper = (LinearLayout) view.findViewById(R.id.home_screen_events_fourth);
        if (events.size()>=4) {
            aux = events.get(3);


            ImageView image = (ImageView) view.findViewById(R.id.home_screen_events_fourth_picture);
            String imageURL = aux.getThumbnail();
            if (imageURL.length()>0) {
                try {
                    Picasso.with(this.getActivity().getApplicationContext()).load(imageURL).placeholder(R.drawable.ic_launcher).resize(300,300).error(R.drawable.ic_launcher).into(image);
                }
                catch (Exception ex) {
                    ex.printStackTrace();
                }
            }

            TextView eventTitle = (TextView) view.findViewById(R.id.home_screen_events_fourth_title);
            eventTitle.setText(StringEscapeUtils.unescapeHtml4(aux.getTitle()));

            TextView eventDate = (TextView) view.findViewById(R.id.home_screen_events_fourth_date);
            eventDate.setText(StringEscapeUtils.unescapeHtml4(DateUtils.convertToEventDate(aux.getStart_date())));

            TextView eventPlace = (TextView) view.findViewById(R.id.home_screen_events_fourth_place);
            eventPlace.setText(StringEscapeUtils.unescapeHtml4(aux.getVenue()));

            final Event finalAux = aux;
            wrapper.setOnClickListener(
                    new View.OnClickListener() {
                        @Override
                        public void onClick(View v) {
                            int id = finalAux.getId();
                            Bundle arguments = new Bundle();
                            arguments.putInt("event",id);
                            EventViewerFragment fragment = new EventViewerFragment();
                            fragment.setArguments(arguments);
                            HomeScreenFragment.this.getActivity().getSupportFragmentManager().beginTransaction().replace(R.id.content_frame, fragment).addToBackStack(null).commit();


                        }
                    }
            );
        }
        else {
            wrapper.setVisibility(View.GONE);
        }

        return view;
    }


    private View setLatestsPosts(View view) {
        ArrayList<Post> posts = this.getLatestsPosts();
        if (posts.size()==0) {
            return view;
        }

        final Post post        = posts.get(0);
        RelativeLayout mainWrapper = (RelativeLayout) view.findViewById(R.id.home_screen_main_wrapper);

        if (post!=null) {
            ImageView image = (ImageView) view.findViewById(R.id.home_screen_main_image);
            String imageURL = post.getThumbnail();
            if (imageURL.length()>0) {
                try {
                    Picasso.with(this.getActivity().getApplicationContext()).load(imageURL).placeholder(R.drawable.ic_launcher).resize(300,300).error(R.drawable.ic_launcher).into(image);
                }
                catch (Exception ex) {
                    ex.printStackTrace();
                }
            }

            TextView postTitle = (TextView) view.findViewById(R.id.home_screen_main_title);
            postTitle.setText(StringEscapeUtils.unescapeHtml4(post.getTitle()));

            TextView postDescription = (TextView) view.findViewById(R.id.home_screen_main_description);
            postDescription.setText(Html.fromHtml(StringEscapeUtils.unescapeHtml4(post.getExcerpt())));

            TextView postDate = (TextView) view.findViewById(R.id.home_screen_main_date);
            postDate.setText(DateUtils.convertToEventDate(post.getDate()));

            mainWrapper.setOnClickListener(
                    new View.OnClickListener() {
                        @Override
                        public void onClick(View v) {
                            int id = post.getId();
                            Bundle arguments = new Bundle();
                            arguments.putInt("post",id);
                            PostViewerFragment fragment = new PostViewerFragment();
                            fragment.setArguments(arguments);
                            HomeScreenFragment.this.getActivity().getSupportFragmentManager().beginTransaction().replace(R.id.content_frame, fragment).addToBackStack(null).commit();


                        }
                    }

            );


            Post aux = posts.get(1);
            LinearLayout wrapper = (LinearLayout) view.findViewById(R.id.home_screen_news_first);

            if (aux!=null) {
                image = (ImageView) view.findViewById(R.id.home_screen_news_first_picture);
                imageURL = aux.getThumbnail();
                if (imageURL.length()>0) {
                    try {
                        Picasso.with(this.getActivity().getApplicationContext()).load(imageURL).placeholder(R.drawable.ic_launcher).resize(300,300).error(R.drawable.ic_launcher).into(image);
                    }
                    catch (Exception ex) {
                        ex.printStackTrace();
                    }
                }

                postTitle = (TextView) view.findViewById(R.id.home_screen_news_first_title);
                postTitle.setText(StringEscapeUtils.unescapeHtml4(aux.getTitle()));

                postDate = (TextView) view.findViewById(R.id.home_screen_news_first_date);
                postDate.setText(DateUtils.convertToEventDate(aux.getDate()));

                final Post finalAux = aux;
                wrapper.setOnClickListener(
                        new View.OnClickListener() {
                            @Override
                            public void onClick(View v) {
                                int id = finalAux.getId();
                                Bundle arguments = new Bundle();
                                arguments.putInt("post",id);
                                PostViewerFragment fragment = new PostViewerFragment();
                                fragment.setArguments(arguments);
                                HomeScreenFragment.this.getActivity().getSupportFragmentManager().beginTransaction().replace(R.id.content_frame, fragment).addToBackStack(null).commit();


                            }
                        }

                );

            }


            aux = posts.get(2);
            wrapper = (LinearLayout) view.findViewById(R.id.home_screen_news_second);

            if (aux!=null) {
                image = (ImageView) view.findViewById(R.id.home_screen_news_second_picture);
                imageURL = aux.getThumbnail();
                if (imageURL.length()>0) {
                    try {
                        Picasso.with(this.getActivity().getApplicationContext()).load(imageURL).placeholder(R.drawable.ic_launcher).resize(300,300).error(R.drawable.ic_launcher).into(image);
                    }
                    catch (Exception ex) {
                        ex.printStackTrace();
                    }
                }

                postTitle = (TextView) view.findViewById(R.id.home_screen_news_second_title);
                postTitle.setText(StringEscapeUtils.unescapeHtml4(aux.getTitle()));

                postDate = (TextView) view.findViewById(R.id.home_screen_news_second_date);
                postDate.setText(DateUtils.convertToEventDate(aux.getDate()));

                final Post finalAux = aux;
                wrapper.setOnClickListener(
                        new View.OnClickListener() {
                            @Override
                            public void onClick(View v) {
                                int id = finalAux.getId();
                                Bundle arguments = new Bundle();
                                arguments.putInt("post",id);
                                PostViewerFragment fragment = new PostViewerFragment();
                                fragment.setArguments(arguments);
                                HomeScreenFragment.this.getActivity().getSupportFragmentManager().beginTransaction().replace(R.id.content_frame, fragment).addToBackStack(null).commit();


                            }
                        }

                );
            }

            aux = posts.get(3);
            wrapper = (LinearLayout) view.findViewById(R.id.home_screen_news_third);

            if (aux!=null) {
                image = (ImageView) view.findViewById(R.id.home_screen_news_third_picture);
                imageURL = aux.getThumbnail();
                if (imageURL.length()>0) {
                    try {
                        Picasso.with(this.getActivity().getApplicationContext()).load(imageURL).placeholder(R.drawable.ic_launcher).resize(300,300).error(R.drawable.ic_launcher).into(image);
                    }
                    catch (Exception ex) {
                        ex.printStackTrace();
                    }
                }

                postTitle = (TextView) view.findViewById(R.id.home_screen_news_third_title);
                postTitle.setText(StringEscapeUtils.unescapeHtml4(aux.getTitle()));

                postDate = (TextView) view.findViewById(R.id.home_screen_news_third_date);
                postDate.setText(DateUtils.convertToEventDate(aux.getDate()));

                final Post finalAux = aux;
                wrapper.setOnClickListener(
                        new View.OnClickListener() {
                            @Override
                            public void onClick(View v) {
                                int id = finalAux.getId();
                                Bundle arguments = new Bundle();
                                arguments.putInt("post",id);
                                PostViewerFragment fragment = new PostViewerFragment();
                                fragment.setArguments(arguments);
                                HomeScreenFragment.this.getActivity().getSupportFragmentManager().beginTransaction().replace(R.id.content_frame, fragment).addToBackStack(null).commit();

                            }
                        }

                );
            }


            aux = posts.get(4);
            wrapper = (LinearLayout) view.findViewById(R.id.home_screen_news_fourth);

            if (aux!=null) {
                image = (ImageView) view.findViewById(R.id.home_screen_news_fourth_picture);
                imageURL = aux.getThumbnail();
                if (imageURL.length()>0) {
                    try {
                        Picasso.with(this.getActivity().getApplicationContext()).load(imageURL).placeholder(R.drawable.ic_launcher).resize(300,300).error(R.drawable.ic_launcher).into(image);
                    }
                    catch (Exception ex) {
                        ex.printStackTrace();
                    }
                }

                postTitle = (TextView) view.findViewById(R.id.home_screen_news_fourth_title);
                postTitle.setText(StringEscapeUtils.unescapeHtml4(aux.getTitle()));

                postDate = (TextView) view.findViewById(R.id.home_screen_news_fourth_date);
                postDate.setText(DateUtils.convertToEventDate(aux.getDate()));

                final Post finalAux = aux;
                wrapper.setOnClickListener(
                        new View.OnClickListener() {
                            @Override
                            public void onClick(View v) {
                                int id = finalAux.getId();
                                Bundle arguments = new Bundle();
                                arguments.putInt("post",id);
                                PostViewerFragment fragment = new PostViewerFragment();
                                fragment.setArguments(arguments);
                                HomeScreenFragment.this.getActivity().getSupportFragmentManager().beginTransaction().replace(R.id.content_frame, fragment).addToBackStack(null).commit();


                            }
                        }

                );
            }


        }

        return view;
    }

    private ArrayList<Post> getLatestsPosts() {
        PostDatabaseHandler handler = PostDatabaseHandler.getInstance(HomeScreenFragment.this.getActivity().getApplicationContext());
        ArrayList<Post> posts       = handler.getLatestNews(Constants.news_category_id);
        return posts;
    }

    private ArrayList<Event> getNextEvents() {
        EventDatabaseHandler handler   = EventDatabaseHandler.getInstance(HomeScreenFragment.this.getActivity().getApplicationContext());
        ArrayList<Event> items         = handler.getNextEvents();
        return items;
    }


    public void setFacebookTab(View v) {
        FragmentManager fragmentManager = this.getActivity().getSupportFragmentManager();
        Fragment fragment               = new FacebookFragment();
        fragmentManager.beginTransaction().replace(R.id.content_frame, fragment).addToBackStack(null).commit();
        MainActivity.displayedFragment = fragment;
    }

    public void setTwitterTab(View v) {
        FragmentManager fragmentManager = this.getActivity().getSupportFragmentManager();
        Fragment fragment               = new TwitterFragment();
        if (MainActivity.mTwoPane) {
            fragmentManager.beginTransaction().replace(R.id.item_detail_container,new WebViewFragment()).commit();
            fragmentManager.beginTransaction().replace(R.id.content_frame, fragment).commit();
        }
        else {
            fragmentManager.beginTransaction().replace(R.id.content_frame, fragment).commit();
        }
        MainActivity.displayedFragment = fragment;
    }

    public void setPhotosTab(View v) {
        FragmentManager fragmentManager = this.getActivity().getSupportFragmentManager();
        Fragment fragment               = new PhotosFragment();

        if (MainActivity.mTwoPane) {
            fragmentManager.beginTransaction().replace(R.id.item_detail_container, fragment).addToBackStack(null).commit();
            v = (View) this.getView().findViewById(R.id.content_frame);
            v.setVisibility(View.GONE);
        }
        else {
            fragmentManager.beginTransaction().replace(R.id.content_frame, fragment).addToBackStack(null).commit();
        }
        MainActivity.displayedFragment = fragment;

    }

    public void setVideosTab(View v) {
        FragmentManager fragmentManager = this.getActivity().getSupportFragmentManager();
        Fragment fragment               = new VideosFragment();
        fragmentManager.beginTransaction().replace(R.id.content_frame, fragment).addToBackStack(null).commit();
        MainActivity.displayedFragment = fragment;
    }


    public void showNews(View v) {
        FragmentManager fragmentManager = this.getActivity().getSupportFragmentManager();
        Fragment fragment               = new PostFragment();
        fragmentManager.beginTransaction().replace(R.id.content_frame, fragment).addToBackStack(null).commit();
        MainActivity.displayedFragment = fragment;
    }

    public void showEvents(View v) {
        FragmentManager fragmentManager = this.getActivity().getSupportFragmentManager();
        Fragment fragment               = new EventsFragment();
        fragmentManager.beginTransaction().replace(R.id.content_frame, fragment).addToBackStack(null).commit();
        MainActivity.displayedFragment = fragment;
    }


    public void showInformation(View v) {
        FragmentManager fragmentManager = this.getActivity().getSupportFragmentManager();
        Fragment fragment               = new InformationFragment();
        fragmentManager.beginTransaction().replace(R.id.content_frame, fragment).addToBackStack(null).commit();
        MainActivity.displayedFragment = fragment;
    }

    public void showServices(View v) {
        FragmentManager fragmentManager = this.getActivity().getSupportFragmentManager();
        Fragment fragment               = new PostCategoryFragment();
        Bundle bundle = new Bundle();
        bundle.putIntArray("categories",new int[] {49});
        fragment.setArguments(bundle);
        fragmentManager.beginTransaction().replace(R.id.content_frame, fragment).addToBackStack(null).commit();
        MainActivity.displayedFragment = fragment;
    }


    public void showContact(View v) {
        FragmentManager fragmentManager = this.getActivity().getSupportFragmentManager();
        Fragment fragment               = new ContactFragment();
        fragmentManager.beginTransaction().replace(R.id.content_frame, fragment).addToBackStack(null).commit();
        MainActivity.displayedFragment = fragment;
    }





    private class StartupBroadcastReceiver extends BroadcastReceiver {

        @Override
        public void onReceive(Context context, Intent intent) {
            HomeScreenFragment.this.drawContents(true);
        }

    }

    private void startEventUpdater() {
        try {
            IntentFilter intentFilter = new IntentFilter("com.andreums.culturarocafort.downloaded.events");
            this.updateReceiver       = new UpdaterBroadcastReceiver();
            this.getActivity().getApplicationContext().registerReceiver(this.receiver, intentFilter);

            Intent intent = new Intent(this.getActivity().getApplicationContext(), EventsDownloadService.class);
            intent.putExtra("url", Constants.getEventsURL(this.getActivity().getApplicationContext()));
            this.getActivity().getApplicationContext().startService(intent);
        }
        catch (Exception ex) {
            ex.printStackTrace();
        }
    }


    private void startPostUpdater() {
        try {
            IntentFilter intentFilter = new IntentFilter("com.andreums.culturarocafort.downloaded.posts");
            this.updateReceiver       = new UpdaterBroadcastReceiver();
            this.getActivity().getApplicationContext().registerReceiver(this.receiver, intentFilter);

            Intent intent = new Intent(this.getActivity().getApplicationContext(), PostDownloaderService.class);
            intent.putExtra("url", Constants.getPostsURL(this.getActivity().getApplicationContext()));
            this.getActivity().getApplicationContext().startService(intent);
        }
        catch (Exception ex) {
            ex.printStackTrace();
        }
    }

    private class UpdaterBroadcastReceiver extends BroadcastReceiver {

        @Override
        public void onReceive(Context context, Intent intent) {
            HomeScreenFragment.this.drawContents(true);
        }
    }

}