package com.andreums.culturarocafort.fragments.other;

import android.content.Intent;
import android.net.Uri;
import android.os.Bundle;
import android.support.v4.app.Fragment;
import android.support.v7.app.ActionBar;
import android.support.v7.app.ActionBarActivity;
import android.view.LayoutInflater;
import android.view.Menu;
import android.view.MenuInflater;
import android.view.MenuItem;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;
import android.widget.TextView;
import android.widget.Toast;

import com.andreums.culturarocafort.Constants;
import com.andreums.culturarocafort.MainActivity;
import com.andreums.culturarocafort.R;
import com.andreums.culturarocafort.activities.settings.SettingsActivity;
import com.andreums.culturarocafort.models.LatLng;
import com.andreums.culturarocafort.util.StaticMaps;


import com.squareup.picasso.Picasso;

public class InformationFragment extends Fragment {



    @Override
    public void onCreateOptionsMenu(Menu menu, MenuInflater inflater) {
        inflater.inflate(R.menu.menu_main, menu);
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        super.onOptionsItemSelected(item);
        switch (item.getItemId()) {

            case R.id.action_settings:
                Intent intent = new Intent(getActivity(),SettingsActivity.class);
                startActivity(intent);
                break;


            case R.id.action_contact:
                Fragment fragment = new ContactFragment();
                this.getActivity().getSupportFragmentManager().beginTransaction().replace(R.id.content_frame, fragment).addToBackStack(null).commit();
                MainActivity.displayedFragment = fragment;
                break;

            default:
                return super.onOptionsItemSelected(item);
        }

        return true;
    }


    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container,Bundle savedInstanceState) {
        View view       = inflater.inflate(R.layout.information_fragment, container, false);
        StaticMaps maps = new StaticMaps();
        LatLng position = new LatLng(39.527591,-0.409509);
        String imgURL   = maps.getURLForImageAtPosition(position,800,600);

        ImageView map = (ImageView) view.findViewById(R.id.information_map);
        Picasso.with(getActivity().getApplicationContext()).load(imgURL).into(map);

        map.setOnClickListener(
                new View.OnClickListener() {
                    @Override
                    public void onClick(View v) {
                        InformationFragment.this.viewInMap();
                    }
                }
        );


        TextView tMap = (TextView) view.findViewById(R.id.information_open_map);
        tMap.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                InformationFragment.this.viewInMap();
            }
        });

        ImageView facebook = (ImageView) view.findViewById(R.id.information_open_facebook);
        facebook.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                InformationFragment.this.openFacebook();
            }
        });

        ImageView twitter = (ImageView) view.findViewById(R.id.information_open_twitter);
        twitter.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                InformationFragment.this.openTwitter();
            }
        });


        TextView web = (TextView) view.findViewById(R.id.information_open_web);
        web.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                InformationFragment.this.openInBrowser();
            }
        });
        return view;
    }


    private void setActionBar() {
        ActionBar bar = ( (ActionBarActivity) getActivity()).getSupportActionBar();
        bar.setTitle(getResources().getString(R.string.bar_information_title));
    }

    @Override
    public void onResume() {
        super.onResume();
        this.setActionBar();
    }


    @Override
    public void setUserVisibleHint(boolean isVisibleToUser) {
        super.setUserVisibleHint(isVisibleToUser);
        if (isVisibleToUser) {
            this.setActionBar();
        }
    }



    void viewInMap() {
        try {
            String uri = "geo:39.527591,-0.409509?q="+getResources().getString(R.string.information_address);
            startActivity(new Intent(Intent.ACTION_VIEW, Uri.parse(uri)));
        }
        catch (Exception ex) {
            Toast.makeText(this.getActivity().getApplicationContext(), "Google Maps APP is not Installed!", Toast.LENGTH_LONG).show();
        }
    }

    void openInBrowser() {
        String url    = Constants.homepage;
        Intent intent = new Intent(Intent.ACTION_VIEW);
        intent.setData(Uri.parse(url));
        startActivity(intent);
    }


    void openTwitter() {
        String url    = Constants.twitterURL;
        Intent intent = new Intent(Intent.ACTION_VIEW);
        intent.setData(Uri.parse(url));
        startActivity(intent);
    }

    void openFacebook() {
        String url    = Constants.facebookURL;
        Intent intent = new Intent(Intent.ACTION_VIEW);
        intent.setData(Uri.parse(url));
        startActivity(intent);
    }



}