package com.andreums.culturarocafort.fragments.photos;

import android.content.Intent;
import android.os.Bundle;
import android.support.v4.app.Fragment;
import android.support.v4.app.FragmentActivity;
import android.support.v7.app.ActionBar;
import android.support.v7.app.ActionBarActivity;
import android.view.LayoutInflater;
import android.view.Menu;
import android.view.MenuInflater;
import android.view.MenuItem;
import android.view.View;
import android.view.ViewGroup;
import android.widget.AdapterView;
import android.widget.GridView;

import com.andreums.culturarocafort.R;
import com.andreums.culturarocafort.activities.photos.PhotoViewerActivity;
import com.andreums.culturarocafort.adapters.photos.FacebookPhotoAlbumsAdapter;
import com.andreums.culturarocafort.database.FacebookPhotosDatabaseHandler;
import com.andreums.culturarocafort.models.FacebookAlbum;
import com.andreums.culturarocafort.models.FacebookPhoto;



import org.apache.commons.lang3.StringEscapeUtils;

import java.util.ArrayList;

public class PhotoGalleryViewerFragment extends Fragment {


    private FacebookAlbum album;
    private GridView grid;

    @Override
    public void onResume() {
        super.onResume();
        this.setActionbar();
    }

    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container,Bundle savedInstanceState) {
        this.setHasOptionsMenu(true);

        View view = inflater.inflate(R.layout.photo_gallery_activity, container, false);
        this.grid = (GridView) view.findViewById(R.id.gridview);

        String id                       = this.getIdFromIntent();
        ArrayList<FacebookPhoto> photos = this.getImages(id);
        this.album                      = this.getAlbum(id);

        this.setItemsInListview(photos);

        this.setActionbar();
        return view;
    }

    private String getIdFromIntent() {
        Bundle extras = getArguments();
        String value;
        value         = extras.getString("id");
        return value;
    }

    private ArrayList<FacebookPhoto> getImages(String id) {
        ArrayList<FacebookPhoto> photos;
        FacebookPhotosDatabaseHandler handler = FacebookPhotosDatabaseHandler.getInstance(this.getActivity().getApplicationContext());
        photos                                = handler.getAlbumPhotos(id);

        return photos;
    }

    private FacebookAlbum getAlbum(String id) {
        FacebookAlbum album;
        FacebookPhotosDatabaseHandler handler = FacebookPhotosDatabaseHandler.getInstance(this.getActivity().getApplicationContext());
        album                                 = handler.getAlbum(id);

        return album;
    }

    private void setActionbar() {
        ActionBar bar = ( (ActionBarActivity) getActivity()).getSupportActionBar();
        bar.setHomeButtonEnabled(true);
        bar.setDisplayHomeAsUpEnabled(true);
        bar.setTitle(StringEscapeUtils.unescapeHtml4(this.album.getName()));
    }

    @Override
    public void onCreateOptionsMenu(Menu menu, MenuInflater inflater) {
        //inflater.inflate(R.menu.menu_viewers, menu);
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        switch (item.getItemId()) {

            case android.R.id.home:
                //this.finish();
                return true;

            default:
                break;
        }

        return true;
    }


    private void setItemsInListview(final ArrayList<FacebookPhoto> items) {
        this.grid.setOnItemClickListener(
                new AdapterView.OnItemClickListener() {
                    @Override
                    public void onItemClick(AdapterView<?> adapterView, View view, int i, long l) {
                        FacebookPhoto item = (FacebookPhoto) PhotoGalleryViewerFragment.this.grid.getItemAtPosition(i);
                        String id      = item.getAlbum_id();
                        int position   = i;

                        Intent intent = new Intent(PhotoGalleryViewerFragment.this.getActivity().getApplicationContext(), PhotoViewerActivity.class);
                        intent.putExtra("image_position",position);
                        intent.putExtra("album_id",id);

                        startActivity(intent);
                    }
                }
        );

        FragmentActivity parentActivity = getActivity();
        if(parentActivity != null) {
            parentActivity.runOnUiThread(new Runnable() {

                @Override
                public void run() {
                    PhotoGalleryViewerFragment.this.grid.setAdapter(new FacebookPhotoAlbumsAdapter(PhotoGalleryViewerFragment.this.getActivity().getApplicationContext(), R.layout.photo_item,items));
                }

            });
        }
    }



}