package com.andreums.culturarocafort.fragments.photos;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.os.Bundle;
import android.support.v4.app.Fragment;
import android.support.v4.app.FragmentActivity;
import android.support.v7.app.ActionBar;
import android.support.v7.app.ActionBarActivity;
import android.view.LayoutInflater;
import android.view.Menu;
import android.view.MenuInflater;
import android.view.MenuItem;
import android.view.View;
import android.view.ViewGroup;
import android.widget.AdapterView;
import android.widget.GridView;
import android.widget.Toast;

import com.andreums.culturarocafort.Constants;
import com.andreums.culturarocafort.MainActivity;
import com.andreums.culturarocafort.R;
import com.andreums.culturarocafort.adapters.photos.FacebookAlbumAdapter;
import com.andreums.culturarocafort.database.FacebookPhotosDatabaseHandler;
import com.andreums.culturarocafort.models.FacebookAlbum;
import com.andreums.culturarocafort.services.FacebookAlbumDownloaderService;
import com.andreums.culturarocafort.util.DataStorage;



import java.util.ArrayList;

public class PhotosFragment extends Fragment {

    private FacebookAlbumsBroadcastReceiver receiver;
    private static boolean isRegistered;


    private GridView grid;


    @Override
    public void onPause() {
        super.onPause();
        try {
            if (PhotosFragment.isRegistered) {
                getActivity().unregisterReceiver(this.receiver);
                PhotosFragment.isRegistered = false;
                this.receiver                   = null;
            }
        }
        catch(Exception e) {
            e.printStackTrace();
        }
    }

    @Override
    public void onResume() {
        super.onResume();
        this.setActionBar();
        FacebookPhotosDatabaseHandler handler = FacebookPhotosDatabaseHandler.getInstance(this.getActivity().getApplicationContext());
        ArrayList<FacebookAlbum> albums       = handler.getAlbums();
        if (albums!=null && albums.size()>0) {
            PhotosFragment.this.setItemsInListview(albums);
        }
        this.startService();
    }


    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container,Bundle savedInstanceState) {
        this.setRetainInstance(true);
        this.setHasOptionsMenu(true);

        View view = inflater.inflate(R.layout.photos_fragment, container, false);
        this.grid = (GridView) view.findViewById(R.id.gridview);

        FacebookPhotosDatabaseHandler handler = FacebookPhotosDatabaseHandler.getInstance(this.getActivity().getApplicationContext());
        ArrayList<FacebookAlbum> albums       = handler.getAlbums();
        if (albums!=null && albums.size()>0) {
            PhotosFragment.this.setItemsInListview(albums);
        }
        this.startProgressBarAnimation();
        this.startService();

        return view;
    }


    private void setItemsInListview(final ArrayList<FacebookAlbum> items) {
        this.grid.setOnItemClickListener(
                new AdapterView.OnItemClickListener() {
                    @Override
                    public void onItemClick(AdapterView<?> adapterView, View view, int i, long l) {
                        FacebookAlbum item = (FacebookAlbum) PhotosFragment.this.grid.getItemAtPosition(i);
                        String id = item.getId();

                        Bundle arguments = new Bundle();
                        arguments.putString("id", id);
                        PhotoGalleryViewerFragment fragment = new PhotoGalleryViewerFragment();
                        fragment.setArguments(arguments);


                        if (MainActivity.mTwoPane) {
                            PhotosFragment.this.getActivity().getSupportFragmentManager().beginTransaction().replace(R.id.item_detail_container, fragment).addToBackStack(null).commit();
                        }
                        else {
                            PhotosFragment.this.getActivity().getSupportFragmentManager().beginTransaction().replace(R.id.content_frame, fragment).addToBackStack(null).commit();
                        }
                        MainActivity.displayedFragment = fragment;
                    }
                }
        );

        FragmentActivity parentActivity = getActivity();
        if(parentActivity != null) {
            parentActivity.runOnUiThread(new Runnable() {

                @Override
                public void run() {
                    PhotosFragment.this.grid.setAdapter(new FacebookAlbumAdapter(PhotosFragment.this.getActivity(), R.layout.album_item,items));
                }

            });
        }
    }


    @Override
    public void onCreateOptionsMenu(Menu menu, MenuInflater inflater) {
        inflater.inflate(R.menu.menu_fragments, menu);
    }


    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        super.onOptionsItemSelected(item);
        switch (item.getItemId()) {

            case R.id.action_refresh:
                Toast.makeText(this.getActivity().getApplicationContext(), getResources().getString(R.string.action_refresh), Toast.LENGTH_SHORT).show();
                this.startService();
                break;

            default:
                return super.onOptionsItemSelected(item);
        }
        return true;
    }


    private void startService() {
        try {
            IntentFilter intentFilter = new IntentFilter("com.andreums.culturarocafort.downloaded.facebook.albums");

            if (!PhotosFragment.isRegistered && this.receiver==null ) {
                this.receiver             = new FacebookAlbumsBroadcastReceiver();
                getActivity().registerReceiver(this.receiver, intentFilter);
                PhotosFragment.isRegistered = true;
            }
            Intent intent = new Intent(this.getActivity(), FacebookAlbumDownloaderService.class);
            intent.putExtra("url", Constants.facebookAlbums);
            getActivity().startService(intent);

        }
        catch (Exception ex) {
            ex.printStackTrace();
        }
    }


    void startProgressBarAnimation() {
        DataStorage.pushProcess();
        this.getActivity().setProgressBarIndeterminateVisibility(true);

    }

    void stopProgressBarAnimation() {
        DataStorage.popProcess();
        this.getActivity().setProgressBarIndeterminateVisibility(false);
    }


    private void setActionBar() {
        ActionBar bar = ( (ActionBarActivity) getActivity()).getSupportActionBar();
        // TODO: Change
        bar.setTitle("Fotos");
    }


    @Override
    public void setUserVisibleHint(boolean isVisibleToUser) {
        super.setUserVisibleHint(isVisibleToUser);
        if (isVisibleToUser) {
            this.setActionBar();
        }
    }


    private class FacebookAlbumsBroadcastReceiver extends BroadcastReceiver {

        @Override
        public void onReceive(Context context, Intent intent) {
            ArrayList<FacebookAlbum> list    = DataStorage.getFacebookAlbums();
            PhotosFragment.this.setItemsInListview(list);
            PhotosFragment.this.stopProgressBarAnimation();
        }
    }



}