package com.andreums.culturarocafort.fragments.posts;

import android.os.Bundle;
import android.support.v4.app.Fragment;
import android.support.v4.app.FragmentActivity;
import android.support.v7.app.ActionBar;
import android.support.v7.app.ActionBarActivity;
import android.view.LayoutInflater;
import android.view.Menu;
import android.view.MenuInflater;
import android.view.MenuItem;
import android.view.View;
import android.view.ViewGroup;
import android.widget.AdapterView;
import android.widget.ListView;
import android.widget.TextView;
import android.widget.Toast;

import com.andreums.culturarocafort.MainActivity;
import com.andreums.culturarocafort.R;
import com.andreums.culturarocafort.adapters.posts.PostsAdapter;
import com.andreums.culturarocafort.database.CategoryDatabaseHandler;
import com.andreums.culturarocafort.database.PostDatabaseHandler;
import com.andreums.culturarocafort.models.Post;
import com.andreums.culturarocafort.models.PostCategory;



import java.util.ArrayList;

public class PostCategoryFragment extends Fragment {

    private static Bundle savedInstance;
    private ListView list;

    private int[] categories;

    @Override
    public void onCreate (Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setHasOptionsMenu(true);
        this.categories  = this.getCategoriesFromIntent();

    }

    @Override
    public void onResume() {
        super.onResume();
        this.setActionBar();
        ArrayList<Post> posts = this.getPostsFromDatabase(this.categories);
        if (posts.size()>0) {
            this.setItemsInListview(posts);
        }
    }


    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container,Bundle savedInstanceState) {

        this.setHasOptionsMenu(true);
        View view = inflater.inflate(R.layout.post_categories_fragment, container, false);
        this.list = (ListView) view.findViewById(R.id.post_category_list);
        this.list.setEmptyView(view.findViewById(R.id.post_category_empty));
        this.list.addHeaderView(inflater.inflate(R.layout.post_category_header,null));


        TextView title = (TextView) view.findViewById(R.id.post_category_title);

        ArrayList<Post> posts = this.getPostsFromDatabase(this.categories);
        PostCategory category = this.getPostCategory(this.categories[0]);
        if (category!=null) {
            title.setText(category.getTitle());
        }
        if (posts.size()>0) {
            this.setItemsInListview(posts);
        }

        return view;
    }


    private void setItemsInListview(final ArrayList<Post> items) {


        this.list.setOnItemClickListener(
                new AdapterView.OnItemClickListener() {
                    @Override
                    public void onItemClick(AdapterView<?> adapterView, View view, int i, long l) {
                        if (i>0) {
                            Post item = (Post) PostCategoryFragment.this.list.getItemAtPosition(i);
                            int id = item.getId();
                            Bundle arguments = new Bundle();
                            arguments.putInt("post", item.getId());
                            PostViewerFragment fragment = new PostViewerFragment();
                            fragment.setArguments(arguments);

                            if (MainActivity.mTwoPane) {
                                PostCategoryFragment.this.getActivity().getSupportFragmentManager().beginTransaction().replace(R.id.item_detail_container, fragment).addToBackStack(null).commit();
                            } else {
                                PostCategoryFragment.this.getActivity().getSupportFragmentManager().beginTransaction().replace(R.id.content_frame, fragment).addToBackStack(null).commit();
                            }
                            MainActivity.displayedFragment = fragment;
                        }
                    }
                }
        );

        FragmentActivity parentActivity = getActivity();
        if(parentActivity != null) {
            parentActivity.runOnUiThread(new Runnable() {



                @Override
                public void run() {
                    PostCategoryFragment.this.list.setAdapter(new PostsAdapter(getActivity(), R.layout.post_item,items));

                    int index = -1;
                    int top   = 0;

                    if (PostCategoryFragment.savedInstance != null) {
                        // Restore last state for checked position.
                        index = PostCategoryFragment.savedInstance.getInt("index", -1);
                        top   = PostCategoryFragment.savedInstance.getInt("top", 0);
                    }
                    if(index!=-1){
                        final int finalIndex = index;
                        final int finalTop = top;
                        PostCategoryFragment.this.list.setSelectionFromTop(finalIndex, finalTop);
                    }

                }

            });
        }
    }


    @Override
    public void onCreateOptionsMenu(Menu menu, MenuInflater inflater) {
        inflater.inflate(R.menu.menu_fragments, menu);
    }


    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        super.onOptionsItemSelected(item);
        switch (item.getItemId()) {

            case R.id.action_refresh:
                Toast.makeText(this.getActivity().getApplicationContext(), getResources().getString(R.string.action_refresh), Toast.LENGTH_SHORT).show();
                break;

            default:
                return super.onOptionsItemSelected(item);
        }

        return true;
    }

    private PostCategory getPostCategory(int id) {
        CategoryDatabaseHandler handler    = CategoryDatabaseHandler.getInstance(PostCategoryFragment.this.getActivity().getApplicationContext());
        return handler.getPostCategory(id);
    }

    private ArrayList<Post> getPostsFromDatabase(int[] categories) {
        PostDatabaseHandler handler = PostDatabaseHandler.getInstance(PostCategoryFragment.this.getActivity().getApplicationContext());
        ArrayList<Post> items       = handler.getPostsByCategoriesId(categories);
        return items;
    }

    private void setActionBar() {
        ActionBar bar = ( (ActionBarActivity) getActivity()).getSupportActionBar();
        bar.setTitle(getResources().getString(R.string.bar_posts_title));
    }


    @Override
    public void setUserVisibleHint(boolean isVisibleToUser) {
        super.setUserVisibleHint(isVisibleToUser);
        if (isVisibleToUser) {
            this.setActionBar();
        }
    }

    public int[] getCategoriesFromIntent() {
        Bundle bundle    = this.getArguments();
        int []categories = bundle.getIntArray("categories");
        return categories;
    }


    @Override
    public void onSaveInstanceState(Bundle outState) {

        int index = this.list.getFirstVisiblePosition();
        View v    = this.list.getChildAt(0);
        int top   = (v == null) ? 0 : v.getTop();

        outState.putInt("index", index);
        outState.putInt("top", top);

        PostCategoryFragment.savedInstance = outState;
        super.onSaveInstanceState(outState);
    }
}