package com.andreums.culturarocafort.fragments.posts;


import android.os.Bundle;
import android.support.v4.app.Fragment;
import android.support.v4.app.FragmentActivity;
import android.support.v7.app.ActionBar;
import android.support.v7.app.ActionBarActivity;
import android.view.LayoutInflater;
import android.view.Menu;
import android.view.MenuInflater;
import android.view.MenuItem;
import android.view.View;
import android.view.ViewGroup;
import android.widget.AdapterView;
import android.widget.ListView;
import android.widget.TextView;

import com.andreums.culturarocafort.MainActivity;
import com.andreums.culturarocafort.R;
import com.andreums.culturarocafort.adapters.posts.PostsAdapter;
import com.andreums.culturarocafort.database.CategoryDatabaseHandler;
import com.andreums.culturarocafort.database.PostDatabaseHandler;
import com.andreums.culturarocafort.models.Post;
import com.andreums.culturarocafort.models.PostCategory;



import java.util.ArrayList;

public class PostCategoryViewerFragment extends Fragment {

    private static Bundle savedInstance;
    private ListView list;

    @Override
    public void onResume() {
        super.onResume();
        this.setActionbar(this.getCategoryFromIntent());
    }


    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container,Bundle savedInstanceState) {
        this.setHasOptionsMenu(true);
        View view = inflater.inflate(R.layout.post_category_activity,container, false);


        PostCategory category  = this.getCategoryFromIntent();
        ArrayList<Post> posts  = this.getCategoryposts(category.getId());

        this.list = (ListView) view.findViewById(R.id.post_category_list);
        this.list.setEmptyView(view.findViewById(R.id.post_category_empty));
        this.list.addHeaderView(inflater.inflate(R.layout.post_category_header,null));

        this.setActionbar(category);
        view = this.setCategoryData(view,category,posts);

        return view;
    }



    private void setActionbar(PostCategory category) {
        ActionBar bar = ( (ActionBarActivity) getActivity()).getSupportActionBar();
        bar.setIcon(R.drawable.ic_launcher);
        bar.setHomeButtonEnabled(true);
        bar.setDisplayHomeAsUpEnabled(true);
        bar.setTitle(category.getTitle());
    }

    private ArrayList<Post> getCategoryposts(int id) {
        PostDatabaseHandler handler       = PostDatabaseHandler.getInstance(this.getActivity().getApplicationContext());
        ArrayList<Post> posts             = handler.getPostsByCategoryId(id);
        return posts;
    }


    private PostCategory getCategoryFromIntent() {
        Bundle extras = getArguments();
        int id        = extras.getInt("category", 0);

        CategoryDatabaseHandler handler  = CategoryDatabaseHandler.getInstance(this.getActivity().getApplicationContext());
        PostCategory category            = handler.getPostCategory(id);
        return category;
    }

    private View setCategoryData(View view,PostCategory category, final ArrayList<Post> posts) {

        TextView title = (TextView) view.findViewById(R.id.post_category_title);
        title.setText(category.getTitle());


        /*TextView description = (TextView) findViewById(R.id.event_category_description);
        String desc = category.getDescription();
        if ( (desc!=null) && (desc.length()>0) ) {
            description.setText(category.getDescription());
            description.setVisibility(View.VISIBLE);
        }*/




        list.setOnItemClickListener(
                new AdapterView.OnItemClickListener() {
                    @Override
                    public void onItemClick(AdapterView<?> adapterView, View view, int i, long l) {
                        Post item = (Post) PostCategoryViewerFragment.this.list.getItemAtPosition(i);
                        if (item!=null) {
                            int id      = item.getId();

                            Bundle arguments = new Bundle();
                            arguments.putInt("post",id);
                            PostViewerFragment fragment = new PostViewerFragment();
                            fragment.setArguments(arguments);

                            if (MainActivity.mTwoPane) {
                                PostCategoryViewerFragment.this.getActivity().getSupportFragmentManager().beginTransaction().replace(R.id.item_detail_container, fragment).addToBackStack(null).commit();
                            }
                            else {
                                PostCategoryViewerFragment.this.getActivity().getSupportFragmentManager().beginTransaction().replace(R.id.content_frame, fragment).addToBackStack(null).commit();
                            }
                            MainActivity.displayedFragment = fragment;
                        }
                    }
                }
        );

        FragmentActivity parentActivity = getActivity();
        if(parentActivity != null) parentActivity.runOnUiThread(new Runnable() {

            @Override
            public void run() {
                PostCategoryViewerFragment.this.list.setAdapter(new PostsAdapter(PostCategoryViewerFragment.this.getActivity().getApplicationContext(),R.layout.post_category_item,posts));

                int index = -1;
                int top   = 0;

                if (PostCategoryViewerFragment.savedInstance != null) {
                    // Restore last state for checked position.
                    index = PostCategoryViewerFragment.savedInstance.getInt("index", -1);
                    top   = PostCategoryViewerFragment.savedInstance.getInt("top", 0);
                }
                if(index!=-1){
                    final int finalIndex = index;
                    final int finalTop = top;
                    PostCategoryViewerFragment.this.list.setSelectionFromTop(finalIndex, finalTop);
                }
            }
        });
        return view;
    }


    @Override
    public void onCreateOptionsMenu(Menu menu, MenuInflater inflater) {
        inflater.inflate(R.menu.menu_main, menu);
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        super.onOptionsItemSelected(item);
        switch (item.getItemId()) {

            case android.R.id.home:
                this.getActivity().finish();
                return true;

            default:
                break;
        }

        return true;
    }


    @Override
    public void onSaveInstanceState(Bundle outState) {

        int index = this.list.getFirstVisiblePosition();
        View v    = this.list.getChildAt(0);
        int top   = (v == null) ? 0 : v.getTop();

        outState.putInt("index", index);
        outState.putInt("top", top);

        PostCategoryViewerFragment.savedInstance = outState;
        super.onSaveInstanceState(outState);
    }


}
