package com.andreums.culturarocafort.fragments.posts;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.os.Bundle;
import android.support.v4.app.Fragment;
import android.support.v4.app.FragmentActivity;
import android.support.v7.app.ActionBar;
import android.support.v7.app.ActionBarActivity;
import android.view.LayoutInflater;
import android.view.Menu;
import android.view.MenuInflater;
import android.view.MenuItem;
import android.view.View;
import android.view.ViewGroup;
import android.widget.AdapterView;
import android.widget.ListView;
import android.widget.Toast;

import com.andreums.culturarocafort.Constants;
import com.andreums.culturarocafort.MainActivity;
import com.andreums.culturarocafort.R;
import com.andreums.culturarocafort.adapters.posts.PostsAdapter;
import com.andreums.culturarocafort.database.PostDatabaseHandler;
import com.andreums.culturarocafort.models.Post;
import com.andreums.culturarocafort.services.PostDownloaderService;
import com.andreums.culturarocafort.util.DataStorage;



import java.util.ArrayList;

public class PostFragment extends Fragment {

    private static Bundle savedInstance;
    private ListView list;
    private PostBroadcastReceiver receiver;
    private static boolean isRegistered;

    @Override
    public void onCreate (Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setRetainInstance(true);
        setHasOptionsMenu(true);
    }

        @Override
        public void onResume() {
            super.onResume();
            this.setActionBar();
            ArrayList<Post> posts = this.getPostsFromDatabase();
            if (posts.size()>0) {
                this.setItemsInListview(posts);
            }
            this.startService();
        }


        @Override
        public void onPause() {
            super.onPause();
            try {
                if (PostFragment.isRegistered) {
                    getActivity().unregisterReceiver(this.receiver);
                    PostFragment.isRegistered = false;
                    this.receiver             = null;
                }
            }
            catch(Exception e) {
                e.printStackTrace();
            }
        }


        @Override
        public void onStop() {
            super.onStop();
            onSaveInstanceState(new Bundle());
        }



        @Override
        public View onCreateView(LayoutInflater inflater, ViewGroup container,Bundle savedInstanceState) {

            this.setHasOptionsMenu(true);
            View view = inflater.inflate(R.layout.posts_fragment, container, false);
            this.list = (ListView) view.findViewById(R.id.blog_list);

            this.list.setEmptyView(view.findViewById(R.id.posts_empty));

            ArrayList<Post> posts = this.getPostsFromDatabase();
            if (posts.size()>0) {
                this.setItemsInListview(posts);
            }
            this.startProgressBarAnimation();
            this.startService();

            return view;
        }


        private void setItemsInListview(final ArrayList<Post> items) {


            this.list.setOnItemClickListener(
                    new AdapterView.OnItemClickListener() {
                        @Override
                        public void onItemClick(AdapterView<?> adapterView, View view, int i, long l) {
                            Post item = (Post) PostFragment.this.list.getItemAtPosition(i);
                            int id = item.getId();
                            Bundle arguments = new Bundle();
                            arguments.putInt("post",id);
                            PostViewerFragment fragment = new PostViewerFragment();
                            fragment.setArguments(arguments);

                            if (MainActivity.mTwoPane) {
                                PostFragment.this.getActivity().getSupportFragmentManager().beginTransaction().replace(R.id.item_detail_container, fragment).addToBackStack(null).commit();
                            }
                            else {
                                PostFragment.this.getActivity().getSupportFragmentManager().beginTransaction().replace(R.id.content_frame, fragment).addToBackStack(null).commit();
                            }
                            MainActivity.displayedFragment = fragment;
                        }
                    }
            );

            FragmentActivity parentActivity = getActivity();
            if(parentActivity != null) {
                parentActivity.runOnUiThread(new Runnable() {



                    @Override
                    public void run() {
                        PostFragment.this.list.setAdapter(new PostsAdapter(getActivity(), R.layout.post_item,items));

                        int index = -1;
                        int top   = 0;

                        if (PostFragment.savedInstance != null) {
                            // Restore last state for checked position.
                            index = PostFragment.savedInstance.getInt("index", -1);
                            top   = PostFragment.savedInstance.getInt("top", 0);
                        }
                        if(index!=-1){
                            final int finalIndex = index;
                            final int finalTop = top;
                            PostFragment.this.list.setSelectionFromTop(finalIndex, finalTop);
                        }

                        PostFragment.this.stopProgressBarAnimation();
                    }

                });
            }
        }


    @Override
    public void onCreateOptionsMenu(Menu menu, MenuInflater inflater) {
        inflater.inflate(R.menu.menu_fragments, menu);
    }


    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        super.onOptionsItemSelected(item);
        switch (item.getItemId()) {

            case R.id.action_refresh:
                Toast.makeText(this.getActivity().getApplicationContext(), getResources().getString(R.string.action_refresh), Toast.LENGTH_SHORT).show();

                this.startProgressBarAnimation();
                this.startService();
                break;

            default:
                return super.onOptionsItemSelected(item);
        }

        return true;
    }

    private ArrayList<Post> getPostsFromDatabase() {
        PostDatabaseHandler handler = PostDatabaseHandler.getInstance(PostFragment.this.getActivity().getApplicationContext());
        ArrayList<Post> items       = handler.getPostsByCategoryId(Constants.news_category_id);
        return items;
    }

    private void startService() {
        try {
            IntentFilter intentFilter = new IntentFilter("com.andreums.culturarocafort.downloaded.posts");

            if (!PostFragment.isRegistered && this.receiver==null) {
                this.receiver             = new PostBroadcastReceiver();
                getActivity().registerReceiver(this.receiver, intentFilter);
                PostFragment.isRegistered = true;
            }
            Intent intent = new Intent(this.getActivity(), PostDownloaderService.class);
            intent.putExtra("url", Constants.getPostsURL(getActivity().getApplicationContext()));
            getActivity().startService(intent);
        }
        catch (Exception ex) {
            ex.printStackTrace();
        }
    }


    private void setActionBar() {
        ActionBar bar = ( (ActionBarActivity) getActivity()).getSupportActionBar();
        bar.setTitle(getResources().getString(R.string.bar_posts_title));
    }


    @Override
    public void setUserVisibleHint(boolean isVisibleToUser) {
        super.setUserVisibleHint(isVisibleToUser);
        if (isVisibleToUser) {
            this.setActionBar();
        }
    }


    private class PostBroadcastReceiver extends BroadcastReceiver {

        @Override
        public void onReceive(Context context, Intent intent) {
            ArrayList<Post> list    = DataStorage.getPosts();
            PostFragment.this.setItemsInListview(list);
            PostFragment.this.stopProgressBarAnimation();
        }

    }



    private void startProgressBarAnimation() {
        DataStorage.pushProcess();
        this.getActivity().setProgressBarIndeterminateVisibility(true);

    }

    private void stopProgressBarAnimation() {
        DataStorage.popProcess();
        this.getActivity().setProgressBarIndeterminateVisibility(false);
    }


    @Override
    public void onSaveInstanceState(Bundle outState) {

        int index = this.list.getFirstVisiblePosition();
        View v    = this.list.getChildAt(0);
        int top   = (v == null) ? 0 : v.getTop();

        outState.putInt("index", index);
        outState.putInt("top", top);

        PostFragment.savedInstance = outState;
        super.onSaveInstanceState(outState);
    }

}