package com.andreums.culturarocafort.fragments.posts;

import android.content.Intent;
import android.net.Uri;
import android.os.Bundle;
import android.support.v4.app.Fragment;
import android.support.v7.app.ActionBar;
import android.support.v7.app.ActionBarActivity;
import android.text.Html;
import android.util.DisplayMetrics;
import android.view.LayoutInflater;
import android.view.Menu;
import android.view.MenuInflater;
import android.view.MenuItem;
import android.view.View;
import android.view.ViewGroup;
import android.webkit.WebSettings;
import android.webkit.WebView;
import android.widget.ImageView;
import android.widget.TextView;

import com.andreums.culturarocafort.R;
import com.andreums.culturarocafort.activities.photos.ImageViewerActivity;
import com.andreums.culturarocafort.database.PostDatabaseHandler;
import com.andreums.culturarocafort.models.Post;
import com.andreums.culturarocafort.util.DataStorage;
import com.andreums.culturarocafort.util.DateUtils;
import com.andreums.culturarocafort.util.HTML;


import com.squareup.picasso.Picasso;

import org.apache.commons.lang3.StringEscapeUtils;

import java.lang.reflect.InvocationTargetException;

public class PostViewerFragment extends Fragment {

    private Post post;
    private WebView content;

    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container,Bundle savedInstanceState) {
        this.setHasOptionsMenu(true);
        this.post = this.getPostFromIntent();
        View view = inflater.inflate(R.layout.post_viewer_activity,container, false);

        if (this.post!=null) {
            DataStorage.setSelectedPost(this.post);
            view = this.setInterface(view);
            this.setActionbar();
        }

        return view;
    }

    @Override
    public void onResume() {
        super.onResume();
        this.setActionbar();
    }

    @Override
    public void onStop() {
        super.onStop();
        this.stopWebView();
    }



    @Override
    public void onPause() {
        super.onPause();
        this.stopWebView();
    }

    private void stopWebView() {
        try {
            Class.forName("android.webkit.WebView").getMethod("onPause", (Class[]) null).invoke(this.content, (Object[]) null);

        }
        catch(ClassNotFoundException cnfe) {

        }
        catch(NoSuchMethodException nsme) {

        }
        catch(InvocationTargetException ite) {

        }
        catch (IllegalAccessException iae) {

        }
    }


    private View setInterface(View view) {
        TextView title = (TextView) view.findViewById(R.id.post_title);
        title.setText(StringEscapeUtils.unescapeHtml4(this.post.getTitle()));

        TextView date  = (TextView) view.findViewById(R.id.post_date);
        date.setText(DateUtils.convertToEventDate(this.post.getDate()));


        this.content = (WebView) view.findViewById(R.id.post_content);

        view = this.setPostImage(view);
        view = this.setPostContent(view);



        return view;
    }

    private View setPostContent(View view) {
        String data = this.post.getContent();

        this.content = (WebView) view.findViewById(R.id.post_content);

        if (data!=null && data.length()==0) {
            data = getResources().getString(R.string.post_no_content);
        }

        data = HTML.getCleanHTML(data, this.getScreenWidth());
        String dataToShare = Html.fromHtml(data).toString();

        try {
            WebSettings settings = this.content.getSettings();
            String appCachePath = this.getActivity().getApplicationContext().getCacheDir().getAbsolutePath();
            settings.setAppCachePath(appCachePath);
            settings.setAppCacheEnabled(true);
            settings.setAppCacheMaxSize(30 * 1024 * 10);
            settings.setJavaScriptEnabled(true);
            settings.setPluginState(WebSettings.PluginState.ON);
        }
        catch (Exception e) {
            e.printStackTrace();
        }

        data = HTML.getContentsAsHTML(data, this.getScreenWidth());
        this.content.loadDataWithBaseURL("http://cultura.rocafort.es", data, "text/html", "UTF-8", "");
        return view;
    }

    private View setPostImage(View view) {
        ImageView image = (ImageView) view.findViewById(R.id.post_image);
        image.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                PostViewerFragment.this.viewImage();
            }
        });

        image.setContentDescription(StringEscapeUtils.unescapeHtml4(this.post.getTitle()));

        if (post.getImage()!=null && post.getImage().length()>0) {
            String img = post.getImage();
            if (img.equals("assets://images/placeholder.png")) {
                image.setScaleType(ImageView.ScaleType.CENTER_INSIDE);
                image.setImageDrawable(getResources().getDrawable(R.drawable.placeholder_big));
            }
            else {
                Picasso.with(this.getActivity().getApplicationContext()).load(img).placeholder(R.drawable.ic_launcher).error(R.drawable.ic_launcher).into(image);
            }
        }
        return view;
    }


    private Post getPostFromIntent() {
        Post    post;
        Bundle extras = getArguments();
        int id        = extras.getInt("post",0);
        PostDatabaseHandler handler = PostDatabaseHandler.getInstance(this.getActivity().getApplicationContext());
        post = handler.getPost(id);
        return post;
    }


    public void viewImage() {
        Intent intent = new Intent(this.getActivity(),ImageViewerActivity.class);
        intent.putExtra("url", this.post.getImage());
        startActivity(intent);
    }

    private void shareItem() {

        String title         = StringEscapeUtils.unescapeHtml4(this.post.getTitle());
        String description   = Html.fromHtml((StringEscapeUtils.unescapeHtml4(this.post.getContent()))).toString();
        String published     = getResources().getString(R.string.post_share_published)+" "+this.post.getDate();

        String header        = getResources().getString(R.string.post_share_header);
        String footer        = getResources().getString(R.string.post_share_read_more)+this.post.getUrl()+getResources().getString(R.string.post_share_more);


        String text          = header+title+"\n"+published+"\n\n"+description+"\n\n"+footer;
        Intent sharingIntent = new Intent(Intent.ACTION_SEND);
        sharingIntent.setType("text/plain");
        sharingIntent.putExtra(Intent.EXTRA_TEXT,text);
        startActivity(Intent.createChooser(sharingIntent, getResources().getString(R.string.post_share_with)));
    }


    public void openInBrowser() {

        String url    = this.post.getUrl();
        Intent intent = new Intent(Intent.ACTION_VIEW);
        intent.setData(Uri.parse(url));
        startActivity(intent);
    }

    private void setActionbar() {
        ActionBar bar = ( (ActionBarActivity) getActivity()).getSupportActionBar();
        bar.setIcon(R.drawable.ic_launcher);
        bar.setHomeButtonEnabled(true);
        bar.setDisplayHomeAsUpEnabled(true);
        bar.setTitle(StringEscapeUtils.unescapeHtml4(this.post.getTitle()));
    }


    @Override
    public void onCreateOptionsMenu(Menu menu, MenuInflater inflater) {
        inflater.inflate(R.menu.menu_viewers, menu);
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        switch (item.getItemId()) {
            case R.id.action_share:
                this.shareItem();
                break;

            case android.R.id.home:
                return true;



            default:
                break;
        }

        return true;
    }


    private int getScreenWidth() {
        DisplayMetrics dm = new DisplayMetrics();
        PostViewerFragment.this.getActivity().getWindowManager().getDefaultDisplay().getMetrics(dm);
        return (int) Math.round((dm.widthPixels) - (dm.widthPixels / 2.50));
    }


}