package com.andreums.culturarocafort.fragments.twitter;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.net.Uri;
import android.os.Bundle;
import android.support.v4.app.Fragment;
import android.support.v4.app.FragmentActivity;
import android.support.v7.app.ActionBar;
import android.support.v7.app.ActionBarActivity;
import android.view.LayoutInflater;
import android.view.Menu;
import android.view.MenuInflater;
import android.view.MenuItem;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ListView;
import android.widget.Toast;

import com.andreums.culturarocafort.Constants;
import com.andreums.culturarocafort.R;
import com.andreums.culturarocafort.adapters.twitter.TwitterAdapter;
import com.andreums.culturarocafort.services.TwitterDownloaderService;
import com.andreums.culturarocafort.util.DataStorage;



import java.util.ArrayList;

import twitter4j.Status;

public class TwitterFragment extends Fragment {

    private static Bundle savedInstance;
    private ListView list;
    private TwitterBroadcastReceiver receiver;
    private static boolean isRegistered;


        @Override
        public void onCreate (Bundle savedInstanceState) {
            super.onCreate(savedInstanceState);
            setHasOptionsMenu(true);
        }

        @Override
        public void onStop() {
            super.onStop();
            onSaveInstanceState(new Bundle());
        }

        @Override
        public void onPause() {
            super.onPause();
            try {
                if (TwitterFragment.isRegistered) {
                    getActivity().unregisterReceiver(this.receiver);
                    TwitterFragment.isRegistered = false;
                    this.receiver                = null;
                }
            }
            catch(Exception e) {
                e.printStackTrace();
            }
        }

        @Override
        public void onResume() {
            super.onResume();
            this.setActionBar();
            ArrayList<Status> list    = DataStorage.getTwitterData();
            if (list!=null && list.size()>0) {
                this.setItemsInListview(list);
            }
            this.startService();
        }



        @Override
        public View onCreateView(LayoutInflater inflater, ViewGroup container,Bundle savedInstanceState) {
            this.setHasOptionsMenu(true);

            View view = inflater.inflate(R.layout.twitter_fragment, container, false);
            this.list = (ListView) view.findViewById(R.id.twitter_list);
            this.list.setEmptyView(view.findViewById(R.id.twitter_empty));


            ArrayList<Status> list    = DataStorage.getTwitterData();
            if (list!=null && list.size()>0) {
                this.setItemsInListview(list);
            }
            this.startProgressBarAnimation();
            this.startService();

            return view;
        }


        private void setItemsInListview(final ArrayList<Status> items) {
            if (items==null) {
                return;
            }
            FragmentActivity parentActivity = getActivity();
            if(parentActivity != null) {
                parentActivity.runOnUiThread(new Runnable() {

                    @Override
                    public void run() {
                        TwitterFragment.this.list.setAdapter(new TwitterAdapter(getActivity(), R.layout.tweet_item,items));
                        if (TwitterFragment.savedInstance!=null) {
                            int index = TwitterFragment.savedInstance.getInt("index", -1);
                            int top   = TwitterFragment.savedInstance.getInt("top", 0);
                            if(index!=-1){
                                TwitterFragment.this.list.setSelectionFromTop(index, top);
                            }
                        }
                    }

                });
            }
        }


    @Override
    public void onCreateOptionsMenu(Menu menu, MenuInflater inflater) {
        inflater.inflate(R.menu.menu_twitter_fragment, menu);
    }


    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        super.onOptionsItemSelected(item);
        switch (item.getItemId()) {

            case R.id.action_refresh:
                Toast.makeText(this.getActivity().getApplicationContext(), getResources().getString(R.string.action_refresh), Toast.LENGTH_SHORT).show();
                    this.startService();
                break;

            case R.id.action_tweet:
                Uri uri = Uri.parse("https://twitter.com/intent/tweet?text=@culturarocafort  ");
                Intent browserIntent = new Intent(Intent.ACTION_VIEW,uri);
                startActivity(browserIntent);

                break;

            default:
                return super.onOptionsItemSelected(item);
        }

        return true;
    }


    private void startService() {
        try {
            IntentFilter intentFilter = new IntentFilter("com.andreums.culturarocafort.downloaded.twitter");

            if (!TwitterFragment.isRegistered && this.receiver==null ) {
                this.receiver             = new TwitterBroadcastReceiver();
                getActivity().registerReceiver(this.receiver, intentFilter);
                TwitterFragment.isRegistered = true;
            }
            Intent intent = new Intent(this.getActivity(), TwitterDownloaderService.class);
            intent.putExtra("url", Constants.twitterURL);
            getActivity().startService(intent);

        }
        catch (Exception ex) {
            ex.printStackTrace();
        }
    }

    private class TwitterBroadcastReceiver extends BroadcastReceiver {

        @Override
        public void onReceive(Context context, Intent intent) {
            ArrayList<Status> list    = DataStorage.getTwitterData();
            TwitterFragment.this.setItemsInListview(list);
            TwitterFragment.this.stopProgressBarAnimation();
        }

    }



    public void startProgressBarAnimation() {
        DataStorage.pushProcess();
        this.getActivity().setProgressBarIndeterminateVisibility(true);

    }

    public void stopProgressBarAnimation() {
        DataStorage.popProcess();
        this.getActivity().setProgressBarIndeterminateVisibility(false);
    }


    private void setActionBar() {
        ActionBar bar = ( (ActionBarActivity) getActivity()).getSupportActionBar();
        bar.setTitle(getResources().getString(R.string.bar_title_twitter));
    }

    @Override
    public void setUserVisibleHint(boolean isVisibleToUser) {
        super.setUserVisibleHint(isVisibleToUser);
        if (isVisibleToUser) {
            this.setActionBar();
        }
    }

    @Override
    public void onSaveInstanceState(Bundle outState) {

        int index = this.list.getFirstVisiblePosition();
        View v    = this.list.getChildAt(0);
        int top   = (v == null) ? 0 : v.getTop();

        outState.putInt("index", index);
        outState.putInt("top", top);

        TwitterFragment.savedInstance = outState;
        super.onSaveInstanceState(outState);
    }

}