package com.andreums.culturarocafort.fragments.videos;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.os.Bundle;
import android.support.v4.app.Fragment;
import android.support.v4.app.FragmentActivity;
import android.support.v7.app.ActionBar;
import android.support.v7.app.ActionBarActivity;
import android.view.LayoutInflater;
import android.view.Menu;
import android.view.MenuInflater;
import android.view.MenuItem;
import android.view.View;
import android.view.ViewGroup;
import android.webkit.WebView;
import android.webkit.WebViewClient;
import android.widget.AdapterView;
import android.widget.ListView;
import android.widget.Toast;

import com.andreums.culturarocafort.Constants;
import com.andreums.culturarocafort.MainActivity;
import com.andreums.culturarocafort.R;
import com.andreums.culturarocafort.activities.video.VideoPlayerActivity;
import com.andreums.culturarocafort.adapters.videos.VideoAdapter;
import com.andreums.culturarocafort.database.VideosDatabaseHandler;
import com.andreums.culturarocafort.fragments.other.WebViewFragment;
import com.andreums.culturarocafort.models.Video;
import com.andreums.culturarocafort.services.YoutubeVideoDownloaderService;
import com.andreums.culturarocafort.util.DataStorage;



import java.util.ArrayList;

public class VideoFragment extends Fragment {

    private static Bundle savedInstance;
    private ListView list;
        private VideoBroadcastReceiver receiver;

        @Override
        public void onCreate (Bundle savedInstanceState) {
            super.onCreate(savedInstanceState);
            setHasOptionsMenu(true);
        }

        @Override
        public void onStart() {
            super.onStart();
            this.startService();
        }

        @Override
        public void onStop() {
            super.onStop();
            onSaveInstanceState(new Bundle());
        }

        @Override
        public void onPause() {
            super.onPause();
            try {
                if (this.receiver != null) {
                    getActivity().unregisterReceiver(this.receiver);
                    this.receiver = null;
                }
            }
            catch(Exception e) {
                e.printStackTrace();
            }
        }

        @Override
        public void onResume() {
            super.onResume();
            ArrayList<Video> videos = this.getVideosFromDatabase();
            if (videos.size()==0) {
                this.startProgressBarAnimation();
                this.startService();
            }
            else {
                this.setItemsInListview(videos);
            }

        }



        @Override
        public View onCreateView(LayoutInflater inflater, ViewGroup container,Bundle savedInstanceState) {
            this.setHasOptionsMenu(true);

            View view = inflater.inflate(R.layout.video_fragment, container, false);
            this.list = (ListView) view.findViewById(R.id.video_list);
            this.list.setEmptyView(view.findViewById(R.id.video_empty));

            ArrayList<Video> videos = this.getVideosFromDatabase();
            if (videos.size()>0) {
                this.setItemsInListview(videos);
            }
            this.startProgressBarAnimation();
            return view;
        }


        private void setItemsInListview(final ArrayList<Video> items) {
            if (items==null) {
                return;
            }


            this.list.setOnItemClickListener(
                    new AdapterView.OnItemClickListener() {
                        @Override
                        public void onItemClick(AdapterView<?> adapterView, View view, int i, long l) {
                            Video item = (Video) VideoFragment.this.list.getItemAtPosition(i);
                            String id  = item.getId();
                            DataStorage.setVideo(item);
                            String url = item.getUrl();

                            if (MainActivity.mTwoPane) {
                                WebView webView = WebViewFragment.getWebView();
                                if (webView!=null) {
                                    webView.loadUrl(url);
                                    webView.getSettings().setJavaScriptEnabled(true);
                                    webView.setWebViewClient(new WebViewClient() {
                                        public boolean shouldOverrideUrlLoading(WebView viewx, String urlx) {
                                            viewx.loadUrl(urlx);
                                            return false;
                                        }
                                    });
                                }
                            }
                            else {

                                Intent videoClient = new Intent(VideoFragment.this.getActivity().getApplicationContext(), VideoPlayerActivity.class);
                                videoClient.putExtra("videoID",id);
                                startActivity(videoClient);
                            }
                        }
                    }
            );

            FragmentActivity parentActivity = getActivity();
            if(parentActivity != null) {
                parentActivity.runOnUiThread(new Runnable() {



                    @Override
                    public void run() {
                        VideoFragment.this.list.setAdapter(new VideoAdapter(getActivity(), R.layout.post_item,items));

                        if (VideoFragment.savedInstance!=null) {
                            int index = VideoFragment.savedInstance.getInt("index", -1);
                            int top   = VideoFragment.savedInstance.getInt("top", 0);
                            if(index!=-1){
                                VideoFragment.this.list.setSelectionFromTop(index, top);
                            }
                        }
                    }

                });
            }
        }


    @Override
    public void onCreateOptionsMenu(Menu menu, MenuInflater inflater) {
        //inflater.inflate(R.menu.menu_fragments, menu);
    }


    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        super.onOptionsItemSelected(item);
        switch (item.getItemId()) {

            case R.id.action_refresh:
                Toast.makeText(this.getActivity().getApplicationContext(), getResources().getString(R.string.action_refresh), Toast.LENGTH_SHORT).show();

                this.startProgressBarAnimation();
                this.startService();
                break;

            default:
                return super.onOptionsItemSelected(item);
        }

        return true;
    }


    private void startService() {
        try {
            IntentFilter intentFilter = new IntentFilter("com.andreums.culturarocafort.downloaded.videos");

            if (this.receiver == null) {
                this.receiver = new VideoBroadcastReceiver();
                getActivity().registerReceiver(this.receiver, intentFilter);
            }
            Intent intent = new Intent(this.getActivity(), YoutubeVideoDownloaderService.class);
            intent.putExtra("url", Constants.youtubeURL);
            getActivity().startService(intent);


        }
        catch (Exception ex) {
            ex.printStackTrace();
        }
    }

    private class VideoBroadcastReceiver extends BroadcastReceiver {

        @Override
        public void onReceive(Context context, Intent intent) {
            ArrayList<Video> list    = DataStorage.getVideos();
            VideoFragment.this.setItemsInListview(list);
            VideoFragment.this.stopProgressBarAnimation();
        }

    }


    private void setActionBar() {
        ActionBar bar = ( (ActionBarActivity) getActivity()).getSupportActionBar();
        // TODO: Change
        bar.setTitle("Vídeos");
    }


    @Override
    public void setUserVisibleHint(boolean isVisibleToUser) {
        super.setUserVisibleHint(isVisibleToUser);
        if (isVisibleToUser) {
            this.setActionBar();
        }
    }

    public void startProgressBarAnimation() {
        DataStorage.pushProcess();
        this.getActivity().setProgressBarIndeterminateVisibility(true);

    }

    public void stopProgressBarAnimation() {
        DataStorage.popProcess();
        this.getActivity().setProgressBarIndeterminateVisibility(false);
    }

    private ArrayList<Video> getVideosFromDatabase() {
        ArrayList<Video> videos;
        VideosDatabaseHandler handler = VideosDatabaseHandler.getInstance(getActivity().getBaseContext());
        videos                        = handler.getVideos();
        return videos;
    }


    @Override
    public void onSaveInstanceState(Bundle outState) {

        int index = this.list.getFirstVisiblePosition();
        View v    = this.list.getChildAt(0);
        int top   = (v == null) ? 0 : v.getTop();

        outState.putInt("index", index);
        outState.putInt("top", top);

        VideoFragment.savedInstance = outState;
        super.onSaveInstanceState(outState);
    }

}