package com.andreums.culturarocafort.fragments.videos;

import android.content.Intent;
import android.os.Bundle;
import android.support.v4.app.Fragment;
import android.support.v4.app.FragmentActivity;
import android.support.v7.app.ActionBar;
import android.support.v7.app.ActionBarActivity;
import android.view.LayoutInflater;
import android.view.Menu;
import android.view.MenuInflater;
import android.view.MenuItem;
import android.view.View;
import android.view.ViewGroup;
import android.widget.AdapterView;
import android.widget.ImageView;
import android.widget.ListView;
import android.widget.TextView;
import android.widget.Toast;

import com.andreums.culturarocafort.R;
import com.andreums.culturarocafort.activities.video.VideoPlayerActivity;
import com.andreums.culturarocafort.adapters.videos.VideoAdapter;
import com.andreums.culturarocafort.database.VideosDatabaseHandler;
import com.andreums.culturarocafort.models.Video;
import com.andreums.culturarocafort.models.VideoPlayList;


import com.squareup.picasso.Picasso;

import java.util.ArrayList;

public class VideoPlayListViewerFragment extends Fragment {

    private static Bundle savedInstance;
    private ListView list;
    VideoPlayList playlist;

    @Override
    public void onCreate (Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setHasOptionsMenu(true);
        this.playlist  = this.getPlayListFromIntent();


    }

    @Override
    public void onResume() {
        super.onResume();
        //ArrayList<Post> posts = this.getPostsFromDatabase(this.categories);
        /*if (posts.size()>0) {
            this.setItemsInListview(posts);
        }*/
    }


    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container,Bundle savedInstanceState) {

        this.setHasOptionsMenu(true);
        View view = inflater.inflate(R.layout.video_playlist_viewer_fragment, container, false);
        this.list = (ListView) view.findViewById(R.id.playlist_videos_list);
        this.list.setEmptyView(view.findViewById(R.id.post_category_empty));
        this.list.addHeaderView(inflater.inflate(R.layout.video_playlist_viewer_header,null));

        TextView title = (TextView) view.findViewById(R.id.playlist_title);
        title.setText(this.playlist.getTitle());

        TextView description = (TextView) view.findViewById(R.id.playlist_description);
        description.setText(this.playlist.getDescription());

        ImageView image = (ImageView) view.findViewById(R.id.playlist_image);
        image.setScaleType(ImageView.ScaleType.CENTER_CROP);
        Picasso.with(this.getActivity().getApplicationContext()).load(this.playlist.getThumbnail()).placeholder(R.drawable.ic_launcher).error(R.drawable.ic_launcher).into(image);

        ArrayList<Video> videos = this.playlist.getVideos(this.getActivity().getApplicationContext());
        /*PostCategory category = this.getPostCategory(this.categories[0]);*/
        /*if (category!=null) {
            title.setText(category.getTitle());
        }*/
        if (videos.size()>0) {
            this.setItemsInListview(videos);
        }

        return view;
    }


    private void setItemsInListview(final ArrayList<Video> items) {


        this.list.setOnItemClickListener(
                new AdapterView.OnItemClickListener() {
                    @Override
                    public void onItemClick(AdapterView<?> adapterView, View view, int i, long l) {
                        if (i>0) {
                            Video item = (Video) VideoPlayListViewerFragment.this.list.getItemAtPosition(i);
                            String id = item.getId();

                            Intent videoClient = new Intent(VideoPlayListViewerFragment.this.getActivity().getApplicationContext(), VideoPlayerActivity.class);
                            videoClient.putExtra("videoID",id);
                            startActivity(videoClient);
                        }
                    }
                }
        );

        FragmentActivity parentActivity = getActivity();
        if(parentActivity != null) {
            parentActivity.runOnUiThread(new Runnable() {



                @Override
                public void run() {
                    VideoPlayListViewerFragment.this.list.setAdapter(new VideoAdapter(getActivity(), R.layout.video_item,items));

                    int index = -1;
                    int top   = 0;

                    if (VideoPlayListViewerFragment.savedInstance != null) {
                        // Restore last state for checked position.
                        index = VideoPlayListViewerFragment.savedInstance.getInt("index", -1);
                        top   = VideoPlayListViewerFragment.savedInstance.getInt("top", 0);
                    }
                    if(index!=-1){
                        final int finalIndex = index;
                        final int finalTop = top;
                        VideoPlayListViewerFragment.this.list.setSelectionFromTop(finalIndex, finalTop);
                    }

                }

            });
        }
    }


    @Override
    public void onCreateOptionsMenu(Menu menu, MenuInflater inflater) {
        inflater.inflate(R.menu.menu_fragments, menu);
    }


    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        super.onOptionsItemSelected(item);
        switch (item.getItemId()) {

            case R.id.action_refresh:
                Toast.makeText(this.getActivity().getApplicationContext(), getResources().getString(R.string.action_refresh), Toast.LENGTH_SHORT).show();
                break;

            default:
                return super.onOptionsItemSelected(item);
        }

        return true;
    }

    private void setActionBar() {
        ActionBar bar = ( (ActionBarActivity) getActivity()).getSupportActionBar();
        bar.setTitle(getResources().getString(R.string.bar_posts_title));
    }


    @Override
    public void setUserVisibleHint(boolean isVisibleToUser) {
        super.setUserVisibleHint(isVisibleToUser);
        if (isVisibleToUser) {
            this.setActionBar();
        }
    }

    public VideoPlayList getPlayListFromIntent() {
        Bundle bundle                 = this.getArguments();
        String id                     = bundle.getString("id");
        VideosDatabaseHandler handler = VideosDatabaseHandler.getInstance(this.getActivity().getApplicationContext());
        VideoPlayList   playList      = handler.getPlayList(id);
        return playList;
    }


    @Override
    public void onSaveInstanceState(Bundle outState) {

        int index = this.list.getFirstVisiblePosition();
        View v    = this.list.getChildAt(0);
        int top   = (v == null) ? 0 : v.getTop();


        outState.putInt("index", index);
        outState.putInt("top", top);

        VideoPlayListViewerFragment.savedInstance = outState;
        super.onSaveInstanceState(outState);
    }
}