package com.andreums.culturarocafort.fragments.videos;

import android.os.Bundle;
import android.support.v4.app.Fragment;
import android.support.v4.app.FragmentManager;
import android.view.LayoutInflater;
import android.view.Menu;
import android.view.MenuInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.TabHost;

import com.andreums.culturarocafort.R;
import com.andreums.culturarocafort.util.DataStorage;


public class VideosFragment extends Fragment implements TabHost.OnTabChangeListener {

    private TabHost tabHost;
    private static int currentTab;

    @Override
    public void onResume() {
        super.onResume();

        if (currentTab==0) {
            this.updateTab("video_channel",R.id.tab_1);
        }
        else {
            this.updateTab("video_playlists", R.id.tab_2);
        }
        this.tabHost.setCurrentTab(currentTab);
    }

    @Override
    public void onCreate (Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setHasOptionsMenu(true);
    }

    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container,Bundle savedInstanceState) {
        View view    = inflater.inflate(R.layout.videos_fragment, container, false);
        this.tabHost = (TabHost) view.findViewById(R.id.videos_tabhost);
        this.setupTabs();

        this.tabHost.setOnTabChangedListener(this);
        this.tabHost.setCurrentTab(0);
        // manually start loading stuff in the first tab
        updateTab("video_channel", R.id.tab_1);


        return view;
    }

    public void startProgressBarAnimation() {
        DataStorage.pushProcess();
        this.getActivity().setProgressBarIndeterminateVisibility(true);

    }

    public void stopProgressBarAnimation() {
        DataStorage.popProcess();
        this.getActivity().setProgressBarIndeterminateVisibility(false);
    }


    private void setupTabs() {
        this.tabHost.setup(); // you must call this before adding your tabs!
        this.tabHost.addTab(newTab("video_channel",getString(R.string.videos_tab_videos), R.id.tab_1));
        this.tabHost.addTab(newTab("video_playlists",getString(R.string.videos_tab_playlists), R.id.tab_2));
    }

    @Override
    public void onCreateOptionsMenu(Menu menu, MenuInflater inflater) {
        inflater.inflate(R.menu.menu_fragments, menu);
    }

    private TabHost.TabSpec newTab(String tag, String labelId, int tabContentId) {
        /*View indicator = LayoutInflater.from(getActivity()).inflate(
                R.layout.videos_fragment,
                (ViewGroup) this.getView().findViewById(android.R.id.tabs), false);
        //((TextView) indicator.findViewById(R.id.text)).setText(labelId);*/

        TabHost.TabSpec tabSpec = this.tabHost.newTabSpec(tag);
        tabSpec.setIndicator(labelId);
        tabSpec.setContent(tabContentId);
        return tabSpec;
    }

    @Override
    public void onTabChanged(String tabId) {
        if (tabId.equals("video_channel")) {
            currentTab = 0;
            updateTab(tabId, R.id.tab_1);

            return;
        }
        if (tabId.equals("video_playlists")) {
            currentTab = 1;
            updateTab(tabId, R.id.tab_2);

            return;
        }
    }



    private void updateTab(String tabId, int placeholder) {
        FragmentManager fm = VideosFragment.this.getActivity().getSupportFragmentManager();
        if (fm.findFragmentByTag(tabId) == null) {
            Fragment fragment = null;
            if (currentTab==0) {
                fragment = new VideoFragment();
            }
            else {
                fragment = new VideoPlayListFragment();
            }
            fm.beginTransaction().replace(placeholder, fragment).commit();
            //fm.beginTransaction().addToBackStack(null).replace(placeholder, fragment, tabId).commit();
        }
    }
}