package com.andreums.culturarocafort.notification;

import android.app.Notification;
import android.app.NotificationManager;
import android.app.PendingIntent;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.media.RingtoneManager;
import android.os.Build;
import android.support.v4.app.NotificationCompat;

import com.andreums.culturarocafort.Constants;
import com.andreums.culturarocafort.MainActivity;
import com.andreums.culturarocafort.R;
import com.andreums.culturarocafort.database.GCMDatabaseHandler;
import com.andreums.culturarocafort.models.GCMMessage;
import com.andreums.culturarocafort.services.CategoryDownloaderService;
import com.andreums.culturarocafort.services.EventsDownloadService;
import com.andreums.culturarocafort.services.FacebookAlbumDownloaderService;
import com.andreums.culturarocafort.services.FacebookPostsDownloaderService;
import com.andreums.culturarocafort.services.FirstTimeDownloaderService;
import com.andreums.culturarocafort.services.PostDownloaderService;
import com.andreums.culturarocafort.services.TwitterDownloaderService;
import com.andreums.culturarocafort.services.YoutubeVideoDownloaderService;
import com.andreums.culturarocafort.util.DataStorage;
import com.andreums.culturarocafort.util.DateUtils;

import java.util.Random;

public class Notifier {

    private Context context;
    private static Notifier instance;
    private String title;
    private String message;
    private UpdaterBroadcastReceiver receiver;
    private NotificationCompat.Builder builder;
    private int lastId;
    private int lastCode;

    public static Notifier getInstance() {
        if (Notifier.instance == null) {
            Notifier.instance = new Notifier();
        }
        return Notifier.instance;
    }

    private void endNotificationProgress() {


        String title   = "";
        String message = "";

        switch (this.lastCode) {

            case 1:
                break;

            case 2:
                title   = context.getResources().getString(R.string.gcm_event_loaded);
                message = context.getResources().getString(R.string.gcm_event_message_loaded);
                break;

            case 3:
                title   = context.getResources().getString(R.string.gcm_news_loaded);
                message = context.getResources().getString(R.string.gcm_news_message_loaded);
                break;

            case 4:
                title   = context.getResources().getString(R.string.gcm_video_loaded);
                message = context.getResources().getString(R.string.gcm_video_message_loaded);
                break;

            case 5:
                title   = context.getResources().getString(R.string.gcm_facebook_loaded);
                message = context.getResources().getString(R.string.gcm_facebook_message_loaded);
                break;

            case 6:
                title   = context.getResources().getString(R.string.gcm_facebook_photo_loaded);
                message = context.getResources().getString(R.string.gcm_facebook_photo_message_loaded);
                break;

            case 7:
                title   = context.getResources().getString(R.string.gcm_reload_loaded);
                message = context.getResources().getString(R.string.gcm_reload_message_loaded);
                break;


            case 8:
                title   = context.getResources().getString(R.string.gcm_twitter_loaded);
                message = context.getResources().getString(R.string.gcm_twitter_message_loaded);
                break;

            case 9:
                title   = context.getResources().getString(R.string.gcm_categories_loaded);
                message = context.getResources().getString(R.string.gcm_categories_message_loaded);
                break;

        }

        if (this.lastCode>10) {
            return;
        }

        Notifier.this.builder.setProgress(0,0,false);
        Notifier.this.builder.setContentTitle(title);
        Notifier.this.builder.setContentText(message);
        Notifier.this.builder.setSound(RingtoneManager.getDefaultUri(RingtoneManager.TYPE_NOTIFICATION));

        String notificationService              = Context.NOTIFICATION_SERVICE;
        NotificationManager notificationManager = (NotificationManager) context.getSystemService(notificationService);

        notificationManager.notify(Notifier.this.lastId,builder.build());
    }

    private void createMessageTexts(int code,String msg,String sTitle) {

        String title   = "";
        String message = "";

        switch (code) {

            case 0:
                if (sTitle.length()==0) {
                    title   = context.getResources().getString(R.string.gcm_message);
                }
                message = msg;
                break;

            case 1:
                if (sTitle.length()==0) {
                    title   = context.getResources().getString(R.string.gcm_message);
                }
                message = msg;
                break;

            case 2:
                title   = context.getResources().getString(R.string.gcm_event);
                message = context.getResources().getString(R.string.gcm_event_message);
                this.startEventUpdater();
                break;

            case 3:
                title   = context.getResources().getString(R.string.gcm_news);
                message = context.getResources().getString(R.string.gcm_news_message);
                this.startPostUpdater();
                break;

            case 4:
                title   = context.getResources().getString(R.string.gcm_video);
                message = context.getResources().getString(R.string.gcm_video_message);
                this.startVideoUpdater();
                break;

            case 5:
                title   = context.getResources().getString(R.string.gcm_facebook);
                message = context.getResources().getString(R.string.gcm_facebook_message);
                this.startFacebookUpdater();
                break;

            case 6:
                title   = context.getResources().getString(R.string.gcm_facebook_photo);
                message = context.getResources().getString(R.string.gcm_facebook_photo_message);
                this.startFacebookPhotosUpdater();
                break;

            case 7:
                title   = context.getResources().getString(R.string.gcm_reload);
                message = context.getResources().getString(R.string.gcm_reload_message);
                this.startGlobalUpdater();
                break;


            case 8:
                title   = context.getResources().getString(R.string.gcm_twitter);
                message = context.getResources().getString(R.string.gcm_twitter_message);
                this.startTwitterUpdater();
                break;

            case 9:
                title   = context.getResources().getString(R.string.gcm_categories);
                message = context.getResources().getString(R.string.gcm_categories_message);
                this.startCategoriesUpdater();
                break;


            case 11:
                this.startEventUpdater();
                break;

            case 12:
                this.startPostUpdater();
                break;

            case 13:
                this.startVideoUpdater();
                break;

            case 14:
                this.startFacebookUpdater();
                break;

            case 15:
                this.startFacebookPhotosUpdater();
                break;

            case 16:
                this.startGlobalUpdater();
                break;


            case 17:
                this.startTwitterUpdater();
                break;

            case 18:
                this.startCategoriesUpdater();
                break;


            default:
                break;
        }


        if (sTitle.length()>0) {
            this.title = sTitle;
        }
        else {
            this.title   = title;
        }
        this.message = message;
    }



    private void startGlobalUpdater() {
        try {
            IntentFilter intentFilter = new IntentFilter("com.andreums.culturarocafort.downloaded.global");
            this.receiver             = new UpdaterBroadcastReceiver();
            this.context.registerReceiver(this.receiver,intentFilter);

            Intent intent = new Intent(this.context, FirstTimeDownloaderService.class);
            intent.putExtra("url", Constants.getEventsURL(this.context));
            this.context.startService(intent);
        }
        catch (Exception ex) {
            ex.printStackTrace();
        }
    }

    private void startEventUpdater() {
        try {
            IntentFilter intentFilter = new IntentFilter("com.andreums.culturarocafort.downloaded.events");
            this.receiver             = new UpdaterBroadcastReceiver();
            this.context.registerReceiver(this.receiver,intentFilter);

            Intent intent = new Intent(this.context, EventsDownloadService.class);
            intent.putExtra("url", Constants.getEventsURL(this.context));
            this.context.startService(intent);
        }
        catch (Exception ex) {
            ex.printStackTrace();
        }
    }


    private void startPostUpdater() {
        try {
            IntentFilter intentFilter = new IntentFilter("com.andreums.culturarocafort.downloaded.posts");
            this.receiver             = new UpdaterBroadcastReceiver();
            this.context.registerReceiver(this.receiver,intentFilter);

            Intent intent = new Intent(this.context, PostDownloaderService.class);
            intent.putExtra("url", Constants.getPostsURL(this.context));
            this.context.startService(intent);
        }
        catch (Exception ex) {
            ex.printStackTrace();
        }
    }

    private void startVideoUpdater() {
        try {
            IntentFilter intentFilter = new IntentFilter("com.andreums.culturarocafort.downloaded.videos");
            this.receiver             = new UpdaterBroadcastReceiver();
            this.context.registerReceiver(this.receiver,intentFilter);

            Intent intent = new Intent(this.context, YoutubeVideoDownloaderService.class);
            intent.putExtra("url", Constants.youtubeURL);
            this.context.startService(intent);
        }
        catch (Exception ex) {
            ex.printStackTrace();
        }
    }

    private void startFacebookUpdater() {
        try {
            IntentFilter intentFilter = new IntentFilter("com.andreums.culturarocafort.downloaded.facebook");
            this.receiver             = new UpdaterBroadcastReceiver();
            this.context.registerReceiver(this.receiver,intentFilter);

            Intent intent = new Intent(this.context, FacebookPostsDownloaderService.class);
            intent.putExtra("url", Constants.facebookFeed);
            this.context.startService(intent);
        }
        catch (Exception ex) {
            ex.printStackTrace();
        }
    }


    private void startTwitterUpdater() {
        try {
            IntentFilter intentFilter = new IntentFilter("com.andreums.culturarocafort.downloaded.twitter");
            this.receiver             = new UpdaterBroadcastReceiver();
            this.context.registerReceiver(this.receiver,intentFilter);

            Intent intent = new Intent(this.context, TwitterDownloaderService.class);
            this.context.startService(intent);
        }
        catch (Exception ex) {
            ex.printStackTrace();
        }
    }


    private void startCategoriesUpdater() {
        try {
            IntentFilter intentFilter = new IntentFilter("com.andreums.culturarocafort.downloaded.categories");
            this.receiver             = new UpdaterBroadcastReceiver();
            this.context.registerReceiver(this.receiver,intentFilter);

            Intent intent = new Intent(this.context, CategoryDownloaderService.class);
            intent.putExtra("url", Constants.getCategoriesURL(this.context));
            this.context.startService(intent);
        }
        catch (Exception ex) {
            ex.printStackTrace();
        }
    }

    private void startFacebookPhotosUpdater() {
        try {
            IntentFilter intentFilter = new IntentFilter("com.andreums.culturarocafort.downloaded.facebook.albums");
            this.receiver             = new UpdaterBroadcastReceiver();
            this.context.registerReceiver(this.receiver,intentFilter);

            Intent intent = new Intent(this.context, FacebookAlbumDownloaderService.class);
            intent.putExtra("url", Constants.facebookAlbums);
            this.context.startService(intent);
        }
        catch (Exception ex) {
            ex.printStackTrace();
        }
    }

    private GCMMessage createGCMMessage() {
        GCMMessage gcmMessage = new GCMMessage();
        gcmMessage.setTitle(this.title);
        gcmMessage.setMessage(this.message);
        gcmMessage.setReaded(false);
        gcmMessage.setReceived(DateUtils.getDateTimeNow());

        return gcmMessage;
    }

    private int insertGCMMessage(GCMMessage message) {
        int id = -1;
        GCMDatabaseHandler handler = GCMDatabaseHandler.getInstance(context);
        handler.insertMessage(message);

        id  = handler.getLastInsertedMessageId();
        return id;
    }

    public void displayNotification(Context context, int code, String msg,String title) {
        this.context                            = context;
        int idMessage                           = -1;
        String notificationService              = Context.NOTIFICATION_SERVICE;
        NotificationManager notificationManager = (NotificationManager) context.getSystemService(notificationService);

        this.createMessageTexts(code,msg,title);
        if (code<10) {
            GCMMessage gcmMessage = this.createGCMMessage();
            idMessage = this.insertGCMMessage(gcmMessage);
        }
        Intent intent         = new Intent(context, MainActivity.class);


        DataStorage.setGcmMessageId(idMessage);
        PendingIntent contIntent = PendingIntent.getActivity(context, 0, intent, PendingIntent.FLAG_UPDATE_CURRENT);

        this.builder = new NotificationCompat.Builder(context);

        long[] vibrate	= {100,100,200,300,10,141,512,22};


        if (Build.VERSION.SDK_INT <= Build.VERSION_CODES.JELLY_BEAN) {
            this.builder
                    .setContentTitle(this.title)
                    .setContentText(this.message)
                    .setTicker(this.title + "\n" + this.message)
                    .setSmallIcon(R.drawable.ic_stat_ic_launcher)
                    .setVibrate(vibrate)
                    .setContentIntent(contIntent)
                    .setAutoCancel(true);
        }
        else {
            this.builder
                    .setSmallIcon(R.drawable.ic_stat_ic_launcher)
                    .setContentTitle(this.title)
                    .setTicker(this.title + "\n" + this.message)
                    .setContentText(this.message)
                    .setContentIntent(contIntent)
                    .setDefaults(Notification.DEFAULT_ALL)
                    .setStyle(new NotificationCompat.BigTextStyle().bigText(message))
                    .setAutoCancel(true);
        }


        switch (code) {
            case 2:
            case 3:
            case 4:
            case 5:
            case 6:
            case 7:
            case 8:
            case 9:
                builder.setProgress(0,0,true);
             break;
        };


        Random r        = new Random();
        int id          = r.nextInt();
        this.lastId     = id;
        this.lastCode   = code;

        if (code>9) {
            return;
        }
        notificationManager.notify(id,this.builder.build());
    }

    private class UpdaterBroadcastReceiver extends BroadcastReceiver {

        @Override
        public void onReceive(Context context, Intent intent) {
            Notifier.this.endNotificationProgress();

        }

    }


}
