package com.andreums.culturarocafort.parsers;

import android.content.Context;

import com.andreums.culturarocafort.Constants;
import com.andreums.culturarocafort.models.FacebookPost;
import com.andreums.culturarocafort.util.DateUtils;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import java.util.ArrayList;

public class FacebookPostJSONParser {


    private Context context;

    public FacebookPostJSONParser(Context context) {
        this.context = context;
    }

    public ArrayList<FacebookPost> parseJSON(String data) {
        ArrayList<FacebookPost> items = new ArrayList<FacebookPost>();

        if ( (data!=null) && (data.length()>=0) ) {
            JSONObject object;
            JSONArray array;
            try {
                object =  new JSONObject(data);
                array  = object.getJSONArray("data");
                if (array.length()>0) {
                    for (int i=0;i<array.length();i++) {
                        JSONObject aux = (JSONObject) array.get(i);
                        FacebookPost item = this.parsePost(aux);
                        if (item!=null) {
                            items.add(item);
                        }
                    }
                }
            }
            catch (JSONException e) {
                e.printStackTrace();
            }
        }
        return items;
    }

    private FacebookPost parsePost(JSONObject aux) throws JSONException {
        FacebookPost item          = new FacebookPost();


        String id          = aux.getString("id");
        String type        = aux.getString("type");
        String published   = aux.getString("created_time");
        String updated     = aux.getString("updated_time");
        String thumbnail   = "assets://images/placeholder.png";
        String image       = "assets://images/placeholder.png";
        String caption     = "";
        String content     = "";
        String message     = "";
        String link        = "";
        String name        = "";
        //Constants.facebookPostURL.replace("POST_ID",id).replace("178576698948965_","");

        String from        = aux.getJSONObject("from").getString("id");
        if (!from.equals(Constants.facebookId)) {
            return null;
        }



        updated      = DateUtils.convertToFacebookDate(updated);
        published    = DateUtils.convertToFacebookDate(published);



        try {
            message = aux.getString("message");
        }
        catch (JSONException ex) {

        }

        try {
            name = aux.getString("name");
        }
        catch (JSONException ex) {

        }


        try {
            caption = aux.getString("caption");
        }
        catch (JSONException ex) {

        }

        try {
            link   = aux.getString("link");
        }
        catch (JSONException ex) {

        }

        try {
            content = aux.getString("description");
        }
        catch (JSONException ex) {

        }
        try {
            thumbnail = aux.getString("picture");
            if (thumbnail!=null) {
                image =  thumbnail.replace("_s","_n");
            }
        }
        catch (JSONException ex) {
        }

        if (image.contains("safe_image.php")) {
            try {
                String []urls = image.split("&url=");
                image         = URLDecoder.decode(urls[1],"UTF-8");
                thumbnail     = image;
            }
            catch (UnsupportedEncodingException e) {
                e.printStackTrace();
            }

        }

        if ( (message.length()==0) && (caption.length()==0) && (content.length()==0) ) {
            return null;
        }



        item.setId(id);
        item.setName(name);
        item.setCaption(caption);
        item.setLink(link);
        item.setPublished(published);
        item.setUpdated(updated);
        item.setContent(content);
        item.setImage(image);
        item.setThumbnail(thumbnail);
        item.setType(type);
        item.setMessage(message);
        return item;
    }



}