package com.andreums.culturarocafort.parsers;

import android.content.Context;

import com.andreums.culturarocafort.models.Video;
import com.andreums.culturarocafort.models.VideoPlayList;
import com.andreums.culturarocafort.util.DateUtils;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import java.util.ArrayList;

public class YoutubeJSONParser {


    private Context context;

    public YoutubeJSONParser(Context context) {
        this.context = context;
    }

    public ArrayList<Video> parseJSON(String data) {
        ArrayList<Video> items = new ArrayList<Video>();

        if ( (data!=null) && (data.length()>=0) ) {
            JSONObject object;
            JSONArray array;
            try {
                object =  new JSONObject(data);
                array  = object.getJSONArray("items");
                if (array.length()>0) {
                    for (int i=0;i<array.length();i++) {
                        JSONObject aux = (JSONObject) array.get(i);
                        Video item = this.parseVideo(aux);
                        if (item!=null) {
                            items.add(item);
                        }
                    }
                }
            }
            catch (JSONException e) {
                e.printStackTrace();
            }
        }
        return items;
    }

    private Video parseVideo(JSONObject aux) throws JSONException {
        Video item         = new Video();

        String kind        = aux.getJSONObject("id").getString("kind");
        if (kind.equals("youtube#channel") || kind.equals("youtube#playlist")) {
            return null;
        }

        JSONObject snippet = aux.getJSONObject("snippet");
        String id          = aux.getJSONObject("id").getString("videoId");
        String title       = snippet.getString("title");
        String description = snippet.getString("description");
        String published   = snippet.getString("publishedAt");
        published          = DateUtils.convertFromZuluDateToSQLiteFormat(published);

        String link        = "https://www.youtube.com/watch?v="+id+"&feature=youtube_gdata_player";
        String thumbnail   = "";


        JSONObject thumb   = null;
        try {
            thumb       = snippet.getJSONObject("thumbnails");
            thumbnail   = thumb.getJSONObject("high").getString("url");
        }
        catch (Exception ex) {

        }

        item.setId(id);
        item.setTitle(title);
        item.setUrl(link);
        item.setPublished(published);
        item.setDescription(description);
        item.setThumbnail(thumbnail);
        item.setIn_playlist(0);
        return item;
    }



    public ArrayList<VideoPlayList> parsePlayListFeedJSON(String data) {
        ArrayList<VideoPlayList> items = new ArrayList<VideoPlayList>();

        if ( (data!=null) && (data.length()>=0) ) {
            JSONObject object;
            JSONArray array;
            try {
                object =  new JSONObject(data);
                array  = object.getJSONArray("items");
                if (array.length()>0) {
                    for (int i=0;i<array.length();i++) {
                        JSONObject aux = (JSONObject) array.get(i);
                        VideoPlayList item = this.parsePlayListFeedItem(aux);
                        items.add(item);
                    }
                }
            }
            catch (JSONException e) {
                e.printStackTrace();
            }
        }
        return items;
    }

    private VideoPlayList parsePlayListFeedItem(JSONObject aux) throws JSONException {
        VideoPlayList item         = new VideoPlayList();

        JSONObject snippet = aux.getJSONObject("snippet");
        String id          = aux.getString("id");
        String title       = snippet.getString("title");
        String description = snippet.getString("description");

        String published   = snippet.getString("publishedAt");
        published          = DateUtils.convertFromZuluDateToSQLiteFormat(published);

        String link        = "";
        String thumbnail   = "";


        JSONObject thumb   = null;
        try {
            thumb       = snippet.getJSONObject("thumbnails").getJSONObject("high");
            thumbnail   = thumb.getString("url");
        }
        catch (Exception ex) {

        }

        item.setId(id);
        item.setTitle(title);
        item.setUrl(link);
        item.setPublished(published);
        item.setDescription(description);
        item.setThumbnail(thumbnail);
        return item;
    }


    public ArrayList<Video> parsePlayListJSONData(String data) {
        ArrayList<Video> videos = new ArrayList<Video>();
        if ( (data!=null) && (data.length()>=0) ) {
            JSONObject object;
            JSONArray array;
            try {
                object = new JSONObject(data);
                array  = object.getJSONArray("items");
                if (array.length()>0) {
                    for (int i=0;i<array.length();i++) {
                        JSONObject aux = (JSONObject) array.get(i);
                        Video item = this.parsePlayListItem(aux);
                        videos.add(item);
                    }
                }
            }
            catch (JSONException e) {
                e.printStackTrace();
            }
        }
        return videos;
    }

    private Video parsePlayListItem(JSONObject aux) throws JSONException  {

        Video item         = new Video();

        JSONObject snippet = aux.getJSONObject("snippet");

        String id          = snippet.getJSONObject("resourceId").getString("videoId");
        String title       = snippet.getString("title");
        String description = snippet.getString("description");
        String published   = snippet.getString("publishedAt");
        published          = DateUtils.convertFromZuluDateToSQLiteFormat(published);

        String link        = "";
        String thumbnail   = "";

        JSONObject thumb   = null;
        try {
            thumb       = snippet.getJSONObject("thumbnails");
            thumbnail   = thumb.getJSONObject("high").getString("url");
        }
        catch (Exception ex) {

        }

        link    = "https://www.youtube.com/watch?v="+id+"&feature=youtube_gdata_player";

        item.setId(id);
        item.setTitle(title);
        item.setUrl(link);
        item.setPublished(published);
        item.setDescription(description);
        item.setThumbnail(thumbnail);
        item.setIn_playlist(1);
        return item;
    }
}