package com.andreums.culturarocafort.services;

import android.app.IntentService;
import android.content.Intent;
import android.util.Log;

import com.andreums.culturarocafort.Constants;
import com.andreums.culturarocafort.database.CategoryDatabaseHandler;
import com.andreums.culturarocafort.models.Categories;
import com.andreums.culturarocafort.models.Event;
import com.andreums.culturarocafort.models.Events;
import com.andreums.culturarocafort.util.Connection;
import com.andreums.culturarocafort.util.DataStorage;
import com.andreums.culturarocafort.util.Downloader;
import com.andreums.culturarocafort.util.HttpUtil;
import com.andreums.culturarocafort.util.Preferences;
import com.fasterxml.jackson.databind.ObjectMapper;

import java.io.IOException;
import java.util.ArrayList;

public class CategoryDownloaderService extends IntentService {

    private String url;

    public CategoryDownloaderService() {
        super("CategoriesDownloaderService");
    }


    @Override
    protected void onHandleIntent(Intent intent) {

        String data           = "";
        String url            = Constants.categoriesURL;
        this.url              = url;

        boolean expired         = this.hasExpired();
        boolean connection      = Connection.getConnectionStatus(this.getApplicationContext());
        boolean haveCategories  = this.haveCategories();

        Categories categories = new Categories();

        if ( (connection && expired) || (connection && !haveCategories) ) {
            data        = this.downloadData(url);
            categories  = this.processJSONData(data);
        }
        else if (haveCategories) {
            CategoryDatabaseHandler handler = CategoryDatabaseHandler.getInstance(this.getApplicationContext());
            categories.setEventCategories(handler.getEventCategories());
            categories.setCategories(handler.getPostCategories());
        }

        this.onServiceReturn(categories);
    }

    private Categories processJSONData(String data) {
        Categories categories = new Categories();
        ObjectMapper mapper   = new ObjectMapper();
        try {
            categories   = mapper.readValue(data,Categories.class);
        }
        catch (IOException e) {
            e.printStackTrace();
        }
        return categories;
    }

    private boolean haveCategories() {
        CategoryDatabaseHandler handler = CategoryDatabaseHandler.getInstance(this.getApplicationContext());
        return handler.haveCategories();
    }


    private String downloadData(String url) {
        String result         = "";
        Downloader downloader = new Downloader(url);
        downloader.invoke();

        result                = downloader.getResult();
        this.setEtag("categoriesETag",downloader.getETag());
        return result;
    }

    private boolean hasExpired() {
        if (Connection.getConnectionStatus(this.getApplicationContext())) {
            Preferences pref      = Preferences.getInstance(this.getApplicationContext());
            String lastEtag       = pref.getValue("categoriesETag");
            String eTag           = HttpUtil.getETag(this.url);
            return (! (lastEtag.equals(eTag)));
        }
        return false;
    }

    private void setEtag(String name,String value) {
        Preferences pref      = Preferences.getInstance(this.getApplicationContext());
        pref.setValue(name,value);
    }


    public void onServiceReturn(Categories data) {
        this.setCategoriesIntoDatabaseHandler(data);
        this.setCategoriesIntoDataStorage(data);
        Intent intentResponse = new Intent();
        intentResponse.setAction(Constants.CATEGORIES_DOWNLOADED);
        sendBroadcast(intentResponse);
    }

    private void setCategoriesIntoDataStorage(Categories data) {
        DataStorage.setPostCategories(data.getCategories());
        DataStorage.setEventCategories(data.getEventCategories());
    }

    private void setCategoriesIntoDatabaseHandler(Categories data) {
        CategoryDatabaseHandler handler = CategoryDatabaseHandler.getInstance(this.getApplicationContext());
        handler.clearCategories();
        handler.insertEventCategories(data.getEventCategories());
        handler.insertPostCategories(data.getCategories());
    }


}