package com.andreums.culturarocafort.services;

import android.app.IntentService;
import android.content.Intent;
import android.util.Log;

import com.andreums.culturarocafort.Constants;
import com.andreums.culturarocafort.database.EventDatabaseHandler;
import com.andreums.culturarocafort.models.Event;
import com.andreums.culturarocafort.models.Events;
import com.andreums.culturarocafort.util.Connection;
import com.andreums.culturarocafort.util.DataStorage;
import com.andreums.culturarocafort.util.Downloader;
import com.andreums.culturarocafort.util.HttpUtil;
import com.andreums.culturarocafort.util.Preferences;
import com.fasterxml.jackson.databind.ObjectMapper;

import java.io.IOException;
import java.util.ArrayList;

public class EventsDownloadService extends IntentService {

    private String url;

    public EventsDownloadService() {
        super("EventDownloaderService");
    }


    @Override
    protected void onHandleIntent(Intent intent) {

        String data           = "";
        String url            = Constants.eventsURL;
        this.url              = url;
        ArrayList<Event> events = new ArrayList<Event>();
        boolean expired       = this.hasExpired();
        boolean connection    = Connection.getConnectionStatus(this.getApplicationContext());
        boolean havePosts     = this.haveEvents();

        if ( (connection && expired) || (connection && !havePosts) ) {
            data    = this.downloadData(url);
            events  = this.processJSONData(data);
            if (events.size()>0) {
                this.setPostsIntoDatabaseHandler(events);
            }
        }
        else if (this.haveEvents()) {
            EventDatabaseHandler handler = EventDatabaseHandler.getInstance(this.getApplicationContext());
            events = handler.getEvents();
        }

        this.setEventsInDataSetorage(events);
        this.onServiceReturn();
    }

    private ArrayList<Event> processJSONData(String data) {
        ArrayList<Event> lEevents = new ArrayList<Event>();
        ObjectMapper mapper   = new ObjectMapper();
        try {
            Events events   = mapper.readValue(data,Events.class);
            lEevents        = events.getPosts();
        }
        catch (IOException e) {
            e.printStackTrace();
        }
        return lEevents;
    }

    private boolean haveEvents() {
        EventDatabaseHandler handler = EventDatabaseHandler.getInstance(this.getApplicationContext());
        return handler.haveEvents();
    }

    private String downloadData(String url) {
        String result         = "";
        Downloader downloader = new Downloader(url);
        downloader.invoke();

        result                = downloader.getResult();
        this.setEtag("eventsETag",downloader.getETag());
        return result;
    }

    private boolean hasExpired() {
        if (Connection.getConnectionStatus(this.getApplicationContext())) {
            Preferences pref      = Preferences.getInstance(this.getApplicationContext());
            String lastEtag       = pref.getValue("eventsETag");
            String eTag           = HttpUtil.getETag(this.url);
            if (lastEtag.equals(eTag)) {
                return false;
            }
            return true;
        }
        return false;
    }

    private void setEtag(String name,String value) {
        Preferences pref      = Preferences.getInstance(this.getApplicationContext());
        pref.setValue(name,value);
    }




    public void onServiceReturn() {
        Intent intentResponse = new Intent();
        intentResponse.setAction("com.andreums.culturarocafort.downloaded.events");
        sendBroadcast(intentResponse);
    }


    private void setEventsInDataSetorage(ArrayList<Event> data) {
        DataStorage.setEvents(data);
    }

    private void setPostsIntoDatabaseHandler(ArrayList<Event> data) {
        EventDatabaseHandler handler = EventDatabaseHandler.getInstance(this.getApplicationContext());
        handler.clearEvents();
        handler.insertEvents(data);
    }



}