package com.andreums.culturarocafort.services;

import android.app.IntentService;
import android.content.Intent;
import android.util.Log;

import com.andreums.culturarocafort.Constants;
import com.andreums.culturarocafort.database.FacebookPhotosDatabaseHandler;
import com.andreums.culturarocafort.models.FacebookAlbum;
import com.andreums.culturarocafort.models.FacebookPhoto;
import com.andreums.culturarocafort.parsers.FacebookAlbumJSONParser;
import com.andreums.culturarocafort.parsers.FacebookAlbumPhotoJSONParser;
import com.andreums.culturarocafort.util.Connection;
import com.andreums.culturarocafort.util.DataStorage;
import com.andreums.culturarocafort.util.Downloader;
import com.andreums.culturarocafort.util.Preferences;

import java.util.ArrayList;
import java.util.Collections;

public class FacebookAlbumDownloaderService extends IntentService {

    private String url;

    public FacebookAlbumDownloaderService() {
        super("FacebookAlbumDownloaderService");
    }


    @Override
    protected void onHandleIntent(Intent intent) {

        ArrayList<FacebookAlbum> albums = new ArrayList<FacebookAlbum>();
        String url                      = intent.getStringExtra("url");
        this.url                        = url;
        boolean expired                 = this.hasExpired();

        if ( (Connection.getConnectionStatus(this.getApplicationContext())) && (expired) ) {
            albums = this.downloadData(url);
            FacebookPhotosDatabaseHandler handler = new FacebookPhotosDatabaseHandler(this.getApplicationContext());
            handler.clearAlbums();
            handler.insertAlbums(albums);
            albums = handler.getAlbums();
        }

        else if (!this.haveAlbums() && Connection.getConnectionStatus(this.getApplicationContext())) {
            albums = this.downloadData(url);
            FacebookPhotosDatabaseHandler handler = new FacebookPhotosDatabaseHandler(this.getApplicationContext());
            handler.clearAlbums();
            handler.insertAlbums(albums);
            albums = handler.getAlbums();
        }

        else if (this.haveAlbums()) {
            FacebookPhotosDatabaseHandler handler = new FacebookPhotosDatabaseHandler(this.getApplicationContext());
            albums = handler.getAlbums();
        }


        this.onServiceReturn(albums);
    }

    private ArrayList<FacebookAlbum> downloadData(String url) {
        ArrayList<FacebookAlbum> albums;
        Downloader downloader = new Downloader(url);
        downloader.invoke();
        String eTag           = downloader.getETag();
        String result         = downloader.getResult();
        FacebookAlbumJSONParser parser = new FacebookAlbumJSONParser(this.getApplicationContext());
        albums                = parser.parseJSON(result);
        this.setEtag("facebookAlbumsETag",eTag);

        FacebookPhotosDatabaseHandler handler = FacebookPhotosDatabaseHandler.getInstance(this.getApplicationContext());
        handler.clearPhotos();
        handler.clearAlbums();
        handler.insertAlbums(albums);

        for (FacebookAlbum album:albums) {
            ArrayList<FacebookPhoto> photos = this.downloadAlbumData(album.getId());

            handler.insertPhotos(photos);
        }

        return albums;
    }


    private ArrayList<FacebookPhoto> downloadAlbumData(String id) {
        ArrayList<FacebookPhoto> photos;

        String url            = Constants.facebookPhotos;
        url                   = url.replace("ALBUM_ID",id);

        if (this.hasExpiredAlbum(id)) {
            Downloader downloader = new Downloader(url);
            downloader.invoke();
            String eTag = downloader.getETag();
            String preferenceTag = "facebookAlbumsETag_" + id;
            this.setEtag(preferenceTag, eTag);
            String result = downloader.getResult();
            FacebookAlbumPhotoJSONParser parser = new FacebookAlbumPhotoJSONParser(this.getApplicationContext());
            photos = parser.parseJSON(result, id);
        }
        else {
            FacebookPhotosDatabaseHandler handler = FacebookPhotosDatabaseHandler.getInstance(this.getApplicationContext());
            photos = handler.getAlbumPhotos(id);
        }
        return photos;
    }


    public void onServiceReturn(ArrayList<FacebookAlbum> data) {
        Collections.reverse(data);
        DataStorage.setFacebookAlbums(data);
        Intent intentResponse = new Intent();
        intentResponse.setAction("com.andreums.culturarocafort.downloaded.facebook.albums");
        sendBroadcast(intentResponse);
    }

    private boolean haveAlbums() {
        FacebookPhotosDatabaseHandler handler = FacebookPhotosDatabaseHandler.getInstance(this.getApplicationContext());
        return handler.haveAlbums();
    }

    private boolean hasExpired() {
        if (Connection.getConnectionStatus(this.getApplicationContext())) {
            Preferences pref      = Preferences.getInstance(this.getApplicationContext());
            String lastEtag       = pref.getValue("facebookAlbumsETag");

            Downloader downloader = new Downloader(this.url);
            downloader.invoke();
            String eTag           = downloader.getETag();
            return (! (lastEtag.equals(eTag)));
        }
        return false;
    }


    private boolean hasExpiredAlbum(String id) {
        String preferenceTag = "facebookAlbumsETag_"+id;
        if (Connection.getConnectionStatus(this.getApplicationContext())) {
            Preferences pref      = Preferences.getInstance(this.getApplicationContext());
            String lastEtag       = pref.getValue(preferenceTag);

            String url            = Constants.facebookPhotos;
            url                   = url.replace("ALBUM_ID",id);
            Downloader downloader = new Downloader(url);
            downloader.invoke();
            String eTag           = downloader.getETag();
            return (! (lastEtag.equals(eTag)));
        }
        return false;
    }

    private void setEtag(String name,String value) {
        Preferences pref      = Preferences.getInstance(this.getApplicationContext());
        pref.setValue(name,value);
    }





}
