package com.andreums.culturarocafort.services;

import android.app.IntentService;
import android.content.Intent;
import android.util.Log;

import com.andreums.culturarocafort.database.FacebookPostsDatabaseHandler;
import com.andreums.culturarocafort.models.FacebookPost;
import com.andreums.culturarocafort.parsers.FacebookPostJSONParser;
import com.andreums.culturarocafort.util.Connection;
import com.andreums.culturarocafort.util.DataStorage;
import com.andreums.culturarocafort.util.Downloader;
import com.andreums.culturarocafort.util.HttpUtil;
import com.andreums.culturarocafort.util.Preferences;

import java.util.ArrayList;

public class FacebookPostsDownloaderService extends IntentService {

    private String url;

    public FacebookPostsDownloaderService() {
        super("FacebookPostsDownloaderService");
    }


    @Override
    protected void onHandleIntent(Intent intent) {

        ArrayList<FacebookPost> posts = new ArrayList<FacebookPost>();
        String url            = intent.getStringExtra("url");
        this.url              = url;

        if ( (Connection.getConnectionStatus(this.getApplicationContext())) && (this.hasExpired()) ) {
            posts = this.downloadData(url);
            FacebookPostsDatabaseHandler handler = FacebookPostsDatabaseHandler.getInstance(this.getApplicationContext());
            handler.clearPosts();
            handler.insertPosts(posts);
        }

        else if (!this.havePosts() && Connection.getConnectionStatus(this.getApplicationContext())) {
            posts = this.downloadData(url);
            FacebookPostsDatabaseHandler handler = FacebookPostsDatabaseHandler.getInstance(this.getApplicationContext());
            handler.clearPosts();
            handler.insertPosts(posts);
        }

        else if (this.havePosts()) {
            FacebookPostsDatabaseHandler handler = FacebookPostsDatabaseHandler.getInstance(this.getApplicationContext());
            posts = handler.getPostsSimple();
        }

        this.onServiceReturn(posts);
    }

    private boolean havePosts() {
        FacebookPostsDatabaseHandler handler = FacebookPostsDatabaseHandler.getInstance(this.getApplicationContext());
        return handler.havePosts();
    }


    private ArrayList<FacebookPost> downloadData(String url) {
        ArrayList<FacebookPost> posts;
        Downloader downloader = new Downloader(url);
        downloader.invoke();

        // Ojo: Aquí utilizamos la cabecera Last-Modified porque Facebook no envía datos de eTag
        String eTag           = downloader.getETag();
        String result         = downloader.getResult();
        FacebookPostJSONParser parser = new FacebookPostJSONParser(this.getApplicationContext());
        posts                 = parser.parseJSON(result);

        this.setEtag("facebookPostsETag",eTag);
        return posts;
    }

    private boolean hasExpired() {
        if (Connection.getConnectionStatus(this.getApplicationContext())) {
            Preferences pref      = Preferences.getInstance(this.getApplicationContext());
            String lastEtag       = pref.getValue("facebookPostsETag");
            String eTag           = HttpUtil.getETag(this.url);
            return (! (lastEtag.equals(eTag)));
        }
        return false;
    }

    private void setEtag(String name,String value) {
        Preferences pref      = Preferences.getInstance(this.getApplicationContext());
        pref.setValue(name,value);
    }


    public void onServiceReturn(ArrayList<FacebookPost> data) {
        DataStorage.setFacebookPosts(data);
        Intent intentResponse = new Intent();
        intentResponse.setAction("com.andreums.culturarocafort.downloaded.facebook");
        sendBroadcast(intentResponse);
    }



}
