package com.andreums.culturarocafort.services;

import android.app.IntentService;
import android.content.Intent;
import android.util.Log;

import com.andreums.culturarocafort.Constants;
import com.andreums.culturarocafort.database.EventDatabaseHandler;
import com.andreums.culturarocafort.database.FacebookPostsDatabaseHandler;
import com.andreums.culturarocafort.database.CategoryDatabaseHandler;
import com.andreums.culturarocafort.database.PostDatabaseHandler;
import com.andreums.culturarocafort.database.VideosDatabaseHandler;
import com.andreums.culturarocafort.models.Categories;
import com.andreums.culturarocafort.models.Event;
import com.andreums.culturarocafort.models.Events;
import com.andreums.culturarocafort.models.FacebookPost;
import com.andreums.culturarocafort.models.Post;
import com.andreums.culturarocafort.models.Posts;
import com.andreums.culturarocafort.models.Video;
import com.andreums.culturarocafort.parsers.FacebookPostJSONParser;
import com.andreums.culturarocafort.parsers.YoutubeJSONParser;
import com.andreums.culturarocafort.util.Connection;
import com.andreums.culturarocafort.util.DataStorage;
import com.andreums.culturarocafort.util.Downloader;
import com.andreums.culturarocafort.util.Preferences;
import com.fasterxml.jackson.databind.ObjectMapper;

import java.io.IOException;
import java.util.ArrayList;

public class FirstTimeDownloaderService extends IntentService {

    private String url;

    public FirstTimeDownloaderService() {
        super("FirstTimeDownloaderService");
    }


    @Override
    protected void onHandleIntent(Intent intent) {

        boolean result = false;
        if (Connection.getConnectionStatus(this.getApplicationContext())) {
            ArrayList<Post> posts                 = this.downloadPosts(Constants.getPostsURL(getApplicationContext()));
            ArrayList<Event> events               = this.downloadEvents(Constants.getEventsURL(getApplicationContext()));
            Categories categories                 = this.downloadCategories(Constants.getCategoriesURL(getApplicationContext()));
            /*Log.d("DEBUG","Loading FAcebook!");
            ArrayList<FacebookPost> facebookPosts = this.downloadFacebookPosts(Constants.facebookFeed);
            Log.d("DEBUG","Loading Videos!");
            ArrayList<Video> videos               = this.downloadVideos(Constants.youtubeURL);*/


            DataStorage.setPosts(posts);
            DataStorage.setEvents(events);
            DataStorage.setEventCategories(categories.getEventCategories());
            DataStorage.setPostCategories(categories.getCategories());
            /*DataStorage.setFacebookPosts(facebookPosts);
            DataStorage.setVideos(videos);*/



            result = true;
        }
        this.onServiceReturn(result);
    }

    private ArrayList<Post> downloadPosts(String url) {
        ArrayList<Post> posts = new ArrayList<Post>();
        Downloader downloader = new Downloader(url);
        downloader.invoke();
        String eTag           = downloader.getETag();
        String result         = downloader.getResult();
        ObjectMapper mapper   = new ObjectMapper();
        try {
            Posts mPosts = mapper.readValue(result,Posts.class);
            posts        = mPosts.getPosts();
        }
        catch (IOException e) {
            e.printStackTrace();
        }

        this.setEtag("postsETag",eTag);

        PostDatabaseHandler handler = PostDatabaseHandler.getInstance(this.getApplicationContext());
        handler.clearPosts();
        handler.insertPosts(posts);

        return posts;
    }


    private Categories downloadCategories(String url) {

        Downloader downloader = new Downloader(url);
        downloader.invoke();
        String eTag           = downloader.getETag();
        String result         = downloader.getResult();

        Categories categories = new Categories();
        ObjectMapper mapper   = new ObjectMapper();
        try {
            categories   = mapper.readValue(result,Categories.class);
        }
        catch (IOException e) {
            e.printStackTrace();
        }

        CategoryDatabaseHandler pHandler = CategoryDatabaseHandler.getInstance(this.getApplicationContext());
        pHandler.clearCategories();
        pHandler.insertPostCategories(categories.getCategories());
        pHandler.insertEventCategories(categories.getEventCategories());

        return categories;
    }


    private ArrayList<Event> downloadEvents(String url) {
        ArrayList<Event> lEevents = new ArrayList<Event>();
        Downloader downloader = new Downloader(url);
        downloader.invoke();
        String eTag           = downloader.getETag();
        String result         = downloader.getResult();

        ObjectMapper mapper   = new ObjectMapper();
        try {
            Events events   = mapper.readValue(result,Events.class);
            lEevents        = events.getPosts();
        }
        catch (IOException e) {
            e.printStackTrace();
        }

        EventDatabaseHandler handler = EventDatabaseHandler.getInstance(this.getApplicationContext());
        handler.clearEvents();
        handler.insertEvents(lEevents);

        return lEevents;
    }


    private ArrayList<FacebookPost> downloadFacebookPosts(String url) {
        ArrayList<FacebookPost> posts;
        Downloader downloader = new Downloader(url);
        downloader.invoke();
        String eTag           = downloader.getETag();
        String result         = downloader.getResult();
        FacebookPostJSONParser parser = new FacebookPostJSONParser(this.getApplicationContext());
        posts                 = parser.parseJSON(result);

        FacebookPostsDatabaseHandler handler = FacebookPostsDatabaseHandler.getInstance(this.getApplicationContext());
        handler.clearPosts();
        handler.insertPosts(posts);

        this.setEtag("facebookPostsETag",eTag);
        return posts;
    }

    private ArrayList<Video> downloadVideos(String url) {
        ArrayList<Video> videos;
        Downloader downloader = new Downloader(url);
        downloader.invoke();
        String eTag           = downloader.getETag();
        String result         = downloader.getResult();
        YoutubeJSONParser parser = new YoutubeJSONParser(this.getApplicationContext());
        videos                = parser.parseJSON(result);

        VideosDatabaseHandler handler = VideosDatabaseHandler.getInstance(this.getApplicationContext());
        handler.clearVideos();
        handler.insertVideos(videos);

        this.setEtag("videosETag",eTag);

        return videos;
    }


    public void onServiceReturn(boolean result) {
        Intent intentResponse = new Intent();
        intentResponse.setAction("com.andreums.culturarocafort.downloaded.global");
        sendBroadcast(intentResponse);
    }

    private void setEtag(String name,String value) {
        Preferences pref      = Preferences.getInstance(getApplicationContext());
        pref.setValue(name,value);
    }
}