package com.andreums.culturarocafort.services;

import android.app.IntentService;
import android.content.Intent;
import android.util.Log;

import com.andreums.culturarocafort.Constants;
import com.andreums.culturarocafort.database.CategoryDatabaseHandler;
import com.andreums.culturarocafort.database.FacebookPhotosDatabaseHandler;
import com.andreums.culturarocafort.database.PostDatabaseHandler;
import com.andreums.culturarocafort.models.Categories;
import com.andreums.culturarocafort.models.Post;
import com.andreums.culturarocafort.models.Posts;
import com.andreums.culturarocafort.util.Connection;
import com.andreums.culturarocafort.util.DataStorage;
import com.andreums.culturarocafort.util.Downloader;
import com.andreums.culturarocafort.util.HttpUtil;
import com.andreums.culturarocafort.util.Preferences;
import com.fasterxml.jackson.databind.ObjectMapper;

import java.io.IOException;
import java.util.ArrayList;

public class PostDownloaderService extends IntentService {

    private String url;

    public PostDownloaderService() {
        super("PostDownloaderService");
    }


    @Override
    protected void onHandleIntent(Intent intent) {

        String data           = "";
        String url            = Constants.postsURL;
        this.url              = url;
        ArrayList<Post> posts = new ArrayList<Post>();
        boolean expired       = this.hasExpired();
        boolean connection    = Connection.getConnectionStatus(this.getApplicationContext());
        boolean havePosts     = this.havePosts();


        if ( (connection && expired) || (connection && !havePosts) ) {
            data  = this.downloadData(url);
            posts = this.processJSONData(data);

            if (posts.size()>0) {
                this.setPostsIntoDatabaseHandler(posts);
            }
        }
        else if (this.havePosts()) {
            PostDatabaseHandler handler = PostDatabaseHandler.getInstance(this.getApplicationContext());
            posts                       = handler.getPosts();
        }

        this.setPostsIntoDataStorage(posts);
        this.onServiceReturn();
    }

    private ArrayList<Post> processJSONData(String data) {
        ArrayList<Post> posts = new ArrayList<Post>();
        ObjectMapper mapper   = new ObjectMapper();
        try {
            Posts mPosts = mapper.readValue(data,Posts.class);
            posts        = mPosts.getPosts();
        }
        catch (IOException e) {
            e.printStackTrace();
        }
        return posts;
    }

    private boolean havePosts() {
        PostDatabaseHandler handler = PostDatabaseHandler.getInstance(this.getApplicationContext());
        return handler.havePosts();
    }

    private String downloadData(String url) {
        String result         = "";
        Downloader downloader = new Downloader(url);
        downloader.invoke();

        result                = downloader.getResult();
        this.setEtag("postsETag",downloader.getETag());
        return result;
    }

    private boolean hasExpired() {
        if (Connection.getConnectionStatus(this.getApplicationContext())) {
            Preferences pref      = Preferences.getInstance(this.getApplicationContext());
            String lastEtag       = pref.getValue("postsETag");
            String eTag           = HttpUtil.getETag(this.url);
            if (lastEtag.equals(eTag)) {
                return false;
            }
            return true;
        }
        return false;
    }

    private void setEtag(String name,String value) {
        Preferences pref      = Preferences.getInstance(this.getApplicationContext());
        pref.setValue(name,value);
    }




    public void onServiceReturn() {
        Intent intentResponse = new Intent();
        intentResponse.setAction("com.andreums.culturarocafort.downloaded.posts");
        sendBroadcast(intentResponse);
    }


    private void setPostsIntoDataStorage(ArrayList<Post> data) {
        DataStorage.setPosts(data);
    }

    private void setPostsIntoDatabaseHandler(ArrayList<Post> data) {
        if (data.size()>0) {
            PostDatabaseHandler handler = PostDatabaseHandler.getInstance(this.getApplicationContext());
            handler.clearPosts();
            handler.insertPosts(data);
        }
    }



}