package com.andreums.culturarocafort.services;

import android.app.IntentService;
import android.content.Intent;

import com.andreums.culturarocafort.Constants;
import com.andreums.culturarocafort.database.EventDatabaseHandler;
import com.andreums.culturarocafort.database.CategoryDatabaseHandler;
import com.andreums.culturarocafort.database.PostDatabaseHandler;
import com.andreums.culturarocafort.models.Categories;
import com.andreums.culturarocafort.models.Event;
import com.andreums.culturarocafort.models.Events;
import com.andreums.culturarocafort.models.Post;
import com.andreums.culturarocafort.models.Posts;
import com.andreums.culturarocafort.util.Connection;
import com.andreums.culturarocafort.util.DataStorage;
import com.andreums.culturarocafort.util.Downloader;
import com.andreums.culturarocafort.util.HttpUtil;
import com.andreums.culturarocafort.util.Preferences;
import com.fasterxml.jackson.databind.ObjectMapper;

import java.io.IOException;
import java.util.ArrayList;

public class UpdateDownloaderService extends IntentService {

    private String url;

    public UpdateDownloaderService() {
        super("FirstTimeDownloaderService");
    }


    @Override
    protected void onHandleIntent(Intent intent) {

        boolean result = false;
        if (Connection.getConnectionStatus(this.getApplicationContext())) {

            if (this.hasExpired("postsETag",Constants.getPostsURL(getApplicationContext()))) {
                result = true;
                ArrayList<Post> posts               = this.downloadPosts(Constants.getPostsURL(getApplicationContext()));
                DataStorage.setPosts(posts);
            }

            if (this.hasExpired("eventsETag",Constants.getEventsURL(getApplicationContext()))) {
                result = true;
                ArrayList<Event> events             = this.downloadEvents(Constants.getEventsURL(getApplicationContext()));
                DataStorage.setEvents(events);
            }

            if (this.hasExpired("categoriesETag", Constants.getCategoriesURL(getApplicationContext()))) {
                result = true;
                Categories categories = this.downloadCategories(Constants.getCategoriesURL(getApplicationContext()));
                DataStorage.setEventCategories(categories.getEventCategories());
                DataStorage.setPostCategories(categories.getCategories());
            }

        }
        this.onServiceReturn(result);
    }

    private ArrayList<Post> downloadPosts(String url) {
        ArrayList<Post> posts = new ArrayList<Post>();
        Downloader downloader = new Downloader(url);
        downloader.invoke();
        String eTag           = downloader.getETag();
        String result         = downloader.getResult();
        ObjectMapper mapper   = new ObjectMapper();
        try {
            Posts mPosts = mapper.readValue(result,Posts.class);
            posts        = mPosts.getPosts();
        }
        catch (IOException e) {
            e.printStackTrace();
        }

        this.setEtag("postsETag",eTag);

        PostDatabaseHandler handler = PostDatabaseHandler.getInstance(this.getApplicationContext());
        handler.clearPosts();
        handler.insertPosts(posts);

        return posts;
    }


    private Categories downloadCategories(String url) {

        Downloader downloader = new Downloader(url);
        downloader.invoke();
        String eTag           = downloader.getETag();
        String result         = downloader.getResult();

        Categories categories = new Categories();
        ObjectMapper mapper   = new ObjectMapper();
        try {
            categories   = mapper.readValue(result,Categories.class);
        }
        catch (IOException e) {
            e.printStackTrace();
        }

        CategoryDatabaseHandler pHandler = CategoryDatabaseHandler.getInstance(this.getApplicationContext());
        pHandler.clearCategories();
        pHandler.insertPostCategories(categories.getCategories());
        pHandler.insertEventCategories(categories.getEventCategories());

        return categories;
    }


    private ArrayList<Event> downloadEvents(String url) {
        ArrayList<Event> lEevents = new ArrayList<Event>();
        Downloader downloader = new Downloader(url);
        downloader.invoke();
        String eTag           = downloader.getETag();
        String result         = downloader.getResult();

        ObjectMapper mapper   = new ObjectMapper();
        try {
            Events events   = mapper.readValue(result,Events.class);
            lEevents        = events.getPosts();
        }
        catch (IOException e) {
            e.printStackTrace();
        }

        EventDatabaseHandler handler = EventDatabaseHandler.getInstance(this.getApplicationContext());
        handler.clearEvents();
        handler.insertEvents(lEevents);

        return lEevents;
    }


    public void onServiceReturn(boolean result) {
        Intent intentResponse = new Intent();
        intentResponse.setAction("com.andreums.culturarocafort.downloaded.updated");
        intentResponse.putExtra("result",result);
        sendBroadcast(intentResponse);
    }

    private void setEtag(String name,String value) {
        Preferences pref      = Preferences.getInstance(getApplicationContext());
        pref.setValue(name,value);
    }

    private boolean hasExpired(String name,String url) {
        if (Connection.getConnectionStatus(this.getApplicationContext())) {
            Preferences pref      = Preferences.getInstance(getApplicationContext());
            String lastEtag       = pref.getValue(name);
            String eTag           = HttpUtil.getETag(url);
            return (! (lastEtag.equals(eTag)));
        }
        return false;
    }
}
