package com.andreums.culturarocafort.services;

import android.app.IntentService;
import android.content.Intent;
import android.util.Log;

import com.andreums.culturarocafort.Constants;
import com.andreums.culturarocafort.database.VideosDatabaseHandler;
import com.andreums.culturarocafort.models.Video;
import com.andreums.culturarocafort.models.VideoPlayList;
import com.andreums.culturarocafort.parsers.YoutubeJSONParser;
import com.andreums.culturarocafort.util.Connection;
import com.andreums.culturarocafort.util.DataStorage;
import com.andreums.culturarocafort.util.Downloader;
import com.andreums.culturarocafort.util.HttpUtil;
import com.andreums.culturarocafort.util.Preferences;

import java.util.ArrayList;

public class YoutubeVideoDownloaderService extends IntentService {

    private String url;

    public YoutubeVideoDownloaderService() {
        super("YoutubeVideoDownloaderService");
    }


    @Override
    protected void onHandleIntent(Intent intent) {

        ArrayList<Video> videos = new ArrayList<Video>();
        String url              = intent.getStringExtra("url");
        this.url                = url;

        if ( (Connection.getConnectionStatus(this.getApplicationContext())) && (this.hasExpired()) ) {
            videos = this.downloadData(url);
            VideosDatabaseHandler handler = VideosDatabaseHandler.getInstance(this.getApplicationContext());
            handler.clearVideos();
            handler.insertVideos(videos);

        }

        else if (!this.haveVideos() && Connection.getConnectionStatus(this.getApplicationContext())) {
            videos = this.downloadData(url);
            VideosDatabaseHandler handler = VideosDatabaseHandler.getInstance(this.getApplicationContext());
            handler.clearVideos();
            handler.insertVideos(videos);
        }

        else if (this.haveVideos()) {
            VideosDatabaseHandler handler = VideosDatabaseHandler.getInstance(this.getApplicationContext());
            videos = handler.getVideos();
        }



        if ( (Connection.getConnectionStatus(this.getApplicationContext())) && (this.hasExpiredPlaylists()) ) {
            this.downloadVideoPlayLists();

        }

        else if (!this.havePlayLists() && Connection.getConnectionStatus(this.getApplicationContext())) {
            this.downloadVideoPlayLists();
        }


        this.onServiceReturn(videos);
    }

    private ArrayList<VideoPlayList> downloadVideoPlayLists() {
        ArrayList<VideoPlayList> playLists;

        VideosDatabaseHandler handler = VideosDatabaseHandler.getInstance(this.getApplicationContext());
        handler.clearPlayLists();
        handler.clearPlayListVideos();

        String url            = Constants.youtubePlayListFeedURL;
        Downloader downloader = new Downloader(url);
        downloader.invoke();
        String eTag           = downloader.getETag();
        String result         = downloader.getResult();
        YoutubeJSONParser parser = new YoutubeJSONParser(this.getApplicationContext());

        this.setEtag("videosPlayListsETag",eTag);

        playLists            = parser.parsePlayListFeedJSON(result);
        for (int i=0;i<playLists.size();i++) {
            String playListURL   =  Constants.youtubePlayListURL;
            playListURL          =  playListURL.replace("PLAYLIST_ID",playLists.get(i).getId());
            downloader.setURL(playListURL);
            downloader.invoke();
            String playListJSONData           = downloader.getResult();
            ArrayList<Video> videosInPlayList = parser.parsePlayListJSONData(playListJSONData);
            handler.insertVideos(videosInPlayList);
            handler.insertVideosInPlayList(playLists.get(i),videosInPlayList);
        }

        handler.insertPlaylists(playLists);

        return playLists;
    }




    private boolean haveVideos() {
        VideosDatabaseHandler handler = VideosDatabaseHandler.getInstance(this.getApplicationContext());
        return handler.haveVideos();
    }

    private boolean havePlayLists() {
        VideosDatabaseHandler handler = VideosDatabaseHandler.getInstance(this.getApplicationContext());
        return handler.havePlaylists();
    }


    private ArrayList<Video> downloadData(String url) {
        ArrayList<Video> videos;
        Downloader downloader = new Downloader(url);
        downloader.invoke();
        String eTag           = downloader.getETag();
        String result         = downloader.getResult();
        YoutubeJSONParser parser = new YoutubeJSONParser(this.getApplicationContext());
        videos                = parser.parseJSON(result);

        this.setEtag("videosETag",eTag);

        return videos;
    }


    private boolean hasExpired() {
        if (Connection.getConnectionStatus(this.getApplicationContext())) {
            Preferences pref      = Preferences.getInstance(this.getApplicationContext());
            String lastEtag       = pref.getValue("videosETag");
            String eTag           = HttpUtil.getETag(this.url);
            return (! (lastEtag.equals(eTag)));
        }
        return false;
    }


    private boolean hasExpiredPlaylists() {
        if (Connection.getConnectionStatus(this.getApplicationContext())) {
            Preferences pref      = Preferences.getInstance(this.getApplicationContext());
            String lastEtag       = pref.getValue("videosPlayListsETag");
            String eTag           = HttpUtil.getETag(Constants.youtubePlayListFeedURL);

            return (! (lastEtag.equals(eTag)));
        }
        return false;
    }

    private void setEtag(String name,String value) {
        Preferences pref      = Preferences.getInstance(this.getApplicationContext());
        pref.setValue(name,value);
    }


    public void onServiceReturn(ArrayList<Video> data) {
        DataStorage.setVideos(data);
        Intent intentResponse = new Intent();
        intentResponse.setAction("com.andreums.culturarocafort.downloaded.videos");
        sendBroadcast(intentResponse);
    }



}
